var locale = {
    "Add symbol": "Añadir un símbolo",
    "Allow scroll wheel zoom?": "¿Permitir acercar con la rueda central del ratón?",
    "Automatic": "Automático",
    "Ball": "Bola",
    "Cancel": "Cancelar",
    "Caption": "subtítulo",
    "Change symbol": "Cambiar símbolo",
    "Choose the data format": "Elegir el formato de datos",
    "Choose the layer of the feature": "Elegir la capa del elemento",
    "Circle": "Círculo",
    "Clustered": "Agrupados",
    "Data browser": "navegador de datos",
    "Default": "Predeterminado",
    "Default zoom level": "Nivel de acercamiento predeterminado",
    "Default: name": "Predeterminado: nombre",
    "Display label": "Mostrar etiqueta",
    "Display the control to open OpenStreetMap editor": "Mostrar el control para abrir el editor OpenStreetMap",
    "Display the data layers control": "Mostrrar el control de la capa de datos",
    "Display the embed control": "Mostrar el control de embebido",
    "Display the fullscreen control": "Mostrar el control de pantalla completa",
    "Display the locate control": "Mostrar el control de ubicación",
    "Display the measure control": "Mostrar el control de medida",
    "Display the search control": "Mostrar el control de búsqueda",
    "Display the tile layers control": "Mostrar el control de capas de teselas",
    "Display the zoom control": "Mostrar el control de acercamiento",
    "Do you want to display a caption bar?": "¿Quiere mostrar la barra de subtítulos?",
    "Do you want to display a minimap?": "¿Quiere mostrar un mini-mapa?",
    "Do you want to display a panel on load?": "¿Quiere mostrar un panel al cargar?",
    "Do you want to display popup footer?": "¿Quiere mostrar la ventana emergente en el pie de página?",
    "Do you want to display the scale control?": "¿Quiere mostrar el control de escala?",
    "Do you want to display the «more» control?": "¿Quiere mostrar el control «más»?",
    "Drop": "Gota",
    "GeoRSS (only link)": "georss (sólo enlace)",
    "GeoRSS (title + image)": "georss (título + imagen)",
    "Heatmap": "Mapa de calor",
    "Icon shape": "Icono de la forma",
    "Icon symbol": "Icono del símbolo",
    "Inherit": "Heredar",
    "Label direction": "Dirección de la etiqueta",
    "Label key": "Etiqueta de la clave",
    "Labels are clickable": "Las etiquetas se podrán hacer clic",
    "None": "ninguno",
    "On the bottom": "En la parte inferior",
    "On the left": "A la izquierda",
    "On the right": "A la derecha",
    "On the top": "En la parte superior",
    "Popup content template": "plantilla del contenido de la ventana emergente",
    "Set symbol": "Establecer símbolo",
    "Side panel": "panel lateral",
    "Simplify": "Simplifica",
    "Symbol or url": "Símbolo o URL",
    "Table": "tabla",
    "always": "siempre",
    "clear": "limpiar",
    "collapsed": "contraído",
    "color": "color",
    "dash array": "matriz de guiones",
    "define": "define",
    "description": "Descripción",
    "expanded": "expandido",
    "fill": "rellenar",
    "fill color": "color de relleno",
    "fill opacity": "rellenar la opacidad",
    "hidden": "oculta",
    "iframe": "iframe",
    "inherit": "heredar",
    "name": "Nombre",
    "never": "nunca",
    "new window": "nueva ventana",
    "no": "no",
    "on hover": "al pasar el ratón",
    "opacity": "opacidad",
    "parent window": "ventana padre",
    "stroke": "trazo",
    "weight": "peso",
    "yes": "si",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# una almohadilla para el encabezado principal",
    "## two hashes for second heading": "## dos almohadillas para el encabezado secundario",
    "### three hashes for third heading": "### tres almohadillas para el encabezado ternario",
    "**double star for bold**": "**dos asteriscos para negrita**",
    "*simple star for italic*": "*un asterisco para cursiva*",
    "--- for an horizontal rule": "--- para una línea horizontal",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista separada por comas que define el patrón de trazos de guión. Ej.: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Acción no permitida :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Añadir una capa",
    "Add a line to the current multi": "Añadir una línea para el multi actual",
    "Add a new property": "Añadir una nueva propiedad",
    "Add a polygon to the current multi": "Añadir un polígono para el multi actual",
    "Advanced actions": "Acciones avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "Advanced transition": "Transición avanzada",
    "All properties are imported.": "Todas las propiedades son importadas.",
    "Allow interactions": "Permitir interacciones",
    "An error occured": "Ocurrió un error",
    "Are you sure you want to cancel your changes?": "¿Está seguro que quiere cancelar sus cambios?",
    "Are you sure you want to clone this map and all its datalayers?": "¿Está seguro que quiere clonar este mapa y todas sus capas de datos?",
    "Are you sure you want to delete the feature?": "¿Está seguro que quiere eliminar este elemento?",
    "Are you sure you want to delete this layer?": "¿Está seguro que quiere borrar esta capa?",
    "Are you sure you want to delete this map?": "¿Está seguro que quiere eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "¿Esta seguro que quiere eliminar esta propiedad en todos los elementos?",
    "Are you sure you want to restore this version?": "¿Está seguro que quiere restaurar esta versión?",
    "Attach the map to my account": "Adjuntar el mapa a mi cuenta",
    "Auto": "Automático",
    "Autostart when map is loaded": "Autocomenzar cuando el mapa esté cargado",
    "Bring feature to center": "Llevar al centro el elemento",
    "Browse data": "Navegar los datos",
    "Cancel edits": "Cancelar las ediciones",
    "Center map on your location": "Centrar el mapa en su ubicación",
    "Change map background": "Cambiar mapa de fondo",
    "Change tilelayers": "Cambiar capas de teselas",
    "Choose a preset": "Elegir un preestablecido",
    "Choose the format of the data to import": "Elegir el formato de los datos a importar",
    "Choose the layer to import in": "Elegir la capa a la que se importa",
    "Click last point to finish shape": "Haga clic en el último punto para terminar la forma",
    "Click to add a marker": "Haga clic para añadir un marcador",
    "Click to continue drawing": "Haga clic para seguir dibujando",
    "Click to edit": "Clic para editar",
    "Click to start drawing a line": "Haga clic para empezar a dibujar una línea",
    "Click to start drawing a polygon": "Haga clic para empezar a dibujar un polígono",
    "Clone": "Clonar",
    "Clone of {name}": "Clón de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Close": "Cerrar",
    "Clustering radius": "Radio de agrupación",
    "Comma separated list of properties to use when filtering features": "Lista de propiedades separado por comas para utilizar el filtrado de elementos",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por coma, tabulación o punto y coma. Se presupone formato SRS WGS84. Sólo se importan geometrías de punto. El importador buscará, en las cabeceras de cada columna, cualquier mención de «lat» y «lon» al comienzo de la cabecera, en mayúsculas o minúsculas. Todas las columnas restantes son importadas como propiedades.",
    "Continue line": "Línea continua",
    "Continue line (Ctrl-click)": "Línea continuada (Ctrl-clic)",
    "Coordinates": "Coordenadas",
    "Credits": "Créditos",
    "Current view instead of default map view?": "¿Vista actual en lugar de la vista predeterminada?",
    "Custom background": "Fondo personalizado",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Opciones de interacción predeterminados",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de formas predeterminados",
    "Define link to open in a new window on polygon click.": "Defina un enlace para abrir en un nueva ventana al hacer clic en el polígono.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Eliminar",
    "Delete all layers": "Eliminar todas las capas",
    "Delete layer": "Borrar capa",
    "Delete this feature": "Eliminar este elemento",
    "Delete this property on all the features": "Eliminar esta propiedad en todos los elementos",
    "Delete this shape": "Eliminar esta forma",
    "Delete this vertex (Alt-click)": "Eliminar este vértice (Alt-clic)",
    "Directions from here": "Direcciones desde aquí",
    "Disable editing": "Deshabilitar la edición",
    "Display measure": "Display measure",
    "Display on load": "Mostrar al cargar",
    "Download": "Descargar",
    "Download data": "Descargar datos",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a line": "Dibuja una línea",
    "Draw a marker": "Dibuja un marcador",
    "Draw a polygon": "Dibuja un polígono",
    "Draw a polyline": "Dibuja una polilínea",
    "Dynamic": "Dinámico",
    "Dynamic properties": "Propiedades dinámicas",
    "Edit": "Editar",
    "Edit feature's layer": "Editar la capa del elemento",
    "Edit map properties": "Editar propiedades del mapa",
    "Edit map settings": "Editar ajustes del mapa",
    "Edit properties in a table": "Editar propiedades en una tabla",
    "Edit this feature": "Editar este elemento",
    "Editing": "Editando",
    "Embed and share this map": "Embeber y compartir este mapa",
    "Embed the map": "Embeber el mapa",
    "Empty": "Vaciar",
    "Enable editing": "Habilitar la edición",
    "Error in the tilelayer URL": "Error en la URL del la capa de teselas",
    "Error while fetching {url}": "Error al recuperar {url}",
    "Exit Fullscreen": "Salir de la pantalla completa",
    "Extract shape to separate feature": "Extraer la forma al elemento separado",
    "Fetch data each time map view changes.": "Traer datos cada vez que la vista del mapa cambia.",
    "Filter keys": "Claves de filtrado",
    "Filter…": "Filtro...",
    "Format": "Formato",
    "From zoom": "Desde el acercamiento",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propiedad intensidad del mapa de calor",
    "Heatmap radius": "Radio del mapa de calor",
    "Help": "Ayuda",
    "Hide controls": "Ocultar controles",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Cuánto se simplificará la polilínea en cada nivel de acercamiento (más = mejor comportamiento y apariencia más suave, menos = más preciso)",
    "If false, the polygon will act as a part of the underlying map.": "Si falso, el polígono actuará como una parte del mapa subyacente.",
    "Iframe export options": "Opciones de exportación del iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altura personalizada (en píxeles): {{{http://iframe.url.com|altura}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con alto y ancho (en px) personalizado: {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imagen con anchura personalizada (en píxeles): {{http://imagen.url.com|anchura}}",
    "Image: {{http://image.url.com}}": "Imagen: {{http://imagen.url.com}}",
    "Import": "Importar",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar en una nueva capa",
    "Imports all umap data, including layers and settings.": "Importar todos los datos umap, incluyendo capas y ajustes.",
    "Include full screen link?": "¿Incluir el enlace de pantalla completa?",
    "Interaction options": "Opciones de interacción",
    "Invalid umap data": "Dato umap inválido",
    "Invalid umap data in {filename}": "Dato umap inválido en {filename}",
    "Keep current visible layers": "Guardar capas visibles actuales",
    "Latitude": "Latitud",
    "Layer": "Capa",
    "Layer properties": "Propiedades de la capa",
    "Licence": "Licencia",
    "Limit bounds": "Limitar los límites",
    "Link to…": "Enlace a...",
    "Link with text: [[http://example.com|text of the link]]": "Enlace con texto: [[http://ejemplo.com|texto del enlace]]",
    "Long credits": "créditos largo",
    "Longitude": "Longitud",
    "Make main shape": "Hacer la forma principal",
    "Manage layers": "Gestionar capas",
    "Map background credits": "Créditos del mapa de fondo",
    "Map has been attached to your account": "El mapa se ha adjuntado a su cuenta",
    "Map has been saved!": "¡Se ha guardado el mapa!",
    "Map user content has been published under licence": "El contenido del mapa del usuario ha sido publicados bajo la licencia",
    "Map's editors": "Editores del mapa",
    "Map's owner": "Propietario del mapa",
    "Merge lines": "Combinar líneas",
    "More controls": "Más controles",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Debe ser un valor CSS válido (por ej.: DarkBlue o #123456)",
    "No licence has been set": "Ninguna licencia se ha establecido",
    "No results": "Sin resultado",
    "Only visible features will be downloaded.": "Sólo los elementos visibles se descargarán.",
    "Open download panel": "Abrir el panel de descarga",
    "Open link in…": "Abrir enlace en...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre la extensión de este mapa en un editor de mapas para proveer datos más precisos a OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedad intensidad opcional para el mapa de calor",
    "Optional. Same as color if not set.": "Opcional. El mismo color si no se establece.",
    "Optionnal.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrescribir el radio de agrupación (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobreescribir el radio del mapa de calor (predeterminado 25)",
    "Paste here your data": "Pegue aquí sus datos",
    "Please be sure the licence is compliant with your use.": "Asegúrase que la licencia sea compatible con el uso que le va a dar.",
    "Please choose a format": "Elije un formato",
    "Please enter the name of the property": "Introduzca el nombre de la propiedad",
    "Please enter the new name of this property": "Introduzca el nuevo nombre de esta propiedad",
    "Please save the map before": "Guarde antes el mapa",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Impulsado por <a href=\"{leaflet}\">Leaflet</a> y <a href=\"{django}\">Django</a>, pegado por <a href=\"{umap}\">proyecto uMap</a>.",
    "Problem in the response": "Problema en la respuesta",
    "Problem in the response format": "Problema con el formato de respuesta",
    "Properties imported:": "Propiedades importadas:",
    "Property to use for sorting features": "Propiedad para ordenar los elementos",
    "Provide an URL here": "Proporcione una URL aquí",
    "Proxy request": "Petición a proxy",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Quitar la forma del multi",
    "Rename this property on all the features": "Renombrar esta propiedad en todos los elementos",
    "Replace layer content": "Reemplaza el contenido de la capa",
    "Restore this version": "Restaurar esta versión",
    "Save": "Guardar",
    "Save anyway": "Guardar de todos modos",
    "Save current edits": "Guardar las ediciones actuales",
    "Save this center and zoom": "Guardar este centrado y acercamiento",
    "Save this location as new feature": "Guardar esta ubicación como nuevo elemento",
    "Search a place name": "Buscar el nombre de un lugar",
    "Search location": "Buscar ubicación",
    "Secret edit link is:<br>{link}": "El enlace secreto de edición es:<br>{link}",
    "See all": "Ver todo",
    "See data layers": "Ver capas de datos",
    "See full screen": "Ver pantalla completa",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Propiedades de la forma",
    "Short URL": "URL corta",
    "Short credits": "créditos corto",
    "Show/hide layer": "Mostrar/ocultar capa",
    "Simple link: [[http://example.com]]": "Enlace simple: [[http://ejemplo.com]]",
    "Skipping unkown geometry.type: {type}": "Ignorando tipo de geometría desconocida: {type}",
    "Slideshow": "Presentación de diapositivas",
    "Smart transitions": "Smart transitions",
    "Sort key": "Orden de la clave",
    "Split line": "Linea de división",
    "Start a hole here": "Iniciar un agujero aquí",
    "Start editing": "Comenzar a editar",
    "Start slideshow": "Iniciar presentación de diapositivas",
    "Stop editing": "Parar de editar",
    "Stop slideshow": "Parar presentación de diapositivas",
    "Supported scheme": "Esquema soportado",
    "Supported variables that will be dynamically replaced": "Variables soportadas que serán reemplazadas dinámicamente",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "El símbolo puede ser un carácter unicode o una URL. Puede usar las propiedades del elemento como variables: ej.: \"http://myserver.org/images/{name}.png\",  la variable {name} será remplazada por el valor \"name\" de cada marcador.",
    "TMS format": "formato TMS",
    "Text color for the cluster label": "Color del texto para la etiqueta clúster",
    "Text formatting": "Formato de texto",
    "The name of the property to use as feature label (ex.: \"nom\")": "El nombre de la propiedad a usar como etiqueta del elemento (ej.: «nom»)",
    "The zoom and center have been setted.": "El acercamiento y el centrado han sido establecidos.",
    "To use if remote server doesn't allow cross domain (slower)": "Para utilizar si el servidor remoto no permite dominios cruzados (más lento)",
    "To zoom": "Para el acercamiento",
    "Toggle edit mode (shift-click)": "Conmuta el modo edición (shift-clic)",
    "Transfer shape to edited feature": "Transferir la forma al elemento editada",
    "Transform to lines": "Transformar a líneas",
    "Transform to polygon": "Transformar a polígono",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "No se puede detectar el formato de archivo {filename}",
    "Untitled layer": "Capa sin título",
    "Untitled map": "Mapa sin título",
    "Update permissions": "Actualizar permisos",
    "Update permissions and editors": "Actualizar permisos y editores",
    "Url": "Url",
    "Use current bounds": "Utilizar límites actuales",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilizar marcadores de posición con propiedades del elemento entre paréntesis, ejemplo &#123;name&#125;, serán reemplazados dinámicamente por los valores correspondientes.",
    "User content credits": "Créditos del contenido del usuario",
    "User interface options": "Opciones de la interface de usuario",
    "Versions": "Versiones",
    "View Fullscreen": "Ver en pantalla completa",
    "Where do we go from here?": "¿A dónde vamos a partir de aquí?",
    "Whether to display or not polygons paths.": "Si desea mostrar o no el trayecto de los polígonos.",
    "Whether to fill polygons with color.": "Si desea rellenar los polígonos con color.",
    "Who can edit": "Quién puede editar",
    "Who can view": "Quién puede ver",
    "Will be displayed in the bottom right corner of the map": "Se mostrará en la esquina inferior izquierda del mapa",
    "Will be visible in the caption of the map": "Será visible en el subtítulo del mapa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "¡Oops! Alguien parece haber editado los datos. Puedes guardar de todos modos, pero esto va a borrar los cambios realizados por otros.",
    "You have unsaved changes.": "Tiene cambios no guardados.",
    "Zoom in": "Acercar",
    "Zoom level for automatic zooms": "Nivel de acercamiento para acercamientos automáticos",
    "Zoom out": "Alejar",
    "Zoom to layer extent": "Acercamiento al nivel de la capa",
    "Zoom to the next": "Acercamiento al siguiente",
    "Zoom to the previous": "Acercamiento al anterior",
    "Zoom to this feature": "Acercamiento a este elemento",
    "Zoom to this place": "Acercamiento a este lugar",
    "attribution": "atribución",
    "by": "por",
    "display name": "mostrar nombre",
    "height": "altura",
    "licence": "licencia",
    "max East": "máximo Este",
    "max North": "máximo Norte",
    "max South": "máximo Sur",
    "max West": "máximo Oeste",
    "max zoom": "acercamiento máximo",
    "min zoom": "acercamiento mínimo",
    "next": "siguiente",
    "previous": "anterior",
    "width": "anchura",
    "{count} errors during import: {message}": "{count} errores durante la importación: {message}",
    "Measure distances": "Medir distancias",
    "NM": "NM",
    "kilometers": "kilómetros",
    "km": "km",
    "mi": "mi",
    "miles": "millas",
    "nautical miles": "millas náuticas",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} millas",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("es", locale);
L.setLocale("es");