var locale = {
    "Add symbol": "Přidat symbol",
    "Allow scroll wheel zoom?": "Povolit přibližování kolečkem myši?",
    "Automatic": "Automatic",
    "Ball": "špendlík",
    "Cancel": "Storno",
    "Caption": "Popisek",
    "Change symbol": "Změnit symbol značky",
    "Choose the data format": "Vyberte formát dat",
    "Choose the layer of the feature": "Zvolte vrstvu do které objekt patří",
    "Circle": "Kruh",
    "Clustered": "Shluková",
    "Data browser": "Prohlížeč dat",
    "Default": "Výchozí",
    "Default zoom level": "Výchozí přiblížení",
    "Default: name": "Výchozí: name (název objektu)",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Chcete zobrazit panel s popiskem?",
    "Do you want to display a minimap?": "Chcete zobrazit minimapu?",
    "Do you want to display a panel on load?": "Chcete při načtení zobrazit panel?",
    "Do you want to display popup footer?": "Chcete v bublině zobrazit navigační panel?",
    "Do you want to display the scale control?": "Chcete zobrazit měřítko mapy?",
    "Do you want to display the «more» control?": "Přejete si zobrazovat ovládací prvek «více»?",
    "Drop": "Pustit",
    "GeoRSS (only link)": "GeoRSS (jen odkaz)",
    "GeoRSS (title + image)": "GeoRSS (titulek + obrázek)",
    "Heatmap": "Teplotní mapa",
    "Icon shape": "Tvar ikony",
    "Icon symbol": "Symbol ikony",
    "Inherit": "výchozí",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Žádný",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Šablona obsahu bubliny",
    "Set symbol": "Set symbol",
    "Side panel": "Boční panel",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Tabulka",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "barva",
    "dash array": "styl přerušované čáry",
    "define": "define",
    "description": "popis",
    "expanded": "expanded",
    "fill": "výplň",
    "fill color": "barva výplně",
    "fill opacity": "průhlednost výplně",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "výchozí",
    "name": "název",
    "never": "never",
    "new window": "new window",
    "no": "ne",
    "on hover": "on hover",
    "opacity": "průhlednost",
    "parent window": "parent window",
    "stroke": "linka",
    "weight": "šířka linky",
    "yes": "ano",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# jedna mřížka pro hlavní nadpis",
    "## two hashes for second heading": "## dvě mřížky pro nadpis druhé úrovně",
    "### three hashes for third heading": "### podnadpis třetí úrovně",
    "**double star for bold**": "**vše mezi dvěma hvězdičkami je tučně**",
    "*simple star for italic*": "*vše mezi hvězdičkami bude kurzívou*",
    "--- for an horizontal rule": "--- vytvoří vodorovnou linku",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Čárkami oddělený seznam čísel, který popisuje vzorek přerušované čáry. Např. «5, 10, 15».",
    "About": "O mapě",
    "Action not allowed :(": "Akce nepovolena :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Přidat vrstvu",
    "Add a line to the current multi": "Přidat čáru k současnému multi",
    "Add a new property": "Přidat novou vlastnost",
    "Add a polygon to the current multi": "Přidat polygon k současnému multi",
    "Advanced actions": "Pokročilé akce",
    "Advanced properties": "Pokročilé vlastnosti",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Všechny vlastnosti jsou importovány.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Došlo k chybě",
    "Are you sure you want to cancel your changes?": "Jste si jisti že chcete stornovat vaše úpravy?",
    "Are you sure you want to clone this map and all its datalayers?": "Určitě chcete vytvořit kopii celé této mapy a všech jejich vrstev?",
    "Are you sure you want to delete the feature?": "Určitě chcete vymazat tento objekt?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Jste si jisti, že chcete vymazat tuto celou mapu?",
    "Are you sure you want to delete this property on all the features?": "Určitě chcete smazat tuto vlastnost na všech objektech?",
    "Are you sure you want to restore this version?": "Opravdu si přejete obnovit tuto verzi?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Automatická",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Centruj mapu na objektu",
    "Browse data": "Prohlížet data",
    "Cancel edits": "Stornovat úpravy",
    "Center map on your location": "Přemístit se na mapě na vaši polohu",
    "Change map background": "Změnit pozadí mapy",
    "Change tilelayers": "Změnit pozadí mapy",
    "Choose a preset": "Zvolte přednastavení",
    "Choose the format of the data to import": "Zvolte v jakém formátu jsou importovaná data",
    "Choose the layer to import in": "Zvolte vrstvu, do které se bude importovat",
    "Click last point to finish shape": "Klikněte na poslední bod pro dokončení tvaru",
    "Click to add a marker": "Kliknutím přidáš značku",
    "Click to continue drawing": "Kliknutím můžeš pokračovat v kreslení",
    "Click to edit": "Klikněte pro úpravy",
    "Click to start drawing a line": "Klikněte pro začátek kreslení čáry",
    "Click to start drawing a polygon": "Klikněte pro začátek kreslení polygonu",
    "Clone": "Klonovat",
    "Clone of {name}": "Klon objektu {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Vytvořit vlastní kopii této mapy",
    "Close": "Zavřít",
    "Clustering radius": "Poloměr shlukování",
    "Comma separated list of properties to use when filtering features": "Čárkami oddělený seznam vlastností pro filtrování objektů",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Hodnoty oddělené čárkou, tabulátorem, nebo středníkem. předpokládá se SRS WGS84 a jsou importovány jen polohy bodů. Import hledá záhlaví sloupců začínající na \"lat\" nebo \"lon\" a ty považuje za souřadnice (na velikosti písmen nesejde). Ostatní sloupce jsou importovány jako vlastnosti.",
    "Continue line": "Pokračovat v čáře",
    "Continue line (Ctrl-click)": "Pokračovat v čáře (Ctrl-klik)",
    "Coordinates": "Souřadnice",
    "Credits": "Autorství",
    "Current view instead of default map view?": "Současný pohled namísto výchozího?",
    "Custom background": "Vlastní pozadí",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Výchozí vlastnosti",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Vymazat",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Vymazat objekt",
    "Delete this property on all the features": "Smazat tuto vlastnost na všech objektech",
    "Delete this shape": "Smazat tento tvar",
    "Delete this vertex (Alt-click)": "Smazat tento bod (Alt-klik)",
    "Directions from here": "Navigovat odsud",
    "Disable editing": "Zakázat úpravy",
    "Display measure": "Display measure",
    "Display on load": "Zobrazit na startu",
    "Download": "Download",
    "Download data": "Stáhnout data",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Nakreslit jednoduchou čáru",
    "Draw a marker": "Umístit značku místa",
    "Draw a polygon": "Vyznačit oblast",
    "Draw a polyline": "Nakreslit čáru",
    "Dynamic": "Dynamicky",
    "Dynamic properties": "Dynamické vlastnosti",
    "Edit": "Upravit",
    "Edit feature's layer": "Upravit vrstvu objektu",
    "Edit map properties": "Nastavení mapy",
    "Edit map settings": "Nastavení mapy",
    "Edit properties in a table": "Upravit vlastnosti v tabulce",
    "Edit this feature": "Upravit tento objekt",
    "Editing": "Upravujete",
    "Embed and share this map": "Sílet mapu nebo ji vložit do jiného webu",
    "Embed the map": "Vložit mapu do jiného webu",
    "Empty": "Vyprázdnit",
    "Enable editing": "Povolit úpravy",
    "Error in the tilelayer URL": "Chyba v URL vrstvy dlaždic",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Vyjmout tvar do samostatného objektu",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filter ...",
    "Format": "Formát",
    "From zoom": "Maximální oddálení",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Jdi na  \"{feature}\"",
    "Heatmap intensity property": "Vlastnost pro intenzitu teplotní mapy",
    "Heatmap radius": "Poloměr teplotní mapy",
    "Help": "Nápověda",
    "Hide controls": "Skrýt ovládací prvky",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak moc zahlazovat a zjednodušovat při oddálení (větší = rychlejší odezva a plynulejší vzhled, menší = přesnější)",
    "If false, the polygon will act as a part of the underlying map.": "Pokud je vypnuto, polygon se bude chovat jako součást mapového podkladu.",
    "Iframe export options": "Možnosti exportu pro iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe s vlastní výškou (v px): {{{http://iframe.url.com|výška}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obrázek s vlastní šířkou (v px): {{http://obrazek.url.com|šířka}}",
    "Image: {{http://image.url.com}}": "Obrázek: {{http://priklad.cz/obrazek.jpg}}",
    "Import": "Importovat",
    "Import data": "Import dat",
    "Import in a new layer": "Importovat do nové vrstvy",
    "Imports all umap data, including layers and settings.": "Importuje všechy data umapy, včetně vrstev a nastavení",
    "Include full screen link?": "Zahrnout odkaz na celou obrazovku?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Neplatná data umapy",
    "Invalid umap data in {filename}": "Neplatná data umapy v souboru {filename}",
    "Keep current visible layers": "Použít aktuální zobrazení vrstev",
    "Latitude": "Sev. šířka",
    "Layer": "Vrstva",
    "Layer properties": "Vlastnosti vrstvy",
    "Licence": "Licence",
    "Limit bounds": "Hranice zobrazení",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Odkaz: [[http://priklad.cz/stranka|text odkazu]]",
    "Long credits": "Dlouhý text autorství",
    "Longitude": "Délka",
    "Make main shape": "Učinit hlavním tvarem",
    "Manage layers": "Manage layers",
    "Map background credits": "Autorství pozadí mapy",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Mapa byla uložena",
    "Map user content has been published under licence": "Uživatelská data jsou zveřejněna pod licencí",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Spojit čáry",
    "More controls": "Více ovládacích prvků",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Platný název v CSS (např.: Red, Blue nebo #123456)",
    "No licence has been set": "Nebyla nastavena licence",
    "No results": "Žádné výsledky",
    "Only visible features will be downloaded.": "Budou staženy jen viditelné objekty",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otevři tuto oblast v editoru OpenStreetMap. Toto vám umožní editovat přímo základní mapová data a přispět tak v tvorbě svobodné mapy pro všechny.",
    "Optional intensity property for heatmap": "Volitelná vlastnost pro výpočet intenzity v teplotní mapě",
    "Optional. Same as color if not set.": "Nepovinné. Stejné jako barva, pokud není nastaveno.",
    "Optionnal.": "Nepovinné.",
    "Override clustering radius (default 80)": "Přepsat shlukovací poloměr (výchozí hodnota 80)",
    "Override heatmap radius (default 25)": "Přepsat poloměr teplotní mapy (výchozí hodnota 25)",
    "Paste here your data": "Sem vložte vaše data",
    "Please be sure the licence is compliant with your use.": "Prosíme ujistěte se, že licence je ve shodě s tím jak mapu používáte.",
    "Please choose a format": "Zvolte formát",
    "Please enter the name of the property": "Zadejte prosím název vlastnosti",
    "Please enter the new name of this property": "Zadejte prosím nový název této vlastnosti",
    "Please save the map before": "Prosíme, uložte nejdříve mapu",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Sestaveno z <a href=\"{leaflet}\">Leaflet</a> a <a href=\"{django}\">Django</a>, propojených pomocí <a href=\"{umap}\">projektu uMap</a>.",
    "Problem in the response": "Problém při odpovědi",
    "Problem in the response format": "Problém ve formátu odpovědi",
    "Properties imported:": "Importované vlastnosti:",
    "Property to use for sorting features": "Vlastnost použitá pro řazení objektů",
    "Provide an URL here": "Sem vložte odkaz",
    "Proxy request": "Požadavky přes proxy",
    "Remote data": "Vzdálená data",
    "Remove shape from the multi": "Odebrat tvar z multi",
    "Rename this property on all the features": "Přejmenovat tuto vlastnost na všech objektech",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Obnovit tuto verzi",
    "Save": "Ulož",
    "Save anyway": "I tak uložit",
    "Save current edits": "Ulož nedávné změny",
    "Save this center and zoom": "Ulož tuto pozici mapy a její přiblížení",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Zobraz vše",
    "See data layers": "See data layers",
    "See full screen": "Na celou obrazovku",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Krátký odkaz",
    "Short credits": "Krátký text autorství",
    "Show/hide layer": "Skrytí/zobrazení vrstvy",
    "Simple link: [[http://example.com]]": "Jednoduchý odkaz: [[http://priklad.cz]]",
    "Skipping unkown geometry.type: {type}": "Přeskakuji neznámý typ geometrie: {type}",
    "Slideshow": "Prezentace",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Rozdělit čáru",
    "Start a hole here": "Začít tady díru",
    "Start editing": "Začít editaci",
    "Start slideshow": "Spustit prezentaci",
    "Stop editing": "Přerušit úpravy",
    "Stop slideshow": "Zastavit prezentaci",
    "Supported scheme": "Podporované schéma",
    "Supported variables that will be dynamically replaced": "Podporované proměnné, které budou automaticky nahrazeny",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "formát TMS",
    "Text color for the cluster label": "Barva textu popisku shluku",
    "Text formatting": "Formátování textu",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Přiblížení a střed mapy byly nastaveny",
    "To use if remote server doesn't allow cross domain (slower)": "Pro případ že vzdálený server neumožňuje cross domain (pomalejší)",
    "To zoom": "Maximální přiblížení",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Přenést tvar do editovaného objektu",
    "Transform to lines": "Převést na čáry",
    "Transform to polygon": "Převést na polygon",
    "Type of layer": "Druh vrstvy",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Nepojmenovaná vrstva",
    "Untitled map": "Mapa bez názvu",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Nastavení přístupu a práva editace",
    "Url": "Url",
    "Use current bounds": "Použít současné hranice",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Použijte zástupný text s vlastnostmi objektů mezi složenými závorkami, např. &#123;name&#125; &mdash; budou dynamicky nahrazeny odpovídajícími hodnotami.",
    "User content credits": "Autorství uživatelského obsahu",
    "User interface options": "Nastavení ovládacích prvků mapy",
    "Versions": "Verze",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Co všechno teď můžete udělat?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Bude zobrazeno s mapou napravo dole",
    "Will be visible in the caption of the map": "Bude zobrazeno v popisu mapy",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ojoj! Někdo jiný mezitím také upravil data. Můžete je uložit bez ohledu na to, ale smažete tak jeho změny.",
    "You have unsaved changes.": "Máte neuložené změny.",
    "Zoom in": "Přiblížit",
    "Zoom level for automatic zooms": "Úroveň přiblížení pro automatické přiblížení",
    "Zoom out": "Oddálit",
    "Zoom to layer extent": "Přizpůsobit přiblížení vrstvě",
    "Zoom to the next": "Skočit na následující",
    "Zoom to the previous": "Skočit na předchozí",
    "Zoom to this feature": "Přiblížit na tento objekt",
    "Zoom to this place": "Zoom to this place",
    "attribution": "autorství",
    "by": "od",
    "display name": "zobrazit název",
    "height": "výška",
    "licence": "licence",
    "max East": "maximálně na Východ",
    "max North": "maximálně na Sever",
    "max South": "maximálně na Jih",
    "max West": "maximálně na Západ",
    "max zoom": "maximální přiblížení",
    "min zoom": "maximální oddálení",
    "next": "další",
    "previous": "předchozí",
    "width": "šířka",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("cs_CZ", locale);
L.setLocale("cs_CZ");