var locale = {
    "Add symbol": "ምልክት ጨምር",
    "Allow scroll wheel zoom?": "በማውሱ መሀከለኛ ተሽከርካሪ ማጉላት ይፈቀድ?",
    "Automatic": "Automatic",
    "Ball": "ኳስ",
    "Cancel": "አቁም/ሰርዝ",
    "Caption": "ካፕሽን",
    "Change symbol": "ምልክቱን ይቀይሩ",
    "Choose the data format": "የረጃውን ፎርማት ቀይር",
    "Choose the layer of the feature": "የፊቸሩን ሌየር ይምረጡ",
    "Circle": "አክብብ/ክብ",
    "Clustered": "ክለስተርድ",
    "Data browser": "የመረጃ ማሰሻ",
    "Default": "ዋና ምርጫ (ዲፎልት)",
    "Default zoom level": "Default zoom level",
    "Default: name": "ዲፎልት፡ ስም",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "የካፕሽን ባሩን ማሳየት ትፈልጋለህ?",
    "Do you want to display a minimap?": "ትንሿን ካርታ ማሳየት ይፈልጋሉ?",
    "Do you want to display a panel on load?": "ፓኔሉ በመጫን ላይ እያለ ማሳየት ትፈልጋለህ?",
    "Do you want to display popup footer?": "ፖፕ አፕ ፉተሩን ማሳየት ይፈልጋሉ?",
    "Do you want to display the scale control?": "የመጠን መቆጣጠሪያውን ማሳየት ይፈልጋሉ?",
    "Do you want to display the «more» control?": "የ «ተጨማሪ» መቆጣጠሪያውን ማሳየት ትፈልጋለህ",
    "Drop": "ጣል",
    "GeoRSS (only link)": "GeoRSS (ሊንክ ብቻ)",
    "GeoRSS (title + image)": "GeoRSS (መጠሪያ + ምስል)",
    "Heatmap": "የሙቀት ካርታ",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "ውረስ",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "ምንም",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "የፖፕ-አፕ ኮንቴንት ተምሳሌ",
    "Set symbol": "Set symbol",
    "Side panel": "የጎን ፓኔል",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "ሰንጠረዥ",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "ከለር",
    "dash array": "ዳሽ አሬይ",
    "define": "define",
    "description": "መገለጫ",
    "expanded": "expanded",
    "fill": "ሙላ",
    "fill color": "ከለር ሙላ",
    "fill opacity": "ኦፓሲቲውን ሙላ",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "ውረስ",
    "name": "ስም",
    "never": "never",
    "new window": "new window",
    "no": "አይደለም",
    "on hover": "on hover",
    "opacity": "ኦፓሲቲ",
    "parent window": "parent window",
    "stroke": "ሳል/ጫር",
    "weight": "ክብደት",
    "yes": "አዎን",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# አንድ ፓውንድ ምልክት ለዋናው አርእስት",
    "## two hashes for second heading": "## ሁለት ፓውንድ ምልክቶች ለንዑስ አርእስቱ",
    "### three hashes for third heading": "### ሶስት ፓውንድ ምልክቶች ለሶስተኛው ደረጃ አርእስት",
    "**double star for bold**": "** ሁለት ኮኮብ ለማወፈር **",
    "*simple star for italic*": "* አንድ ኮከብ ለማጣመም *",
    "--- for an horizontal rule": "--- ለአግድም መስመር",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "ስለ",
    "Action not allowed :(": "አይፈቀድም :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "ሌየር ጨምር",
    "Add a line to the current multi": "ላሁኑ ብዝሀ መስመር ጨምር",
    "Add a new property": "አዲስ ባህርይ ጨምር",
    "Add a polygon to the current multi": "ላሁኑ ብዝሀ ፖሊጎን ጨምር",
    "Advanced actions": "ተጨማሪ ተግባራት",
    "Advanced properties": "ተጨማሪ ባህርያት",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "ሁሉም ባህርያት መጥተዋል",
    "Allow interactions": "Allow interactions",
    "An error occured": "ስህተት ተፈጥሯል",
    "Are you sure you want to cancel your changes?": "እርግጠኛ ነዎት ያሻሻሉትም ማስቀመጥ አይፈልጉም?",
    "Are you sure you want to clone this map and all its datalayers?": "እርግጠኛ ነዎት ይህንን ካርታ እና ሁሉንም የመረጃ ገጾች ማባዛት ይፈልጋሉ?",
    "Are you sure you want to delete the feature?": "እርግጠኛ ነዎት ይህንን ተግባሩን መሰረዝ ይፈልጋሉ?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "እርግጠኛ ነዎት ይህንን ካርታ መሰረዝ ይፈልጋሉ?",
    "Are you sure you want to delete this property on all the features?": "እርግጠኛ ነህ ይህንንባህርይ ከሁሉም ፊቸሮች ላይ መሰረዝ ትችላለህ",
    "Are you sure you want to restore this version?": "እርግጠኛ ነዎት ወደዚህኛው እትም መመለስ ይልጋሉ?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "አውቶ",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "ፊቸርሩን ወደመሀከል አምጣ",
    "Browse data": "መረጃዎቹን አሥሥ",
    "Cancel edits": "እርማቶችን ሰርዝ",
    "Center map on your location": "መገኛዎን የሚያሳየውን ካርታ ወደ መሀል ያድርጉ",
    "Change map background": "የካርታውን የጀርባ ገፅታ ይቀይሩ",
    "Change tilelayers": "የታይልሌየሩን",
    "Choose a preset": "ፕሪሴት ምረጥ",
    "Choose the format of the data to import": "ሊያመጡ የፈለጉትን የመረጃ ፎርማት ይምረጡ",
    "Choose the layer to import in": "የሚያስገቡበት ሌየር ይምረጡ",
    "Click last point to finish shape": "ቅርፁን ለማስጨረስ የመጨረሻውን ነጥብ ጠቅ ያድርጉ",
    "Click to add a marker": "መለያ ለመጨመር ጠቅ አድርግ",
    "Click to continue drawing": "መሳል ለመቀጠል ጠቅ አድርግ",
    "Click to edit": "ለማረም ጠቅ አድርግ",
    "Click to start drawing a line": "መስመር ለመሳል ጠቅ አድርግ",
    "Click to start drawing a polygon": "ፖሊጎን ለመሳል ጠቅ አድርግ",
    "Clone": "አዳቅል",
    "Clone of {name}": "የ {name} ድቃይ",
    "Clone this feature": "Clone this feature",
    "Clone this map": "ይህንን ካርታ አባዛ",
    "Close": "ዝጋ",
    "Clustering radius": "ክለስተሪንግ ራዲየስ",
    "Comma separated list of properties to use when filtering features": "ፊቸሮችን በሚያጣሩበት ጊዜ ሊጠቀሙ የሚችሏቸው በኮማ የተከፋፈሉ የባህርያት ዝርዝር",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "በኮማ፣ታብ፣ግማሽኮለን የተከፋፈሉ ውጤቶች። SRSWG84 ተመላክቷል። የነጥብ ጂኦሜትሪዎች ብቻ መጥተዋል። የማምጣት ሂደቱ የኮለምን ሄደሮችን በማሰስ «ላቲትዩድ» እና «ሎንጊትዩድ» የሚሉትን ቃላት መኖር ከመጀመሪያው በመነሳት ያጣራል። ሁሉም ኮለምኖች እንደባህርይ መጥተዋል።",
    "Continue line": "መስመሩን ቀጥል",
    "Continue line (Ctrl-click)": "መስመሩን ቀጥል",
    "Coordinates": "ኮርዲኔቶች",
    "Credits": "ክሬዲቶች",
    "Current view instead of default map view?": "ከዲፎልት የካርታ እይታው ፋንታ የአሁኑ እይታ?",
    "Custom background": "የተስተካከለ ጀርባ",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "ዲፎልት ባህርያት",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "ሰርዝ",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "ይህንን ፊቸር ሰርዝ",
    "Delete this property on all the features": "በሁሉም ፊቸሮች ላይ ይህንን ባህርይ ሰርዝ",
    "Delete this shape": "ይህንን ቅርፅ ሰርዝ",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "ከዚህ የሚነሱ አቅጣጫዎች",
    "Disable editing": "ማረም ከልክል ነው",
    "Display measure": "Display measure",
    "Display on load": "በመጫን ላይ እያለ አሳይ",
    "Download": "Download",
    "Download data": "መረጃውን አውርድ",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "መስመር አስምር",
    "Draw a marker": "መለያ ሳል",
    "Draw a polygon": "ፖሊጎን ሳል",
    "Draw a polyline": "ባለነጠላ መስመር ሳል",
    "Dynamic": "ዳይናሚክ",
    "Dynamic properties": "ዳይናሚክ ባህርያት",
    "Edit": "አርም",
    "Edit feature's layer": "የፊቸሩን ሌይር አርም",
    "Edit map properties": "የካርታውን ባህርያት አርም",
    "Edit map settings": "የካርታውን ሁነቶች አርም",
    "Edit properties in a table": "በሰንጠረዡ ውስጥ ያሉትን ባህርያት አርም",
    "Edit this feature": "ይህንን ፊቸር አርም",
    "Editing": "በማረም ላይ",
    "Embed and share this map": "ይህንን ካርታ አካትት እና ሼር አድርግ",
    "Embed the map": "ካርታውን አካትት",
    "Empty": "ባዶ",
    "Enable editing": "እርማትን ፍቀድ",
    "Error in the tilelayer URL": "በታይልሌየሩ የድረ-ገፅ መገኛ ላይ ስህተት ተፈጥሯል",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "ፊቸሩን ለመለየት ቅርፁን ነጥለህ አውጣ",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "አጣራ",
    "Format": "ፎርማት",
    "From zoom": "ከዙም",
    "Full map data": "Full map data",
    "Go to «{feature}»": "ወደ «{feature}» ተመለስ",
    "Heatmap intensity property": "የሙቀት ካርታ ኢንቴንሲቲ ባህርይ",
    "Heatmap radius": "የሙቀት ካርታ ራዲየስ",
    "Help": "እርዳታ",
    "Hide controls": "መቆጣጠሪያዎቹን ደብቅ",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "በእያንዳንዱ የዙም መጠን ፖሊላይኑን ምን ያህል ያቃልል (ብዙ = ጥሩ አገልግሎት እና ጥሩ መልክ፣ ትንሽ = ይበልጥ ትክክለኛ)",
    "If false, the polygon will act as a part of the underlying map.": "ስህተት ከሆነ ፖሊጎኑ ከስር እንደተነጠፈ ካርታ ያገለግላል",
    "Iframe export options": "የፍሬም ኤክስፖርት ምርጫዎች",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "|ፍሬሙ ከተሻሻለ ቁመት ጋር (በፒክሰል)፡ {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "|ፍሬም፡ {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "የተስተካከለ ጉን ያለው ምስል (በፒክስል)፡ {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "ምስል፡{{http://image.url.com}}",
    "Import": "አምጣ",
    "Import data": "መረጃ አምጣ",
    "Import in a new layer": "አዲስ ሌየር አምጣ",
    "Imports all umap data, including layers and settings.": "ሌየር እና ሁኔታዎቹን ጨምሮ ሁሉንም የዩማፕ መረጃ ያመጣል",
    "Include full screen link?": "ሙሉ ስክሪን ሊክን ያካትት?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "ያልተፈቀደ የዩማፕ መረጃ",
    "Invalid umap data in {filename}": "ያልተፈቀደ የዩማፕ መረጃ በ {filename} ውስጥ",
    "Keep current visible layers": "በወቅቱ የሚታየውን ሌየር አቆይ",
    "Latitude": "ላቲትዩድ",
    "Layer": "ሌየር",
    "Layer properties": "የሌየር ባህርያት",
    "Licence": "ፈቃድ",
    "Limit bounds": "መድረሻዎቹን ምረጥ",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "ከዚህ ፅሁፍ ጋር አስተሳስር፡ [[http://example.com|text of the link]]",
    "Long credits": "ክሬዲቶች በመጫን ላይ",
    "Longitude": "ሎንጊትዩድ",
    "Make main shape": "ዋና ቅርፅ አድርግ",
    "Manage layers": "Manage layers",
    "Map background credits": "የካርታ የጀርባ ክሬዲትስ",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "ካርታው ተቀምጧል/ድኗል",
    "Map user content has been published under licence": "የካርታ ይዘት በሚከተለው ፈቃድ አማካኝነት ታትሟል",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "መስመሮችን ቀላቅል",
    "More controls": "ተጨማሪ መቆጣጠሪያዎች",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "ምንም ፈቃድ አልተሰጠም",
    "No results": "No results",
    "Only visible features will be downloaded.": "የሚታዩት ፊቸሮች ብቻ ይወርዳሉ",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "ለOpernStreetMap ይበልጥ ትክክል ይሆነ መረጃ ለመስጠ የካርታውን ኤክስቴንት በካርታ ማረሚያ ክፈት",
    "Optional intensity property for heatmap": "ለሙቀት ካርታው ባህርይ አማራጭ ኢንቴንሲቲ",
    "Optional. Same as color if not set.": "አማራጭ፣ ካልተመረጠለት እንደቀለሙ የሚሆን",
    "Optionnal.": "አማራጭ",
    "Override clustering radius (default 80)": "የራዲየስ ክለስተሪንግ አልፈህ ሂድ (ዲፎልት 80)",
    "Override heatmap radius (default 25)": "የሙቀት ካርታውን ራዲየስ አልፈህ ሂድ (ዲፎልት 25)",
    "Paste here your data": "መረጃውን እዚህ ጋር ለጥፍ",
    "Please be sure the licence is compliant with your use.": "እባክዎ ፈቃዱ እስርዎ ሊጠቀሙ ካሉበት አገልግሎት ጋር መጣጣሙን ያረጋግጡ",
    "Please choose a format": "እባክዎ ፎርማት ይምረጡ",
    "Please enter the name of the property": "እባክዎ የባህርይውን ስም ያስገቡ",
    "Please enter the new name of this property": "እባክዎን አዲሱን የባህርይውን ስም ያስገቡ",
    "Please save the map before": "እባክዎን ካርታውን በመጀመሪያ ያድኑ/ያስቀምጡ",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "በ <a href=\"{leaflet}\">ሊፍሌት</a> እየታገዘ በ<a href=\"{django}\"> ጃንጎ</a> ታግዞ በ<a href=\"{umap}\"> uMap ፕሮጀክት</a> አማካኝነት የቀረበ",
    "Problem in the response": "በምላሹ ላይ ችግር ተፈጥሯል",
    "Problem in the response format": "በምላሹ ፎርማት ላይ ችግር ተፈጥሯል",
    "Properties imported:": "ባህርያት መጥተዋል",
    "Property to use for sorting features": "ፊችሮችን ለመደርደር የሚጥቀምበት ባህርይ",
    "Provide an URL here": "የድረገፁን መገኛ አድራሻ ያስገቡ",
    "Proxy request": "የፕሮክሲ ጥያቄ",
    "Remote data": "ሪሞት ዳታ",
    "Remove shape from the multi": "ከብዝሀው ላይ ቅርፁን አስወግድ",
    "Rename this property on all the features": "በሁሉም ፊቸሮች ይህንን ያባህርይ መጠሪያ ያሻሽሉ",
    "Replace layer content": "Replace layer content",
    "Restore this version": "ይህንን እትም መልስ",
    "Save": "አድን/አስቀምጥ",
    "Save anyway": "ለማንኛውም አስቀምጥ/አድን",
    "Save current edits": "የአሁኑን እርማቶች አስቀምጥ/አድን",
    "Save this center and zoom": "ይህንን ዙም እና መሀከል አስቀምጥ/አድን",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "ሁሉንም ተመልከት",
    "See data layers": "See data layers",
    "See full screen": "ሙሉውን ስክሪን ተመልከት",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "አጭር የድረ-ገፅ መገኛ",
    "Short credits": "አጭር ክሬዲት",
    "Show/hide layer": "ሌየሩን አሳይ/ደብቅ",
    "Simple link: [[http://example.com]]": "ቀላል መገኛ: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "ያልታወቁ ጂኦሜትሪዎችን በማለፍ ላይ።አይነት ፡{TYPE}",
    "Slideshow": "ስላይድሾው",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "መስመሩን ክፈል",
    "Start a hole here": "እዚህ ጋር ቀዳዳ ጀምር",
    "Start editing": "ማረም ጀምር",
    "Start slideshow": "ስላይድሾውን አስጀምር",
    "Stop editing": "ማረም አቁም",
    "Stop slideshow": "ስላይድሾውን አስቁም",
    "Supported scheme": "የሚደገፉ ስኪሞች",
    "Supported variables that will be dynamically replaced": "ዳይናሚካሊ የሚቀየሩ የሚደገፉ ቫርያብሎች",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "ቲ.ኤም.ኤስ. ፎርማት",
    "Text color for the cluster label": "የክላስተሩን ሌብ ፅሑፍ ከለር",
    "Text formatting": "ፅሁፍ ማስተካከያ",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "ዙሙ እና መሀከሉ ተወስነዋል",
    "To use if remote server doesn't allow cross domain (slower)": "ሪሞት ሰርቨሩ የዶሜይን ልውውጥን የማይፈቅድ ከሆነ ይህን ለመጠቀም (አዝጋሚ)",
    "To zoom": "ለማጉላት",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "ቅርፁን ወደ ታረመ ፊቸር አስተላልፍ",
    "Transform to lines": "ወደመስመር ቀይር",
    "Transform to polygon": "ወደፖሊጎን ቀይር",
    "Type of layer": "የሌየሩ ዓይነት",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "ያልተሰየመ ሌየር",
    "Untitled map": "ያለተሰየመ ካርታ",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "ፍቃዶችን እና አራሚዎችን አሻሽል",
    "Url": "የድረ-ገፅ መገኛ",
    "Use current bounds": "የአሁንኖቹን መደረሻዎች ተጠቀም",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "በቅንፎች መሀከል የፊቸር ባህርያት ያላቸው ቦታያዦችን ተጠቀም፣ ለምሳሌ &#123;name&#125; ዳይናሚካሊ በተቀራራቢ ዋጋችወ ይተካሉ",
    "User content credits": "የይዘቱን ክሬዲቶች ተጠቀም",
    "User interface options": "የኢንተርፌስ ምርጫዎች",
    "Versions": "እትሞች",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "ከዚህ ቀጥሎ ወደየት ነው የምንሄደው?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "ከታች በቀኝ ኮርነሩ ላይ ይታያል",
    "Will be visible in the caption of the map": "በካርታው ካፕሽን ላይ እንዲታይ ይደረጋል",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "ውይ! ሌላ ሰው መረጃውን ሳያርመው አይቀርም። ለማንኛውም ማዳን/ማስቀመጥ ይቻላል፣ ነገር ግን የሌሎች እርማቶች ይሰረዛሉ",
    "You have unsaved changes.": "ያልዳኑ/ያልተቀመጡ ለውጦች አሉ",
    "Zoom in": "አጉላ",
    "Zoom level for automatic zooms": "አውቶማቲክ ዙሞች የሚጎሉበት መጠን",
    "Zoom out": "አርቅ",
    "Zoom to layer extent": "የሌየሩ ኤክስቴንት ድረስ አጉላ",
    "Zoom to the next": "ወደ ሚቀጥለው አጉላ",
    "Zoom to the previous": "ቀደም ወዳለው አጉላ",
    "Zoom to this feature": "ፊቸሩ ድረስ አጉላ",
    "Zoom to this place": "Zoom to this place",
    "attribution": "አትሪብዩሽን",
    "by": "በ",
    "display name": "ስሙን አሳይ",
    "height": "ቁመት",
    "licence": "ፈቃድ",
    "max East": "በምስራቅ ከፍተናው",
    "max North": "በደቡብ ከፍተኛው",
    "max South": "በሰሜን ከፍተኛው",
    "max West": "በምዕራብ ከፍተኛው",
    "max zoom": "የመጨረሻው ዙም",
    "min zoom": "ትንሹ ዙም",
    "next": "ቀጥሎ",
    "previous": "ቀድሞ",
    "width": "ጎን",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("am_ET", locale);
L.setLocale("am_ET");