var locale = {
    "Add symbol": "Pridėti simbolį",
    "Allow scroll wheel zoom?": "Leisti pelės ratuko veiksmus?",
    "Automatic": "Automatic",
    "Ball": "Rutulys",
    "Cancel": "Atšaukti",
    "Caption": "Antraštė",
    "Change symbol": "Pakeisti simbolį",
    "Choose the data format": "Pasirinkite duomenų formatą",
    "Choose the layer of the feature": "Pasirinkite objekto sluoksnį",
    "Circle": "Apskritimas",
    "Clustered": "Sugrupuota",
    "Data browser": "Duomenų naršyklė",
    "Default": "Pagal nutylėjimą",
    "Default zoom level": "Default zoom level",
    "Default: name": "Pagal nutylėjimą: name",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Ar norite rodyti antraštę?",
    "Do you want to display a minimap?": "Ar norite rodyti mini žemėlapį?",
    "Do you want to display a panel on load?": "Ar norite rodyti panelę kraunantis?",
    "Do you want to display popup footer?": "Ar norite rodyti iškylančio lango paraštę?",
    "Do you want to display the scale control?": "Ar norite rodyti žemėlapio skalės valdymą?",
    "Do you want to display the «more» control?": "Ar norite rodyti nuorodą \"daugiau\"?",
    "Drop": "Atmesti",
    "GeoRSS (only link)": "GeoRSS (tik nuoroda)",
    "GeoRSS (title + image)": "GeoRSS (pavadinimas + paveikslas)",
    "Heatmap": "Tankio žemėlapis",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Paveldėti",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Nieko",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup'o turinio šablonas",
    "Set symbol": "Set symbol",
    "Side panel": "Šoninis skydelis",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Lentelė",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "spalva",
    "dash array": "brūkšnių masyvas",
    "define": "define",
    "description": "aprašymas",
    "expanded": "expanded",
    "fill": "užpildyti",
    "fill color": "ploto spalva",
    "fill opacity": "ploto skaidrumas",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "paveldėti",
    "name": "vardas",
    "never": "never",
    "new window": "new window",
    "no": "ne",
    "on hover": "on hover",
    "opacity": "nepermatomumas",
    "parent window": "parent window",
    "stroke": "brūkšnys",
    "weight": "svoris",
    "yes": "taip",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# viena grotelė pagrindinei antraštei",
    "## two hashes for second heading": "## dvi grotelės antraštei",
    "### three hashes for third heading": "### trys grotelės trečio lygio pastraipai",
    "**double star for bold**": "**dviguba žvaigždutė paryškintam tekstui**",
    "*simple star for italic*": "*viena žvaigždutė pasvyriajam tekstui*",
    "--- for an horizontal rule": "--- horizontaliai linijai",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Apie",
    "Action not allowed :(": "Veiksmas nėra leidžiamas :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Pridėti sluoksnį",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Pridėti naują savybę",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Sudėtingesni veiksmai",
    "Advanced properties": "Sudėtingesni nustatymai",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Visi objektai importuoti.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Įvyko klaida",
    "Are you sure you want to cancel your changes?": "Ar tikrai nori atšaukti savo pakeitimus?",
    "Are you sure you want to clone this map and all its datalayers?": "Ar tikrai norite nukopijuoti šį žemėlapį ir visus jo duomenų sluoksnius?",
    "Are you sure you want to delete the feature?": "Ar tikrai norite ištrinti šį objektą?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Ar Jūs tikrai norite ištrinti šį žemėlapį?",
    "Are you sure you want to delete this property on all the features?": "Ar tikrai norite pašalinti šią savybę visiem objektams?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Automatiškai",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Pastumti objektą į centrą",
    "Browse data": "Peržiūrėti duomenis",
    "Cancel edits": "Atšaukti pakeitimus",
    "Center map on your location": "Centruoti pagal Jūsų vietovę",
    "Change map background": "Keisti žemėlapio foną",
    "Change tilelayers": "Pakeisti sluoksnius",
    "Choose a preset": "Pasirinkite šabloną",
    "Choose the format of the data to import": "Pasirinkite importuojamų uomenų formatą",
    "Choose the layer to import in": "Pasirinkite sluoksnį importavimui",
    "Click last point to finish shape": "Paspauskite ant paskutinio taško kad baigti piešimą",
    "Click to add a marker": "Paspauskite kad pridėti žymeklį",
    "Click to continue drawing": "Paspauskite kad tęsti piešimą",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Paspauskite ir pradėsite piešti liniją",
    "Click to start drawing a polygon": "Paspauskite ir pradėsite priešti poligoną",
    "Clone": "Kopijuoti",
    "Clone of {name}": "{name} kopija",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Klonuoti šį žemėlapį",
    "Close": "Uždaryti",
    "Clustering radius": "Grupavimo spindulys",
    "Comma separated list of properties to use when filtering features": "Kableliu atskirtas savybių sąrašas naudojamas objektų filtrui",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Kableliu, tab'u arba kabliataškiu atskirtos reikšmės. SRS WGS84 yra palaikomas. Tik taškai yra importuoti. Importuojant bus patikrintos stulpelių antraštės ieškant pavadinimų \"lat\" ir \"lon\". Visi kiti stulpeliai bus įtraukti kaip papildomi atributai.",
    "Continue line": "Continue line",
    "Continue line (Ctrl-click)": "Tęsti liniją (Ctrl klavišas)",
    "Coordinates": "Koordinatės",
    "Credits": "Apie kūrėjus",
    "Current view instead of default map view?": "Naudoti esamą vaizdą vietoje standartinio?",
    "Custom background": "Pritaikytas fonas",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Nustatymai pagal nutylėjimą",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Trinti",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Ištrinti šį objektą",
    "Delete this property on all the features": "Pašalinti šį parametrą visuose objektuose",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Nuorodos iš šio taško",
    "Disable editing": "Uždrausti redagavimą",
    "Display measure": "Display measure",
    "Display on load": "Rodyti pasikrovus",
    "Download": "Download",
    "Download data": "Atsisiųsti duomenis",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Piešti liniją",
    "Draw a marker": "Padėti žymeklį",
    "Draw a polygon": "Piešti poligoną",
    "Draw a polyline": "Piešti linijas",
    "Dynamic": "Dinaminis",
    "Dynamic properties": "Dinaminės savybės",
    "Edit": "Redaguoti",
    "Edit feature's layer": "Redaguoti objekto sluoksnį",
    "Edit map properties": "Keisti žemėlapio nustatymus",
    "Edit map settings": "Keisti žemėlapio nustatymus",
    "Edit properties in a table": "Redaguoti savybes lentelėje",
    "Edit this feature": "Redaguoti šį objektą",
    "Editing": "Redaguojama",
    "Embed and share this map": "Įkelti ir dalintis šiuo žemėlapiu",
    "Embed the map": "Įsikelti šį žemėlapį",
    "Empty": "Tuščias",
    "Enable editing": "Leisti redaguoti",
    "Error in the tilelayer URL": "Klaida tile-sluoksnio URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filtruoti...",
    "Format": "Formatas",
    "From zoom": "Mažiausias mastelis",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Eiti į «{feature}»",
    "Heatmap intensity property": "Tankio žemėlpaio faktorius",
    "Heatmap radius": "Tankio žemėlapio spindulys",
    "Help": "Pagalba",
    "Hide controls": "Slėpti mygtukus",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Kaip stipriai supaprastinti linijas kiekviename mastelyje (daugiau - diesnis greitis ir lygesnis vaizdas, mažiau - tikslesnis atvaizdavimas)",
    "If false, the polygon will act as a part of the underlying map.": "Jei false, poligonas bus pagrindinio žemėlapio dalis.",
    "Iframe export options": "Iframe export nustatymai",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe su nurodytu aukščiu (pikseliais):  {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Paveikslo plotis (pikseliais): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Paveikslas: {{http://image.url.com/image.jpeg}}",
    "Import": "Importuoti",
    "Import data": "Importuoti duomenis",
    "Import in a new layer": "Importuoti naują sluoksnį",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Įtraukti nuorodą į viso ekrano vaizdą?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Esamus sluoksnius palikti matomais",
    "Latitude": "Platuma",
    "Layer": "Sluoksnis",
    "Layer properties": "Layer properties",
    "Licence": "Licenzija",
    "Limit bounds": "Nustatyti ribas",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Nuoroda tekstui:: [[http://example.com|nuorodos tekstas]]",
    "Long credits": "Apie kūrėjus",
    "Longitude": "Ilguma",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Žemėlapio fono naudojimo sąlygos",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Žemėlapis išsaugotas!",
    "Map user content has been published under licence": "Vartotojo turinys buvo publikuotas pagal licenziją",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "Daugiau valdymo mygtukų",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Nenustatyta licenzija",
    "No results": "No results",
    "Only visible features will be downloaded.": "Tik matomi objektai bus atsiųsti.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Atidaryti šį plotą duomenų redagavimui per OpenStreetMap",
    "Optional intensity property for heatmap": "Papildomas intensyvumo faktorius",
    "Optional. Same as color if not set.": "Neprivalomas. Toks pats kaip ir spalva, jei nenustatyta.",
    "Optionnal.": "Neprivalomas.",
    "Override clustering radius (default 80)": "Perrašyti grupavimo spindulį (pagal nutylėjimą 80)",
    "Override heatmap radius (default 25)": "Perrašyti tankio žemėlapio spindulį (pagal nutylėjimą 25)",
    "Paste here your data": "Įklijuokite Jūsų duomenis čia",
    "Please be sure the licence is compliant with your use.": "Prašom pasitikrinti ar licezija tikrai tinka Jūsų poreikiams.",
    "Please choose a format": "Pasirinkite formatą",
    "Please enter the name of the property": "Įveskite, prašom, savybės pavadinimą",
    "Please enter the new name of this property": "Įveskite, prašom, naują savybės pavadinimą",
    "Please save the map before": "Prašom išsaugoti žemėlapį prieš",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Pagaminta naudojant <a href=\"{leaflet}\">Leaflet</a> ir <a href=\"{django}\">Django</a>, apjungta pagal <a href=\"{umap}\">uMap projektą</a>.",
    "Problem in the response": "Klaida atsakyme",
    "Problem in the response format": "Klaida atsakymo formate",
    "Properties imported:": "Importuoti objektai:",
    "Property to use for sorting features": "Savybės pavadinimas rūšiavimui",
    "Provide an URL here": "Įvęskite adresą",
    "Proxy request": "Proxy užklausa",
    "Remote data": "Išoriniai duomenys",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Pervadinti šią savybę visuose objektuose",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Išsaugoti",
    "Save anyway": "Išsaugoti bet kuriuo atveju",
    "Save current edits": "Išsaugoti pakeitimus",
    "Save this center and zoom": "Išsaugoti šį centrą ar mastelį.",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Išsaugoti viską",
    "See data layers": "See data layers",
    "See full screen": "Peržiūrėti per visą ekraną",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Trumpas URL",
    "Short credits": "Trumpai apie kūrėjus",
    "Show/hide layer": "Rodyti/slėpti sluoksnį",
    "Simple link: [[http://example.com]]": "Paprasta nuoroda: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Praleidžiamas nežinomas geometrijos tipas: {type}",
    "Slideshow": "Peržiūra",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Padalinti liniją",
    "Start a hole here": "Piešti skylę čia",
    "Start editing": "Pradėti redagavimą",
    "Start slideshow": "Pradėti peržiūrą",
    "Stop editing": "Baigti redagavimą",
    "Stop slideshow": "Stabdyti peržiūrą",
    "Supported scheme": "Palaikoma struktūra",
    "Supported variables that will be dynamically replaced": "Palaikomi kintamieji bus automatiškai perrašyti",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS formatas",
    "Text color for the cluster label": "Teksto spalva klasterio pavadinimui",
    "Text formatting": "Teksto formatavimas",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Šis mastelis ir centras išsaugoti.",
    "To use if remote server doesn't allow cross domain (slower)": "Naudoti jei serveris neleidžia cross domain užklausų (lėtesnis sprendimas)",
    "To zoom": "Padidinti",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transformuoti į linijas",
    "Transform to polygon": "Transformuoti į poligoną",
    "Type of layer": "Sluoksnio tipas",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Bevardis sluoksnis",
    "Untitled map": "Be pavadinimo",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Atnaujinti leidimus ir redaguotojus",
    "Url": "Url",
    "Use current bounds": "Naudoti dabartines ribas",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Objekto savybės tarp laužtinių skliaustų, pvz. &#123;name&#125;, bus automatiškai pakeisto atitinkamomis reikšmėmis.",
    "User content credits": "Vartotojo duomenų sąlygos",
    "User interface options": "Vartotojo sąsajos nustatymai",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Kur norite eiti iš čia?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Bus rodomas apatiniame dešiniame žemėlapio kampe",
    "Will be visible in the caption of the map": "Bus matoma žemėlapio antraštėje",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Dėmesio! Kažkas kitas jau paredagavo šiuos duomenis. Jūs galite išsaugoti, bet tuomet bus prarasti kiti pakeitimai.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Padidinti mastelį",
    "Zoom level for automatic zooms": "Priartinimo lygis automatiniui režimui",
    "Zoom out": "Didinti",
    "Zoom to layer extent": "Išdidinti iki sluoksnio ribų",
    "Zoom to the next": "Priartinti sekantį",
    "Zoom to the previous": "Priartinti ankstesnį",
    "Zoom to this feature": "Išdidinti šį objektą",
    "Zoom to this place": "Zoom to this place",
    "attribution": "atributai",
    "by": "pagal",
    "display name": "rodyti pavadinimą",
    "height": "aukštis",
    "licence": "licenzija",
    "max East": "max Rytų",
    "max North": "max Šiaurės",
    "max South": "max Pietų",
    "max West": "max Vakarų",
    "max zoom": "didžiausias mastelis",
    "min zoom": "mažiausias mastelis",
    "next": "next",
    "previous": "previous",
    "width": "plotis",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("lt", locale);
L.setLocale("lt");