"Create maps with OpenStreetMap layers in a minute and embed them in your site."
VERSION = (1, 0, 0, 'rc', 5)

__author__ = 'Yohan Boniface'
__contact__ = "ybon@openstreetmap.fr"
__homepage__ = "https://github.com/umap-project/umap"
__version__ = ".".join(map(str, VERSION))
