{% extends "umap/content.html" %}

{% load umap_tags i18n %}

{% block maincontent %}
{% if DEMO_SITE %}
<div class="wrapper demo-instance-warning">
  <div class="row">
    {% blocktrans with repo_url="https://github.com/umap-project/umap" stable_url="http://umap.openstreetmap.fr" %}This is a demo instance, used for tests and pre-rolling releases. If you need a stable instance, please use <a href="{{ stable_url }}">{{ stable_url }}</a>. You can also host your own instance, it's <a href="{{ repo_url }}">open source</a>!{% endblocktrans %}
  </div>
</div>
{% endif %}
{% include "umap/search_bar.html" %}
{% include "umap/about_summary.html" %}
{% if showcase_map %}
  <div class="wrapper showcase-map">
    <h2 class="section">{% blocktrans %}Map of the uMaps{% endblocktrans %}</h2>
    <div class="row">
      {% map_fragment showcase_map zoomControl=1 %}
    </div>
  </div>
{% endif %}
<div class="wrapper">
  <h2 class="section">{% blocktrans %}Get inspired, browse maps{% endblocktrans %}</h2>
  <div class="map_list row">
    {% include "umap/map_list.html" %}
  </div>
</div>

{% endblock maincontent %}
