var locale = {
    "Add symbol": "Lisää symboli",
    "Allow scroll wheel zoom?": "Salli zoomaus hiiren rullalla?",
    "Automatic": "Automaattinen",
    "Ball": "Pallo",
    "Cancel": "Peruuta",
    "Caption": "Kuvateksti",
    "Change symbol": "Vaihda symboli",
    "Choose the data format": "Valitse päivämäärän muoto",
    "Choose the layer of the feature": "Valitse piirteen kerros",
    "Circle": "Ympyrä",
    "Clustered": "Klusteroituna",
    "Data browser": "Dataselain",
    "Default": "Oletusarvo",
    "Default zoom level": "Default zoom level",
    "Default: name": "Oletus: nimi",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Haluatko näyttää otsikkopalkin?",
    "Do you want to display a minimap?": "Haluatko aktivoida minikartan?",
    "Do you want to display a panel on load?": "Haluatko näyttää paneelin ladattaessa?",
    "Do you want to display popup footer?": "Haluatko näyttää ponnahdusikkunan alatunnisteen?",
    "Do you want to display the scale control?": "Näytetäänkö mittakaavaohjain?",
    "Do you want to display the «more» control?": "Haluatko näyttää «lisää»-ohjaimen?",
    "Drop": "Pisara",
    "GeoRSS (only link)": "GeoRSS (vain linkki)",
    "GeoRSS (title + image)": "GeoRSS (otsikko + kuva)",
    "Heatmap": "Lämpökartta",
    "Icon shape": "Ikonin muoto",
    "Icon symbol": "Ikonin symboli",
    "Inherit": "Peri",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Ei mitään",
    "On the bottom": "Alhaalla",
    "On the left": "Vasemmalla",
    "On the right": "Oikealla",
    "On the top": "Ylhäällä",
    "Popup content template": "Ponnahdusikkunan sisällön sapluuna",
    "Set symbol": "Set symbol",
    "Side panel": "Sivupaneeli",
    "Simplify": "Yksinkertaista",
    "Symbol or url": "Symbol or url",
    "Table": "Taulukko",
    "always": "aina",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "väri",
    "dash array": "katkoviivatyyppilista",
    "define": "määritä",
    "description": "kuvaus",
    "expanded": "laajennettu",
    "fill": "täyttö",
    "fill color": "täyteväri",
    "fill opacity": "täytön läpinäkyvyys",
    "hidden": "piilotettu",
    "iframe": "iframe",
    "inherit": "peri",
    "name": "nimi",
    "never": "ei koskaan",
    "new window": "uusi ikkuna",
    "no": "ei",
    "on hover": "on hover",
    "opacity": "läpikuultavuus",
    "parent window": "parent window",
    "stroke": "sivallus",
    "weight": "paksuus",
    "yes": "kyllä",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# yksi risuaita tekee päätason otsikon",
    "## two hashes for second heading": "## kaksi risuaitaa tekee kakkostason otsikon",
    "### three hashes for third heading": "### kolme risuaitaa tekee kolmostason otsikon",
    "**double star for bold**": "**tuplatähti lihavoi**",
    "*simple star for italic*": "*yksi tähti kursivoi*",
    "--- for an horizontal rule": "--- luo vaakasuoran erottimen kuplan halki",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Tietoja",
    "Action not allowed :(": "Toimenpide ei ole sallittu :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Lisää kerros",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Lisää uusi ominaisuus",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Lisätoiminnot",
    "Advanced properties": "Lisäominaisuudet",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Kaikki omainaisuudet tuodaan.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Hups! Virhe on tapahtunut...",
    "Are you sure you want to cancel your changes?": "Oletko _ihan_ varma, että haluat peruuttaa muutoksesi?",
    "Are you sure you want to clone this map and all its datalayers?": "Oletko varma että haluat kloonata tämän kartan ja kaikki sen data-kerrokset?",
    "Are you sure you want to delete the feature?": "Oletko varma että haluat poistaa piirteen?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Oletko ihan täysin varma, että haluat poistaa tämän kartan? Poistettua karttaa ei voi palauttaa.",
    "Are you sure you want to delete this property on all the features?": "Oletko varma että haluat poistaa tämän ominaisuuden kaikista piirteistä?",
    "Are you sure you want to restore this version?": "Oletko varma että haluat palauttaa tämän version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Automaattinen",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Tuo piirre keskelle",
    "Browse data": "Selaa tietoja",
    "Cancel edits": "Peruuta muokkaukset",
    "Center map on your location": "Keskitä kartta sijaintiisi",
    "Change map background": "Vaihda taustakarttaa",
    "Change tilelayers": "Muuta karttavaihtoehtoja",
    "Choose a preset": "Valitse",
    "Choose the format of the data to import": "Valitse tuotavien tietojen formaatti",
    "Choose the layer to import in": "Valitse kerros johon tieto tuodaan",
    "Click last point to finish shape": "Klikkaa viimeistä pistettä täydentääksesi muodon",
    "Click to add a marker": "Klikkaa lisätäksesi karttamerkki",
    "Click to continue drawing": "Klikkaa jatkaaksesi piirtämistä",
    "Click to edit": "Klikkaa muokataksesi",
    "Click to start drawing a line": "Klikkaa aloittaaksesi viivan piirtäminen",
    "Click to start drawing a polygon": "Klikkaa aloittaaksesi monikulmion piirtäminen",
    "Clone": "Kloonaa",
    "Clone of {name}": "{name}n klooni",
    "Clone this feature": "Kloonaa tämä piirre",
    "Clone this map": "Kloonaa tämä kartta",
    "Close": "Sulje",
    "Clustering radius": "Klusterointisäde",
    "Comma separated list of properties to use when filtering features": "Pilkkueroteltu lista käytettävistä ominaisuuksista piirteitä suodatettaessa.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Pilkku-, tabulaattori- tai puolipiste-erotettuja arvoja. Koordinaattijärjestemänä WGS84. Vain pistegeometriat tuodaan uMapiin. Tietue-tuonti etsii «lat»- ja «lon»-alkavia sarakeotsikoita. Kaikki muut sarakkeet tuodaan ominaisuustietoina.",
    "Continue line": "Jatka viivaa",
    "Continue line (Ctrl-click)": "Jatka viivaa (Ctrl+Klikkaus)",
    "Coordinates": "Koordinaatit",
    "Credits": "Tunnustukset",
    "Current view instead of default map view?": "Nykyinen näkymä oletuskarttanäkymän asemesta?",
    "Custom background": "Räätälöity tausta",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Oletusasetukset",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Poista",
    "Delete all layers": "Poista kaikki kerrokset",
    "Delete layer": "Poista kerros",
    "Delete this feature": "Poista tämä piirre",
    "Delete this property on all the features": "Poista tämä ominaisuus kaikista piirteistä",
    "Delete this shape": "Poista tämä muoto",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Ohjeet täältä",
    "Disable editing": "Lopeta kartan muokaaminen",
    "Display measure": "Display measure",
    "Display on load": "Näytä ladattaessa",
    "Download": "Download",
    "Download data": "Lataa tietoja",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Piirrä viiva",
    "Draw a marker": "Piirrä karttamerkki",
    "Draw a polygon": "Piirrä monikulmio",
    "Draw a polyline": "Piirrä monisegmenttinen viiva",
    "Dynamic": "Dynaaminen",
    "Dynamic properties": "Dynaamiset ominaisuudet",
    "Edit": "Muokkaa",
    "Edit feature's layer": "Muokkaa piirteen kerrosta",
    "Edit map properties": "Muokkaa kartan ominaisuuksia",
    "Edit map settings": "Muokkaa kartta-asetuksia",
    "Edit properties in a table": "Muokkaa ominaisuuksia taulukossa",
    "Edit this feature": "Muokkaa tätä piirrettä",
    "Editing": "Muokkauksessa",
    "Embed and share this map": "Jaa tämä kartta tai käytä sitä muualla",
    "Embed the map": "Liitä kartta",
    "Empty": "Tyhjä",
    "Enable editing": "Aktivoi kartan muokkaus",
    "Error in the tilelayer URL": "Virhe karttalaattojen URL:ssä",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Irroita muoto erilliseksi piirteeksi.",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Suodata...",
    "Format": "Formaatti",
    "From zoom": "Zoomaustasolta",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Mene piirteeseen «{feature}»",
    "Heatmap intensity property": "Lämpökartan vahvuusominaisuus",
    "Heatmap radius": "Lämpökartan säde",
    "Help": "Apua",
    "Hide controls": "Piilota ohjaimet",
    "Home": "Alku",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Kuinka paljon viivaa yleistetäänkullakin zoomaustasolla (enemmän = parempi suorituskyky, vähemmän = suurempi tarkkuus)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe-vientiasetukset",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe määrätyn korkuisena (pikseleinä): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Kuva määrätyn leveyisenä (pikseleinä): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Kuva: {{http://kuva.url.com}}",
    "Import": "Tuo",
    "Import data": "Tuo tietoja",
    "Import in a new layer": "Tuo uuteen kerrokseen",
    "Imports all umap data, including layers and settings.": "Tuo kaikki karttatiedot, mukaan lukien datatasot ja asetukset.",
    "Include full screen link?": "Sisällytä koko näyttö -linkki?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Virheellistä uMap-dataa",
    "Invalid umap data in {filename}": "Virheellistä uMap-dataa {filename}:ssa",
    "Keep current visible layers": "Pidä nyt näkyvät datakerrokset",
    "Latitude": "Leveysaste",
    "Layer": "Kerros",
    "Layer properties": "Datakerroksen ominaisuudet",
    "Licence": "Lisenssi",
    "Limit bounds": "Alueen rajaus",
    "Link to…": "Linkitä kohteeseen...",
    "Link with text: [[http://example.com|text of the link]]": "Hyperlinkki tekstillä: [[http://esimerkkisaitti.fi|linkin teksti]]",
    "Long credits": "Pitkät tekijätiedot",
    "Longitude": "Pituusaste",
    "Make main shape": "Luo päämuoto",
    "Manage layers": "Hallitse kerroksia",
    "Map background credits": "Taustakartan tekijämerkinnät",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Kartta on tallennettu!",
    "Map user content has been published under licence": "Kartan käyttäjien luomat tiedot on julkaistu lisenssillä",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Yhdistä rivit",
    "More controls": "Lisää ohjaimia",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Lisenssiä ei ole määritetty",
    "No results": "Ei tuloksia",
    "Only visible features will be downloaded.": "Vain näkyvät piirteet ladataan.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Avaa rajauksen mukainen alue editorissa parantaaksesi OpenStreetMapin tietosisältöä.",
    "Optional intensity property for heatmap": "Valinnainen lämpökartan vahvuusominaisuus",
    "Optional. Same as color if not set.": "Valinnainen. Sama kuin väri jos ei asetettu.",
    "Optionnal.": "Valinnainen.",
    "Override clustering radius (default 80)": "Ohita klusterointisäde (oletus on 80)",
    "Override heatmap radius (default 25)": "Ohita lämpökartan säde (oletus on 25)",
    "Paste here your data": "Liitä tiedot tähän",
    "Please be sure the licence is compliant with your use.": "Huomioithan että valitsemasi lisenssi on yhteensopiva käyttösi kanssa.",
    "Please choose a format": "Valitse formaatti",
    "Please enter the name of the property": "Kirjoita ominaisuuden nimi",
    "Please enter the new name of this property": "Kirjoita ominaisuuden uusi nimi",
    "Please save the map before": "Ole hyvä ja tallenna kartta ensin",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Konepellin alla hyrrää <a href=\"{leaflet}\">Leaflet</a> ja <a href=\"{django}\">Django</a>; <a href=\"{umap}\">uMap-projektin</a> kasaan liimaamana.",
    "Problem in the response": "Ongelma vastauksessa",
    "Problem in the response format": "Ongelma vastauksen muodossa",
    "Properties imported:": "Tuodut ominaisuudet:",
    "Property to use for sorting features": "Ominaisuus jonka mukaan piirteet järjestetään",
    "Provide an URL here": "Syötä verkko-osoite tänne",
    "Proxy request": "Välityspalvelinpyyntö",
    "Remote data": "Etä-tiedot",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Uudelleen nimeä tämä ominaisuus kaikissa piirteissä",
    "Replace layer content": "Korvaa kerroksen sisältö",
    "Restore this version": "Palauta tämä versio",
    "Save": "Tallenna",
    "Save anyway": "Tallenna joka tapauksessa",
    "Save current edits": "Tallenna tämänhetkiset muokkaukset",
    "Save this center and zoom": "Tallenna tämä kartan keskitys ja zoomaustaso",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Näytä kaikki",
    "See data layers": "See data layers",
    "See full screen": "Katso koko näytöllä",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Piirteen ominaisuudet",
    "Short URL": "Lyhyt URL",
    "Short credits": "Lyhyet tekijätiedot",
    "Show/hide layer": "Näytä/piilota kerros",
    "Simple link: [[http://example.com]]": "Yksinkertainen linkki: [[http://esimerkki.fi]]",
    "Skipping unkown geometry.type: {type}": "Ohitetaan tuntematon geometry.type: {type}",
    "Slideshow": "Kuvaesitys",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Pilko/katkaise viiva",
    "Start a hole here": "Aloita reikä tässä",
    "Start editing": "Aloita muokkaus",
    "Start slideshow": "Aloita kuvaesitys",
    "Stop editing": "Lopeta muokkaus",
    "Stop slideshow": "Lopeta kuvaesitys",
    "Supported scheme": "Tuettu muoto",
    "Supported variables that will be dynamically replaced": "Tuetut muuttujat, jotka korvataan dynaamisesti",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS-formaatti",
    "Text color for the cluster label": "Tekstin väri klusterietiketissä",
    "Text formatting": "Tekstin muotoilu",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Kartan keskitys ja zoomaustaso on asetettu.",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Zoomaukseen",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Siirrä muoto muokatuksi piirteeksi.",
    "Transform to lines": "Muunna viivoiksi",
    "Transform to polygon": "Muunna monikulmioksi",
    "Type of layer": "Datakerroksen tyyppi",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Nimeämätön kerros",
    "Untitled map": "Nimeämätön kartta",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Päivitä oikeudet ja editori",
    "Url": "URL",
    "Use current bounds": "Käytä nykyistä rajausta",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Käyttäjien luoman tiedon tuottajat:",
    "User interface options": "Käyttäjän käyttöliittymäoptiot",
    "Versions": "Versiot",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Minnekäs sitten?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Näytetään kartan oikeassa alakulmassa",
    "Will be visible in the caption of the map": "Näytetään kartan kuvatekstinä",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Hupsankeikkaa! Joku muu on näemmä muokannut tietoja. Voit tallentaa joka tapauksessa, mutta tallentamisesi poistaa muiden muokkaukset.",
    "You have unsaved changes.": "Sinulla on tallentamattomia muutoksia.",
    "Zoom in": "Lähennä",
    "Zoom level for automatic zooms": "Zoomaustaso automaattisessa zoomauksessa",
    "Zoom out": "Loitonna",
    "Zoom to layer extent": "Zoomaa tason laajuuteen",
    "Zoom to the next": "Kohdenna seuraavaan",
    "Zoom to the previous": "Kohdenna edelliseen",
    "Zoom to this feature": "Kohdenna tähän piirteeseen",
    "Zoom to this place": "Kohdenna tähän paikkaan",
    "attribution": "Viittaukset tausta-aineiston lisenssiin",
    "by": "taholta",
    "display name": "näytettävä nimi",
    "height": "korkeus",
    "licence": "lisenssi",
    "max East": "itäraja",
    "max North": "pohjoisraja",
    "max South": "eteläraja",
    "max West": "länsiraja",
    "max zoom": "suurin zoomaustaso",
    "min zoom": "pienin zoomaustaso",
    "next": "seuraava",
    "previous": "edellinen",
    "width": "leveys",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("fi", locale);
L.setLocale("fi");