var locale = {
    "Add symbol": "Додати зображення",
    "Allow scroll wheel zoom?": "Дозволити зміну масштабу колесом миші?",
    "Automatic": "Automatic",
    "Ball": "Шпилька",
    "Cancel": "Скасувати",
    "Caption": "Заголовок",
    "Change symbol": "Змінити зображення",
    "Choose the data format": "Виберіть формат даних",
    "Choose the layer of the feature": "Виберіть шар для об’єкта",
    "Circle": "Коло",
    "Clustered": "Кластеризованний",
    "Data browser": "Оглядач даних",
    "Default": "За умовчанням",
    "Default zoom level": "Default zoom level",
    "Default: name": "За умовчанням: назва",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Показувати рядок заголовку?",
    "Do you want to display a minimap?": "Показувати мінімапу?",
    "Do you want to display a panel on load?": "Показувати панель керування при завантаженні?",
    "Do you want to display popup footer?": "Хочете використовувати спливаючу підказку знизу?",
    "Do you want to display the scale control?": "Показувати шкалу відстаней?",
    "Do you want to display the «more» control?": "Показувати кнопку „Більше“?",
    "Drop": "Крапля",
    "GeoRSS (only link)": "GeoRSS (лише посилання)",
    "GeoRSS (title + image)": "GeoRSS (заголовок та зображення)",
    "Heatmap": "Теплова мапа",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Успадковувати",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Ні",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Шаблон спливаючої підказки",
    "Set symbol": "Вибрати значок",
    "Side panel": "Бічна панель",
    "Simplify": "Simplify",
    "Symbol or url": "Значок чи URL",
    "Table": "Таблиця",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "колір",
    "dash array": "штрихи",
    "define": "define",
    "description": "опис",
    "expanded": "expanded",
    "fill": "заливка",
    "fill color": "колір заливки",
    "fill opacity": "Непрозорість заливки",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "успадковувати",
    "name": "назва",
    "never": "never",
    "new window": "new window",
    "no": "ні",
    "on hover": "при наведенні",
    "opacity": "непрозорість",
    "parent window": "parent window",
    "stroke": "штрихи",
    "weight": "товщина",
    "yes": "так",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# один знак решітки — основний заголовок",
    "## two hashes for second heading": "## два знаки решітки — підзаголовок",
    "### three hashes for third heading": "### три знаки решітки — підзаголовок підзаголовка",
    "**double star for bold**": "**подвійні зірочки — жирний**",
    "*simple star for italic*": "*одинарні зірочки — курсив*",
    "--- for an horizontal rule": "---  горизонтальна лінія",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Про це",
    "Action not allowed :(": "Дія недоступна :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Додати шар",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Додати нову властивість",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Додаткові дії",
    "Advanced properties": "Розширенні параметри",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Усі властивості імпортовані.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Виникла помилка",
    "Are you sure you want to cancel your changes?": "Ви впевнені, що хочете скасувати зроблені зміни?",
    "Are you sure you want to clone this map and all its datalayers?": "Ви впевнені, що бажаєте скопіювати цю мапу з її усіма даними",
    "Are you sure you want to delete the feature?": "Ви впевнені, що хочете вилучити об’єкт?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Ви впевнені, що хочете вилучити мапу?",
    "Are you sure you want to delete this property on all the features?": "Ви впевнені, що хочете вилучити цю властивість у всіх об’єктів?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Прикріпити мапу до мого облікового запису",
    "Auto": "Автоматично",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Помістити об’єкт в центр",
    "Browse data": "Огляд даних",
    "Cancel edits": "Скасувати правки",
    "Center map on your location": "Центрувати мапу за Вашим місцем розташування",
    "Change map background": "Змінити фонову мапу",
    "Change tilelayers": "Вибрати фонові шари",
    "Choose a preset": "Виберіть шаблон",
    "Choose the format of the data to import": "Виберіть формат даних для імпорту",
    "Choose the layer to import in": "Виберіть шар для імпорту в нього",
    "Click last point to finish shape": "Клацніть на останній точці, щоб завершити",
    "Click to add a marker": "Клацніть, щоб додати позначку",
    "Click to continue drawing": "Клацайте, щоб продовжити малювання",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Клацайте, щоб продовжити малювання",
    "Click to start drawing a polygon": "Клацніть, щоб почати малювання багатокутника",
    "Clone": "Створити копію",
    "Clone of {name}": "Копія {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Створити копію мапи",
    "Close": "Зачинити",
    "Clustering radius": "Радіус кластеризації",
    "Comma separated list of properties to use when filtering features": "Список властивостей, розділених комами, для використання при фільтрації",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Як роздільник використовуються коми, табуляції і крапки з комою.  Застосовується датум WGS84. Імпорт переглядає заголовок на наявність полів „lat“ та „lon“, регістр не має значення.  Усі інші поля імпортуються як властивості.",
    "Continue line": "Continue line",
    "Continue line (Ctrl-click)": "Продовжити лінію (Ctrl + клацання)",
    "Coordinates": "Координати",
    "Credits": "Авторські права / подяки",
    "Current view instead of default map view?": "Поточний вид замість виду мапи за умовчанням?",
    "Custom background": "Користувацька фонова мапа",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Властивості за умовчанням",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Видалити",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Вилучити цей об’єкт",
    "Delete this property on all the features": "Вилучити цю властивість у всіх об’єктів",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Навігація звідси",
    "Disable editing": "Вимкнути редагування",
    "Display measure": "Display measure",
    "Display on load": "Відображати при завантаженні",
    "Download": "Звантажити",
    "Download data": "Звантажити дані",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Намалювати лінію",
    "Draw a marker": "Додати позначку",
    "Draw a polygon": "Намалювати багатокутник",
    "Draw a polyline": "Намалювати лінію",
    "Dynamic": "Динамічний",
    "Dynamic properties": "Динамічні властивості",
    "Edit": "Редагувати",
    "Edit feature's layer": "Змінити шар об’єкту",
    "Edit map properties": "Редагуємо властивості мапи",
    "Edit map settings": "Змінити властивості мапи",
    "Edit properties in a table": "Редагувати властивості в таблиці",
    "Edit this feature": "Редагувати цей об’єкт",
    "Editing": "Редагуємо",
    "Embed and share this map": "Вбудувати мапу та поділитися нею",
    "Embed the map": "Вбудувати мапу",
    "Empty": "Очистити",
    "Enable editing": "Задіяти редагування",
    "Error in the tilelayer URL": "Помилка в посиланні на шар мапи",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Відбір…",
    "Format": "Формат",
    "From zoom": "З масштабу",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Перейти до «{feature}»",
    "Heatmap intensity property": "Властивість інтенсивності теплової мапи",
    "Heatmap radius": "Радіус для теплової мапи",
    "Help": "Допомога",
    "Hide controls": "Прибрати елементи управління",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Наскільки сильно спрощувати лінії на кожному масштабі (більше значення — більша швидкість, але виглядає гірше; менше значення — більш гладке відображення)",
    "If false, the polygon will act as a part of the underlying map.": "Якщо ні, тоді багатокутник буде виглядати як частина мапи",
    "Iframe export options": "Властивості експорту для Iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe із зазначенням висоти (в пікселях): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Зображення із зазначенням ширини (в пікселях): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Зображення: {{http://image.url.com}}",
    "Import": "Імпорт",
    "Import data": "Імпорт даних",
    "Import in a new layer": "Імпортувати в новий шар",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Долучити посилання на повноекранний вид?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Залишити поточні видимі шари",
    "Latitude": "Широта",
    "Layer": "Шар",
    "Layer properties": "Layer properties",
    "Licence": "Ліцензія",
    "Limit bounds": "Встановлення меж",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Посилання з текстом: [[http://example.com|текст для посилання]]",
    "Long credits": "Повний опис прав/подяки",
    "Longitude": "Довгота",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Права/подяки на фонову мапу",
    "Map has been attached to your account": "Мапа була прикріплена до Вашого облікового запису",
    "Map has been saved!": "Мапу збережено!",
    "Map user content has been published under licence": "Картографічні дані користувача опубліковані згідно ліцензії",
    "Map's editors": "Редактори мапи",
    "Map's owner": "Власник мапи",
    "Merge lines": "Merge lines",
    "More controls": "Інші елементи управління",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Ліцензія не була зазначена",
    "No results": "No results",
    "Only visible features will be downloaded.": "Будуть завантажені лише відображувані об’єкти.",
    "Open download panel": "Відкрити панель звантаження",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Відкрийте цю частину мапи у редакторі OpenStreetMap, щоб поліпшити дані",
    "Optional intensity property for heatmap": "Додаткові властивості інтенсивності теплової мапи",
    "Optional. Same as color if not set.": "Додатково.  Якщо не вибрано, то як колір.",
    "Optionnal.": "Додатково.",
    "Override clustering radius (default 80)": "Перевизначити радіус кластеризації (за умовчанням 80)",
    "Override heatmap radius (default 25)": "Перевизначити радіус для теплової мапи (за умовчанням 25)",
    "Paste here your data": "Вставити Ваші дані сюди",
    "Please be sure the licence is compliant with your use.": "Переконайтеся, що ліцензія відповідає правилам використання.",
    "Please choose a format": "Будь ласка, виберіть формат",
    "Please enter the name of the property": "Будь ласка, введіть назву властивості",
    "Please enter the new name of this property": "Будь ласка, введіть нову назву властивості",
    "Please save the map before": "Будь ласка, спочатку збережіть мапу",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Працює на <a href=\"{leaflet}\">Leaflet</a> та <a href=\"{django}\">Django</a>, об’єднані проектом <a href=\"{umap}\">uMap</a>.",
    "Problem in the response": "Проблема з відповіддю",
    "Problem in the response format": "Формат відповіді не розпізнано",
    "Properties imported:": "Імпортовані властивості:",
    "Property to use for sorting features": "Властивість для сортування об’єктів",
    "Provide an URL here": "Вкажіть посилання тут",
    "Proxy request": "Запит проксі",
    "Remote data": "Віддалені дані",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Перейменувати цю властивість у всіх об’єктів",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Зберегти",
    "Save anyway": "Зберегти в будь-якому випадку",
    "Save current edits": "Зберегти поточні правки",
    "Save this center and zoom": "Зберегти такі центрування та масштаб",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Шукати назву місця",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Секретне посилання для редагування:<br>{link}",
    "See all": "Переглянути усе",
    "See data layers": "Подивитися шари даних",
    "See full screen": "Дивитися в повноекранному режимі",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Коротке посилання",
    "Short credits": "Короткий опис прав/подяки",
    "Show/hide layer": "Показати/приховати шар",
    "Simple link: [[http://example.com]]": "Просте посилання: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Пропущена невідома властивість geometry.type: {type}",
    "Slideshow": "Слайдшоу",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Розділити лінію",
    "Start a hole here": "Почати отвір звідси",
    "Start editing": "Почати редагування",
    "Start slideshow": "Почати слайдшоу",
    "Stop editing": "Зупинити редагування",
    "Stop slideshow": "Зупинити слайдшоу",
    "Supported scheme": "Підтримувана схема",
    "Supported variables that will be dynamically replaced": "Підтримувані змінні для автоматичної заміни",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Значок може бути як юнікод-символом так і URL. Ви можете використовувати властивості об'єктів як змінні. Наприклад, в \"http://myserver.org/images/{name}.png\", змінна {name} буде замінена значенням поля \"name\" кожної мітки на мапі.",
    "TMS format": "Формат TMS",
    "Text color for the cluster label": "Колір тексту для позначок кластера",
    "Text formatting": "Форматування тексту",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Масштаб й центрування виставлені",
    "To use if remote server doesn't allow cross domain (slower)": "Якщо віддалений сервер не дозволяє крос-домен (повільно)",
    "To zoom": "Масштабувати",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Перетворити на лінію",
    "Transform to polygon": "Перетворити на багатокутник",
    "Type of layer": "Тип шару",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Шар без назви",
    "Untitled map": "Безіменна мапа",
    "Update permissions": "Оновити дозволи",
    "Update permissions and editors": "Налаштувати привілеї та редакторів",
    "Url": "Посилання",
    "Use current bounds": "Використовувати поточні межі",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Використовуйте змінні в дужках з властивостями об’єктів, наприклад, &#123;name&#125;, вони будуть автоматично замінені відповідними значеннями.",
    "User content credits": "Права/подяки на користувацькі дані",
    "User interface options": "Налаштування інтерфейсу",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Що можна зробити з мапою далі?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Хто може редагувати",
    "Who can view": "Хто може редагувати",
    "Will be displayed in the bottom right corner of the map": "Буде показано в правому нижньому кутку мапи",
    "Will be visible in the caption of the map": "Буде показано у заголовку мапи",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Упс!  Схоже, хтось інший теж редагує ці дані.  Ви можете зберегти свої правки, але це знищить правки іншого учасника.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Збільшити масштаб",
    "Zoom level for automatic zooms": "Рівень масштабу для автоматичного масштабування",
    "Zoom out": "Зменшити масштаб",
    "Zoom to layer extent": "Масштабувати до кордонів шару",
    "Zoom to the next": "Наблизитися до наступного",
    "Zoom to the previous": "Наблизитися до попереднього",
    "Zoom to this feature": "Наблизитися до цього об’єкта",
    "Zoom to this place": "Zoom to this place",
    "attribution": "призначені властивості",
    "by": "від",
    "display name": "відображувана назва",
    "height": "висота",
    "licence": "ліцензія",
    "max East": "макс. на схід",
    "max North": "макс. на північ",
    "max South": "макс. на південь",
    "max West": "макс. на захід",
    "max zoom": "максимальний масштаб",
    "min zoom": "мінімальний масштаб",
    "next": "next",
    "previous": "previous",
    "width": "ширина",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Виміряти відстань",
    "NM": "NM",
    "kilometers": "кілометрів",
    "km": "км",
    "mi": "миля",
    "miles": "миль",
    "nautical miles": "морських миль",
    "{area} acres": "{area} акрів",
    "{area} ha": " {area} гектар",
    "{area} m&sup2;": "{area} м&sup2;",
    "{area} mi&sup2;": " {area} миль&sup2;",
    "{area} yd&sup2;": " {area} ярд&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} км",
    "{distance} m": "{distance} м",
    "{distance} miles": " {distance} миль",
    "{distance} yd": " {distance} ярдів",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("uk_UA", locale);
L.setLocale("uk_UA");