{% load compress %}
{% compress js %}
    <script src="{{ STATIC_URL }}umap/vendors/leaflet/leaflet-src.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/editable/Path.Drag.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/editable/Leaflet.Editable.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/hash/leaflet-hash.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/i18n/Leaflet.i18n.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/editinosm/Leaflet.EditInOSM.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/minimap/Control.MiniMap.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/csv2geojson/csv2geojson.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/togeojson/togeojson.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/osmtogeojson/osmtogeojson.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/loading/Control.Loading.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/markercluster/leaflet.markercluster-src.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/contextmenu/leaflet.contextmenu.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/photon/leaflet.photon.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/georsstogeojson/GeoRSSToGeoJSON.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/heat/leaflet-heat.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/fullscreen/Leaflet.fullscreen.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/toolbar/leaflet.toolbar-src.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/formbuilder/Leaflet.FormBuilder.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/measurable/Leaflet.Measurable.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/togpx/togpx.js"></script>
    <script src="{{ STATIC_URL }}umap/vendors/tokml/tokml.js"></script>
{% endcompress %}
{% if locale %}
    <script src="{{ STATIC_URL }}umap/locale/{{ locale }}.js"></script>
{% endif %}
{% compress js %}
    <script src="{{ STATIC_URL }}umap/js/umap.core.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.autocomplete.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.popup.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.xhr.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.forms.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.icon.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.features.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.layer.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.controls.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.slideshow.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.tableeditor.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.permissions.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.js"></script>
    <script src="{{ STATIC_URL }}umap/js/umap.ui.js"></script>
{% endcompress %}
