var locale = {
    "Add symbol": "Pridať symbol",
    "Allow scroll wheel zoom?": "Povoliť približovanie kolieskom myši?",
    "Automatic": "Automaticky",
    "Ball": "Špendlík",
    "Cancel": "Zrušiť",
    "Caption": "Nadpis",
    "Change symbol": "Zmeniť symbol",
    "Choose the data format": "Zvoľte formát údajov",
    "Choose the layer of the feature": "Zvoľte vrstvu do ktorej objekt patrí",
    "Circle": "Kruh",
    "Clustered": "Zhluková",
    "Data browser": "Prehliadač",
    "Default": "Predvolené",
    "Default zoom level": "Predvolené priblíženie",
    "Default: name": "Štandardná hodnota: názov",
    "Display label": "Zobraziť popis",
    "Display the control to open OpenStreetMap editor": "Zobraziť ovládanie na otvorenie editora OpenStreetMap",
    "Display the data layers control": "Zobraziť ovládanie údajov vrstiev",
    "Display the embed control": "Zobraziť ovládanie vkladania",
    "Display the fullscreen control": "Zobraziť ovládanie celej obrazovky",
    "Display the locate control": "Zobraziť ovládanie polohy",
    "Display the measure control": "Zobraziť ovládanie merania",
    "Display the search control": "Zobraziť ovládanie vyhľadávania",
    "Display the tile layers control": "Zobraziť ovládanie dlaždíc vrstiev",
    "Display the zoom control": "Zobraziť ovládanie priblíženia",
    "Do you want to display a caption bar?": "Chcete zobraziť lištu s nadpismi?",
    "Do you want to display a minimap?": "Chcete zobraziť minimapu?",
    "Do you want to display a panel on load?": "Prajete si zobraziť panel pri štarte?",
    "Do you want to display popup footer?": "Chcete zobraziť v bubline navigačný panel?",
    "Do you want to display the scale control?": "Chcete zobraziť mierku mapy?",
    "Do you want to display the «more» control?": "Prajete si zobrazit  «viac» nastavení?",
    "Drop": "Pustiť",
    "GeoRSS (only link)": "GeoRSS (iba odkaz)",
    "GeoRSS (title + image)": "GeoRSS (názov + obrázok)",
    "Heatmap": "Teplotná mapa",
    "Icon shape": "Tvar ikony",
    "Icon symbol": "Symbol ikony",
    "Inherit": "Predvolené",
    "Label direction": "Orientácia popisu",
    "Label key": "Kľúč popisu",
    "Labels are clickable": "Popis je klikateľný",
    "None": "Žiadny",
    "On the bottom": "V spodnej časti",
    "On the left": "Naľavo",
    "On the right": "Napravo",
    "On the top": "V hornej časti",
    "Popup content template": "Šablóna obsahu bubliny",
    "Set symbol": "Set symbol",
    "Side panel": "Bočný panel",
    "Simplify": "Zjednodušiť",
    "Symbol or url": "Symbol or url",
    "Table": "Tabuľka",
    "always": "vždy",
    "clear": "vyčistiť",
    "collapsed": "zbalené",
    "color": "farba",
    "dash array": "štýl prerušovanej čiary",
    "define": "definovať",
    "description": "popis",
    "expanded": "rozbalené",
    "fill": "výplň",
    "fill color": "farba výplne",
    "fill opacity": "priehľadnosť výplne",
    "hidden": "skryté",
    "iframe": "iframe",
    "inherit": "predvolené",
    "name": "názov",
    "never": "nikdy",
    "new window": "nové okno",
    "no": "nie",
    "on hover": "on hover",
    "opacity": "priehľadnosť",
    "parent window": "nadradené okno",
    "stroke": "linka",
    "weight": "šírka linky",
    "yes": "áno",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# jedna mriežka pre hlavný nadpis",
    "## two hashes for second heading": "## dve mriežky pre nadpis druhej úrovne",
    "### three hashes for third heading": "## tri mriežky pre nadpis tretej úrovne",
    "**double star for bold**": "**všetko medzi dvoma hviezdičkami je tučně**",
    "*simple star for italic*": "*všetko medzi hviezdičkami bude kurzívou*",
    "--- for an horizontal rule": "--- vytvorí vodorovnú linku",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Čiarkami oddelený zoznam čísel, ktorý popisuje vzor prerušovanej čiary. Napr. \"5, 10, 15\".",
    "About": "O uMap",
    "Action not allowed :(": "Akcia nie je povolená :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Pridať vrstvu",
    "Add a line to the current multi": "Pridať čiaru k aktuálnemu multi",
    "Add a new property": "Pridať novú vlastnosť",
    "Add a polygon to the current multi": "Pridať polygón k aktuálnemu multi",
    "Advanced actions": "Pokročilé akcie",
    "Advanced properties": "Pokročilé vlastnosti",
    "Advanced transition": "Pokročilý prechod",
    "All properties are imported.": "Všetky vlastnosti sú naimportované.",
    "Allow interactions": "Povoliť interakcie",
    "An error occured": "Nastala chyba",
    "Are you sure you want to cancel your changes?": "Ste si istí že chcete zrušiť vaše úpravy?",
    "Are you sure you want to clone this map and all its datalayers?": "Určite chcete vytvoriť kópiu celej tejto mapy a všetkých jej vrstiev?",
    "Are you sure you want to delete the feature?": "Určite chcete vymazať tento objekt?",
    "Are you sure you want to delete this layer?": "Určite chcete vymazať túto vrstvu?",
    "Are you sure you want to delete this map?": "Ste si istí, že chcete vymazať túto mapu?",
    "Are you sure you want to delete this property on all the features?": "Ste si istí že chcete vymazať túto vlastnosť na všetkých objektoch?",
    "Are you sure you want to restore this version?": "Určite chcete obnoviť túto verziu?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Automatická",
    "Autostart when map is loaded": "Aut. spustenie pri načítaní mapy",
    "Bring feature to center": "Vycentruj mapu na objekt",
    "Browse data": "Prezerať údaje",
    "Cancel edits": "Zrušiť zmeny",
    "Center map on your location": "Vycentrovať mapu na vašu polohu",
    "Change map background": "Zmeniť pozadie mapy",
    "Change tilelayers": "Zmeniť pozadie mapy",
    "Choose a preset": "Vyberte predvoľbu",
    "Choose the format of the data to import": "Zvoľte v akom formáte sú importované údaje",
    "Choose the layer to import in": "Zvoľte vrstvu, do ktorej sa bude importovať",
    "Click last point to finish shape": "Kliknite na posledný bod pre dokončenie tvaru",
    "Click to add a marker": "Kliknutím pridáte značku",
    "Click to continue drawing": "Kliknutím môžete pokračovať v kreslení",
    "Click to edit": "Kliknutím upravte",
    "Click to start drawing a line": "Kliknutím začnete kresliť čiaru",
    "Click to start drawing a polygon": "Kliknutím začnete kresliť polygón",
    "Clone": "Vytvoriť kópiu",
    "Clone of {name}": "Kópia {name}",
    "Clone this feature": "Vytvoriť kópiu objektu",
    "Clone this map": "Vytvoriť kópiu tejto mapy",
    "Close": "Zatvoriť",
    "Clustering radius": "Polomer zhlukovania",
    "Comma separated list of properties to use when filtering features": "Čiarkami oddelený zoznam vlastností pre filtrovanie objektov",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Hodnoty oddelené čiarkou, tabulátorom, alebo bodkočiarkou. Predpokladá sa SRS WGS84 a sú importované iba polohy bodov. Import hľadá záhlavie stĺpcov začínajúcich na \"lat\" a \"lon\" a tie považuje za súradnice (na veľkosti písmien nezáleži). Ostatné stĺpce sú importované ako vlastnosti.",
    "Continue line": "Pokračovať v čiare",
    "Continue line (Ctrl-click)": "Pokračovať v čiare (Ctrl+klik)",
    "Coordinates": "Súradnice",
    "Credits": "Poďakovania",
    "Current view instead of default map view?": "Aktuálne zobrazenie namiesto štandardného zobrazenia mapy?",
    "Custom background": "Vlastné pozadie",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Predvolené možnosti interakcie",
    "Default properties": "Predvolené vlastnosti",
    "Default shape properties": "Predvolené vlastnosti tvaru",
    "Define link to open in a new window on polygon click.": "Definujte odkaz na otvorenie, ktorý otvorí nové okno po kliknutí na polygón.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Vymazať",
    "Delete all layers": "Vymazať všetky vrstvy",
    "Delete layer": "Vymazať vrstvu",
    "Delete this feature": "Vymazať tento objekt",
    "Delete this property on all the features": "Vymazať túto vlastnosť na všetkých objektoch",
    "Delete this shape": "Vymazať tento tvar",
    "Delete this vertex (Alt-click)": "Vymazať tento bod (Alt+klik)",
    "Directions from here": "Navigovať odtiaľto",
    "Disable editing": "Zakázať úpravy",
    "Display measure": "Display measure",
    "Display on load": "Zobraziť pri štarte",
    "Download": "Download",
    "Download data": "Stiahnuť údaje",
    "Drag to reorder": "Presunutím zmeníte poradie",
    "Draw a line": "Nakresliť jednoduchú čiaru",
    "Draw a marker": "Nakresliť značku miesta",
    "Draw a polygon": "Nakresliť polygon",
    "Draw a polyline": "Nakresliť krivku",
    "Dynamic": "Dynamicky",
    "Dynamic properties": "Dynamické vlastnosti",
    "Edit": "Upraviť",
    "Edit feature's layer": "Upraviť vrstvu objektu",
    "Edit map properties": "Upraviť vlastnosti mapy",
    "Edit map settings": "Upraviť nastavenia mapy",
    "Edit properties in a table": "Upraviť vlastnosti v tabuľke",
    "Edit this feature": "Upraviť tento objekt",
    "Editing": "Upravujete",
    "Embed and share this map": "Zdieľaj alebo vlož mapu do iného webu",
    "Embed the map": "Vložiť mapu na iný web",
    "Empty": "Vyprázdniť",
    "Enable editing": "Povoliť úpravy",
    "Error in the tilelayer URL": "Chyba URL dlaždicovej vrstvy",
    "Error while fetching {url}": "Vyskytla sa chyba počas načítania {url}",
    "Exit Fullscreen": "Ukončiť režim celej obrazovky",
    "Extract shape to separate feature": "Vyňať tvar do samostatného objektu",
    "Fetch data each time map view changes.": "Načítanie údajov pri každej zmene zobrazenia mapy.",
    "Filter keys": "Kľúče filtra",
    "Filter…": "Filter…",
    "Format": "Formát",
    "From zoom": "Max. oddialenie",
    "Full map data": "Údaje celej mapy",
    "Go to «{feature}»": "Prejsť na «{feature}»",
    "Heatmap intensity property": "Vlastnosti intenzity heatmapy",
    "Heatmap radius": "Polomer teplotnej mapy",
    "Help": "Nápoveda",
    "Hide controls": "Skryť ovládacie prvky",
    "Home": "Domov",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Ako veľmi vyhladzovať a zjednodušovať pri oddialeni (väčšie = rýchlejša odozva a plynulejší vzhľad, menšie = presnejšie)",
    "If false, the polygon will act as a part of the underlying map.": "Ak je vypnuté, polygón sa bude správať ako súčasť mapového podkladu.",
    "Iframe export options": "Možnosti Iframe exportu",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe s vlastnou výškou (v px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe s vlastnou výškou a šírkou (v px): {{{http://iframe.url.com|height*widht}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obraz s vlastnou šírkou (v pixeloch): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Obrázok: {{http://url.obrazka.sk}}",
    "Import": "Importovať",
    "Import data": "Import údajov",
    "Import in a new layer": "Importovať do novej vrstvy",
    "Imports all umap data, including layers and settings.": "Importuje všetky údaje umapy, vrátane vrstiev a nastavení.",
    "Include full screen link?": "Zahrnúť odkaz na celú obrazovku?",
    "Interaction options": "Možnosti interakcie",
    "Invalid umap data": "Neplatné údaje umapy",
    "Invalid umap data in {filename}": "Neplatné údaje umapy v súbore {filename}",
    "Keep current visible layers": "Použiť pre aktuálne zobrazenie vrstiev",
    "Latitude": "Zem. šírka",
    "Layer": "Vrstva",
    "Layer properties": "Vlastnosti vrstvy",
    "Licence": "Licencia",
    "Limit bounds": "Obmedziť hranice",
    "Link to…": "Odkaz na…",
    "Link with text: [[http://example.com|text of the link]]": "Odkaz s textom: [[http://priklad.sk|text odkazu]]",
    "Long credits": "Dlhý text autorstva",
    "Longitude": "Zem. dĺžka",
    "Make main shape": "Urobiť hlavným tvarom",
    "Manage layers": "Nastavenie vrstiev",
    "Map background credits": "Autor mapy pozadia",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Mapa bola uložená!",
    "Map user content has been published under licence": "Použivateľské údaje sú zverejnené pod licenciou",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Spojiť čiary",
    "More controls": "Viac ovládacích prvkov",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Musí byť platná hodnota CSS (napr.: DarkBlue or #123456)",
    "No licence has been set": "Nebola nastavená žiadna licencia",
    "No results": "Žiadne výsledky",
    "Only visible features will be downloaded.": "Stiahnuté budú len viditeľné objekty.",
    "Open download panel": "Open download panel",
    "Open link in…": "Otvoriť odkaz v…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otvoriť túto mapovú oblasť v mapovom editore pre presnenie dát v OpenStreetMap",
    "Optional intensity property for heatmap": "Voliteľné vlastnosti intenzity pre heatmapu",
    "Optional. Same as color if not set.": "Nepovinné. Rovnaké ako farba, ak nie je nastavené.",
    "Optionnal.": "Nepovinné",
    "Override clustering radius (default 80)": "Prepísať polomer zhlukovania (predvolené 80)",
    "Override heatmap radius (default 25)": "Prepísať polomer teplotnej mapy (predvolené 25)",
    "Paste here your data": "Sem vložte vaše údaje",
    "Please be sure the licence is compliant with your use.": "Prosíme uistite sa, že licencia je v zhode s tým ako mapu používate.",
    "Please choose a format": "Prosím, zvoľte formát",
    "Please enter the name of the property": "Prosím, zadajte názov vlastnosti",
    "Please enter the new name of this property": "Prosím, zadajte nový názov tejto vlastnosti",
    "Please save the map before": "Prosím, najprv uložte mapu",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Zostavené z <a href=\"{leaflet}\">Leaflet</a> a <a href=\"{django}\">Django</a>, prepojené pomocou <a href=\"{umap}\">projektu uMap</a>.",
    "Problem in the response": "Problém v odpovedi",
    "Problem in the response format": "Problém vo formáte odpovede",
    "Properties imported:": "Importované vlastnosti:",
    "Property to use for sorting features": "Vlastnosť použitá pre radenie objektov",
    "Provide an URL here": "Sem vložte odkaz URL",
    "Proxy request": "Požiadavky cez proxy",
    "Remote data": "Vzdialené údaje",
    "Remove shape from the multi": "Odobrať tvar z multi",
    "Rename this property on all the features": "Premenovať túto vlastnosť na všetkých objektoch",
    "Replace layer content": "Nahradiť obsah vrstvy",
    "Restore this version": "Obnoviť túto verziu",
    "Save": "Uložiť",
    "Save anyway": "Uložiť napriek tomu",
    "Save current edits": "Uložiť nedávne zmeny",
    "Save this center and zoom": "Uložiť túto pozíciu mapy a jej priblíženie",
    "Save this location as new feature": "Uložiť túto polohu ako nový objekt",
    "Search a place name": "Search a place name",
    "Search location": "Vyhľadať polohu",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Zobraziť všetko",
    "See data layers": "See data layers",
    "See full screen": "Na celú obrazovku",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Vlastnosti tvaru",
    "Short URL": "Krátky odkaz URL",
    "Short credits": "Krátky text autorstva",
    "Show/hide layer": "Ukázať/skryť vrstvu",
    "Simple link: [[http://example.com]]": "Jednoduchý odkaz: [[http://priklad.sk]]",
    "Skipping unkown geometry.type: {type}": "Preskakujem neznáme geometry.type: {type}",
    "Slideshow": "Prezentácia",
    "Smart transitions": "Chytré prechody",
    "Sort key": "Kľúč radenia",
    "Split line": "Rozdelit čiaru",
    "Start a hole here": "Tu začať dieru",
    "Start editing": "Začať úpravy",
    "Start slideshow": "Spustiť prezentáciu",
    "Stop editing": "Ukončiť úpravy",
    "Stop slideshow": "Zastaviť prezentáciu",
    "Supported scheme": "Podporovaná schéma",
    "Supported variables that will be dynamically replaced": "Podporované premenné, ktoré budú automaticky nahradené",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "Formát TMS",
    "Text color for the cluster label": "Farba textu pre popis zhluku",
    "Text formatting": "Formátovanie textu",
    "The name of the property to use as feature label (ex.: \"nom\")": "Názov vlastnosti používať ako popis objektu (napr.: \"nom\")",
    "The zoom and center have been setted.": "Priblíženie a stred mapy boli nastavené",
    "To use if remote server doesn't allow cross domain (slower)": "Použiť keď vzdialený server nepovoľuje cross-domain (pomalšie)",
    "To zoom": "Max. priblíženie",
    "Toggle edit mode (shift-click)": "Prepnúť režim úprav (Shift+klik)",
    "Transfer shape to edited feature": "Preniesť tvar do upravovaného objektu",
    "Transform to lines": "Transformuj na čiary",
    "Transform to polygon": "Transformuj na mnohouholník",
    "Type of layer": "Typ vrstvy",
    "Unable to detect format of file {filename}": "Nepodarilo sa rozpoznať formát súboru {filename}",
    "Untitled layer": "Nepomenovaná vrstva",
    "Untitled map": "Nepomenovaná mapa",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Nastaviť prístupové práva a prispievateľov",
    "Url": "URL",
    "Use current bounds": "Použiť aktuálne hranice",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Použite zástupné znaky s vlastnosťami objektov medzi zloženými zátvorkami, napr. &#123;name&#125;, a budú dynamicky nahradené zodpovedajúcimi hodnotami.",
    "User content credits": "Autor používateľského obsahu",
    "User interface options": "Možnosti používateľského rozhrania",
    "Versions": "Verzie",
    "View Fullscreen": "Zobraziť na celú obrazovky",
    "Where do we go from here?": "Kam sa dá odtiaľto dostať?",
    "Whether to display or not polygons paths.": "Či sa má alebo nemá zobraziť cesty polygónov.",
    "Whether to fill polygons with color.": "Či sa má vyplniť polygón farbou.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Bude zobrazené s mapou vpravo dole",
    "Will be visible in the caption of the map": "Bude zobrazené v nadpise mapy",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ojoj! Niekto iný medzitým taktiež upravil údaje. Môžete ich napriek tomu uložiť, ale zmažete tak jeho zmeny.",
    "You have unsaved changes.": "Máte neuložené zmeny.",
    "Zoom in": "Priblížiť",
    "Zoom level for automatic zooms": "Úroveň priblíženia pre automatické približovanie",
    "Zoom out": "Oddialiť",
    "Zoom to layer extent": "Prispôsobiť priblíženie vrstve",
    "Zoom to the next": "Priblížiť k ďalšiemu",
    "Zoom to the previous": "Priblížiť k predošlému",
    "Zoom to this feature": "Priblížiť na tento objekt",
    "Zoom to this place": "Priblížiť na toto miesto",
    "attribution": "autorstvo",
    "by": "od",
    "display name": "zobraziť názov",
    "height": "Výška",
    "licence": "licencia",
    "max East": "max. Východ",
    "max North": "max. Sever",
    "max South": "max. Juh",
    "max West": "max. Západ",
    "max zoom": "max. priblíženie",
    "min zoom": "max. oddialenie",
    "next": "ďalší",
    "previous": "predchádzajúci",
    "width": "Šírka",
    "{count} errors during import: {message}": "Počet chýb počas importu {count}: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("sk_SK", locale);
L.setLocale("sk_SK");