var locale = {
    "Add symbol": "Tilføj symbol",
    "Allow scroll wheel zoom?": "Tillad scrool mus zoom?",
    "Automatic": "Automatic",
    "Ball": "Kugle",
    "Cancel": "Fortryd",
    "Caption": "Billedtekst",
    "Change symbol": "Skift symbol",
    "Choose the data format": "Vælg geodata format",
    "Choose the layer of the feature": "Vælg lag for objektet",
    "Circle": "Cirkel",
    "Clustered": "Klynge",
    "Data browser": "Geodata browser",
    "Default": "Standard",
    "Default zoom level": "Standard zoom-niveau",
    "Default: name": "Standardnavn:",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Vis knap til OpenStreetMap-redigering",
    "Display the data layers control": "Vis knap til valg af datalag",
    "Display the embed control": "Vis knap til indlejring",
    "Display the fullscreen control": "Vis knap til fuldskærm",
    "Display the locate control": "Vis knap til lokaliserings",
    "Display the measure control": "Vis knap til opmåling",
    "Display the search control": "Vis knap til søgning",
    "Display the tile layers control": "Vis knap til valg af fliselag",
    "Display the zoom control": "Vis knap til valg af zoom",
    "Do you want to display a caption bar?": "Vil du vise en billedtekst?",
    "Do you want to display a minimap?": "Vil du vise  et miniaturekort?",
    "Do you want to display a panel on load?": "Vil du vise et panel ved indlæsning?",
    "Do you want to display popup footer?": "Vil du vise popup noten?",
    "Do you want to display the scale control?": "Vil du vise skala kontrolpanelet?",
    "Do you want to display the «more» control?": "Vil du vise mere af kontrolpanel?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (kun link)",
    "GeoRSS (title + image)": "GeoRSS (titel + billede)",
    "Heatmap": "Heatmap",
    "Icon shape": "Ikon-form",
    "Icon symbol": "Ikon-symbol",
    "Inherit": "Nedarve",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Ingen",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popul indholdsskabelon",
    "Set symbol": "Set symbol",
    "Side panel": "Sidepanel",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Tabel",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "farver",
    "dash array": "stiplet kasse",
    "define": "define",
    "description": "beskrivelse",
    "expanded": "expanded",
    "fill": "fyld",
    "fill color": "udfyldningsfarve",
    "fill opacity": "Fyldnings opacitet",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "nedarve",
    "name": "Navn",
    "never": "never",
    "new window": "new window",
    "no": "nej",
    "on hover": "on hover",
    "opacity": "opacitet",
    "parent window": "parent window",
    "stroke": "stroke i typografi",
    "weight": "vægtning",
    "yes": "ja",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# et hashtag for hovedoverskrift",
    "## two hashes for second heading": "## to hashtag for anden overskrift",
    "### three hashes for third heading": "### tre hashtag for tredje overskriftsniveau",
    "**double star for bold**": "**dobbelt stjerne for fed skrift**",
    "*simple star for italic*": "*enkelt stjerne for kursiv*",
    "--- for an horizontal rule": "---  for vandret regel",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommasepareret liste af numre som definerer prikmønstret. Ex.: \"5, 10, 15\".",
    "About": "Om",
    "Action not allowed :(": "Handling er ikke tilladt :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Tilføj et lag",
    "Add a line to the current multi": "Tilføj en linje til nuværende multi",
    "Add a new property": "Tilføj en ny egenskab",
    "Add a polygon to the current multi": "Tilføj en polygon til nuværende multi",
    "Advanced actions": "Avancerede handlinger",
    "Advanced properties": "Avancerede indstillinger",
    "Advanced transition": "Avanceret overgang",
    "All properties are imported.": "Alle objekter er blevet importeret.",
    "Allow interactions": "Tillad interaktioner",
    "An error occured": "Der opstod en fejl",
    "Are you sure you want to cancel your changes?": "Er du sikker på du vil fortryde dine ændringer?",
    "Are you sure you want to clone this map and all its datalayers?": "Er du sikker på du vil klone dette kort og alle geodatalagene?",
    "Are you sure you want to delete the feature?": "Er du sikker på at du vil slette dette objekt?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Er du sikker på at du vil slette dette kort?",
    "Are you sure you want to delete this property on all the features?": "Er du sikker på du vil slette denne egenskab for alle objekter?",
    "Are you sure you want to restore this version?": "Er du sikker på at du vil genskabe denne version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Start automatisk når kort er indlæst",
    "Bring feature to center": "Centrerer objekterne",
    "Browse data": "Browse geodata",
    "Cancel edits": "Fortryd redigeringer",
    "Center map on your location": "Centrer kort på din placering",
    "Change map background": "Skift kortbaggrund",
    "Change tilelayers": "Skift kortlag",
    "Choose a preset": "Vælg en forudindstillet indstilling",
    "Choose the format of the data to import": "Vælg format af geodata der skal importeres",
    "Choose the layer to import in": "Vælg lag der skal importeres",
    "Click last point to finish shape": "Klik på det det sidste punkt for at færdigegøre",
    "Click to add a marker": "Klik for at tilføje en  markør",
    "Click to continue drawing": "Klik for at fortsætte indtegning",
    "Click to edit": "Klik for at redigere",
    "Click to start drawing a line": "Klik for at starte med at indtegne en linje",
    "Click to start drawing a polygon": "Klik for at starte indtegning af polygon",
    "Clone": "Klone",
    "Clone of {name}": "Klone af {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Klon dette kort",
    "Close": "Luk",
    "Clustering radius": "Klynge radius",
    "Comma separated list of properties to use when filtering features": "Kommasepareret list af alle egenskaberne til brug ved filteret objekter.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabulering eller semikolon adskiller værdier. SRS WGS84 er standard. Kun punkt geometri er importeret. Importen vil kigge efter kolonner der indeholder varianter af  «lat» eller  «lon» i begyndelsen af overskriften. Disse er store/små ufølsomme. Alle andre kolonner vil blive importeret som objekter.",
    "Continue line": "Fortsæt linje",
    "Continue line (Ctrl-click)": "Fortsæt linje (Kontrol-klik)",
    "Coordinates": "Koordinater",
    "Credits": "Kreditering",
    "Current view instead of default map view?": "Nuværende kortudsnit i stedet for standard kortudsnit?",
    "Custom background": "Tilpas baggrund",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Standard interaktionsindstillinger",
    "Default properties": "Standard indstillinger",
    "Default shape properties": "Standard figur-egenskaber",
    "Define link to open in a new window on polygon click.": "Definer link som åbnes i et nyt vindue ved klik på polygon.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Slet",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Slet dette objekt",
    "Delete this property on all the features": "Slet denne egenskab for alle objekter",
    "Delete this shape": "Slet denne figur",
    "Delete this vertex (Alt-click)": "Slet denne vertex (Alt-click)",
    "Directions from here": "Kørselsvejledning fra her",
    "Disable editing": "Deaktiver redigering",
    "Display measure": "Display measure",
    "Display on load": "Vis ved indlæsning",
    "Download": "Download",
    "Download data": "Download geodata",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Tegn en linje",
    "Draw a marker": "Tegn en markør",
    "Draw a polygon": "Tegn en polygon",
    "Draw a polyline": "Tegn en polygonlinje",
    "Dynamic": "Dynamisk",
    "Dynamic properties": "Dynamiske egenskaber",
    "Edit": "Redigere",
    "Edit feature's layer": "Ret objekt lag",
    "Edit map properties": "Ret kortindstillinger",
    "Edit map settings": "Kortredigerings indstillinger",
    "Edit properties in a table": "Ret egenskaberne i en tabel",
    "Edit this feature": "Ret dette objekt",
    "Editing": "Redigere",
    "Embed and share this map": "Indlejre og del dette kort",
    "Embed the map": "Indlejring af kortet",
    "Empty": "Tomt",
    "Enable editing": "Aktiver redigering",
    "Error in the tilelayer URL": "Fejl i tile-lags URLen",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Afslut fuldskærm",
    "Extract shape to separate feature": "Træk figur ud for at separere objekter",
    "Fetch data each time map view changes.": "Hent data hver gang kortvisningen ændres.",
    "Filter keys": "Filternøgler",
    "Filter…": "Filter…",
    "Format": "Format",
    "From zoom": "Fra zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Gå til «{feature}»",
    "Heatmap intensity property": "Heatmap intensitet egenskaber",
    "Heatmap radius": "Heatmap radius",
    "Help": "Hjælp",
    "Hide controls": "Skjul kontrolpanel",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hvor meget  linjen skal forenkles på hvert zoom niveau. (Mere =  hurtigere og lettere udseende, mindre = mere præcist)",
    "If false, the polygon will act as a part of the underlying map.": "Hvis falsk så vil polygonen opfører sig som en del af det underliggende kort.",
    "Iframe export options": "Iframe eksportmuligheder",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe med brugerdefineret højde (i px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Billede med bredde (i px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Billede:  {{http://image.url.com}}",
    "Import": "Import",
    "Import data": "Importer geodata",
    "Import in a new layer": "Importerer i et nyt lag",
    "Imports all umap data, including layers and settings.": "Importerer alle umap-data, inklusiv lag og indstillinger,",
    "Include full screen link?": "Inkluderer fuldskærm link?",
    "Interaction options": "Interaktionsindstillinger",
    "Invalid umap data": "Ugyldige umap data",
    "Invalid umap data in {filename}": "Uglydige umap-data i {filename}",
    "Keep current visible layers": "Behold nuværende synlige lag",
    "Latitude": "Længdegrader",
    "Layer": "Lag",
    "Layer properties": "Lag-indstillinger",
    "Licence": "Licens",
    "Limit bounds": "Geografisk afgræsning",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link med tekst: [[http://example.com|tekst for linket her]]",
    "Long credits": "Lang kreditering",
    "Longitude": "Breddegrader",
    "Make main shape": "Gør til hoved-figur",
    "Manage layers": "Manage layers",
    "Map background credits": "Baggrundskort kreditering",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Kortet er blevet gemt!",
    "Map user content has been published under licence": "Kortindholdet er udgivet under licensen",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Flet linjer",
    "More controls": "Vis flere kontrolpaneler",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Ingen licens angivet",
    "No results": "No results",
    "Only visible features will be downloaded.": "Kun synlige objekter vil blive downloadet.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Åbn dette kort i en korteditor for at gøre geodata endnu bedre i OpenStreetMap",
    "Optional intensity property for heatmap": "Valgfrie  intensitets egenskaber for heatmap",
    "Optional. Same as color if not set.": "Valgfrit. Uden ændring samme farve.",
    "Optionnal.": "Valgfrit.",
    "Override clustering radius (default 80)": "Overskriv klynge radius (standard 80)",
    "Override heatmap radius (default 25)": "Overskriv heatmap radius (standard 25)",
    "Paste here your data": "Indsæt dine geodata her",
    "Please be sure the licence is compliant with your use.": "Vær sikker på at licensen er kompatibel med din brug.",
    "Please choose a format": "Vælg venligst et format",
    "Please enter the name of the property": "Vær venlig at indtaste navnet for egenskaben",
    "Please enter the new name of this property": "Vær venlig at indtaste et nyt navn for denne egenskab",
    "Please save the map before": "Gem kortet først før du går videre",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Håndteret af <a href='{leaflet}'>Leaflet</a> og <a href='{django}'>Django</a>,  flettet ind i <a href='{umap}'>uMap projektet</a>.",
    "Problem in the response": "Problem med responsen",
    "Problem in the response format": "Der er et problem med det kaldte format",
    "Properties imported:": "Objekter importeret:",
    "Property to use for sorting features": "Egenskab til brug for at sortere objekter",
    "Provide an URL here": "Indsæt en URL her",
    "Proxy request": "Proxy forespørgsel",
    "Remote data": "Fjernudbudt geodata",
    "Remove shape from the multi": "Fjern figur fra multi",
    "Rename this property on all the features": "Omdøb denne egenskab for alle objekter",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Genskab denne version",
    "Save": "Gem",
    "Save anyway": "Gem alligevel",
    "Save current edits": "Gem nuværende rettelser",
    "Save this center and zoom": "Gem med dette center og zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Se alle",
    "See data layers": "See data layers",
    "See full screen": "Se i fuld skærmstørrelse",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Kort URL",
    "Short credits": "Kort kreditering",
    "Show/hide layer": "Vis/skjul lag",
    "Simple link: [[http://example.com]]": "Simpelt link: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Spring ukendt geometry.type: {type} over",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Spilt linjen op",
    "Start a hole here": "Start et hul her",
    "Start editing": "Start redigering",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop redigering",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Understøttet skema",
    "Supported variables that will be dynamically replaced": "Understøttede variabler som vil blive dynamisk erstattet",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Tekstfarve for klynge label",
    "Text formatting": "Tekstformatering",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Zoom og center er blevet justeret.",
    "To use if remote server doesn't allow cross domain (slower)": "Brug denne hvis remote server ikke tillader krydsdomæne (sløvere)",
    "To zoom": "For at zoome",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Overfør figur til redigerede objekt",
    "Transform to lines": "Transformere til linjer",
    "Transform to polygon": "Transformere til polygon",
    "Type of layer": "Type af lag",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Unavngivet lag",
    "Untitled map": "Unavngivet kort",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Opdaterer indstillinger og redaktører",
    "Url": "URL",
    "Use current bounds": "Brug nuværende grænser",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Brug pladsholdere med objekt egenskaberne mellem tuborgklammer fx &#123;navn&#125; så vil de dynamatisk blive erstattet med de tilhørende værdier.",
    "User content credits": "Brugerindholds kredit",
    "User interface options": "Brugergrænseflade indstillinger",
    "Versions": "Versioner",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Hvor skal vi gå til fra her?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Vil blive vist nede i højre hjørne af kortet",
    "Will be visible in the caption of the map": "Vil blive synlig i tekstfeltet på kortet",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Oops! Det ser ud til at nogen har rettet i data. Du kan godt gemme alligevel, men dette vil så overskrive de ændringer de andre har lavet.",
    "You have unsaved changes.": "Du har ugemte ændringer.",
    "Zoom in": "Zoom ind",
    "Zoom level for automatic zooms": "Zoomniveau for automatisk zoomniveauer",
    "Zoom out": "Zoom ud",
    "Zoom to layer extent": "Zoom hen til lag indhold",
    "Zoom to the next": "Zoom hen til næste",
    "Zoom to the previous": "Zoom hen til forrige",
    "Zoom to this feature": "Zoom ind til dette objekt",
    "Zoom to this place": "Zoom to this place",
    "attribution": "navngivelse",
    "by": "af",
    "display name": "visningsnavn",
    "height": "højde",
    "licence": "licens",
    "max East": "max Øst",
    "max North": "max Nord",
    "max South": "max Syd",
    "max West": "max Vest",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "næste",
    "previous": "forrige",
    "width": "bredde",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("da", locale);
L.setLocale("da");