var locale = {
    "Add symbol": "Προσθήκη συμβόλου ",
    "Allow scroll wheel zoom?": "Επέτρεψε ζουμ κύλισης",
    "Automatic": "Automatic",
    "Ball": "Ball",
    "Cancel": "Άκυρο ",
    "Caption": "Caption",
    "Change symbol": "Αλλαγή συμβόλου ",
    "Choose the data format": "Choose the data format",
    "Choose the layer of the feature": "Επιλέξτε το επίπεδο του στοιχείου",
    "Circle": "Κύκλος ",
    "Clustered": "Clustered",
    "Data browser": "Data browser",
    "Default": "Προεπιλογή ",
    "Default zoom level": "Default zoom level",
    "Default: name": "Default: name",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Επιθυμείτε την εμφάνιση χάρτη υπομνήματος ;",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Επιθυμείτε την εμφάνιση αναδυόμενης βάσης ;",
    "Do you want to display the scale control?": "Επιθυμείτε την εμφάνιση κλίμακας ;",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Ρίψη ",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Inherit",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "None",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup content template",
    "Set symbol": "Set symbol",
    "Side panel": "Side panel",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Table",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "color",
    "dash array": "dash array",
    "define": "define",
    "description": "description",
    "expanded": "expanded",
    "fill": "fill",
    "fill color": "fill color",
    "fill opacity": "fill opacity",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "inherit",
    "name": "name",
    "never": "never",
    "new window": "new window",
    "no": "όχι",
    "on hover": "on hover",
    "opacity": "opacity",
    "parent window": "parent window",
    "stroke": "stroke",
    "weight": "weight",
    "yes": "ναι",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# one hash for main heading",
    "## two hashes for second heading": "## two hashes for second heading",
    "### three hashes for third heading": "### three hashes for third heading",
    "**double star for bold**": "**double star for bold**",
    "*simple star for italic*": "*simple star for italic*",
    "--- for an horizontal rule": "--- for an horizontal rule",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Σχετικά",
    "Action not allowed :(": "Μη επιτρεπόμενη ενέργεια :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Προσθήκη επιπέδου",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Εξειδικευμένες ενέργειες ",
    "Advanced properties": "Εξειδικευμένα ιδιότητες ",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "All properties are imported.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Παρουσιάστηκε σφάλμα ",
    "Are you sure you want to cancel your changes?": "Είστε βέβαιος για το ότι θέλετε να ακυρώσετε τις αλλαγές σας;",
    "Are you sure you want to clone this map and all its datalayers?": "Είστε βέβαιος ότι θέλετε να κλωνοποιηθεί  αυτός ο χάρτης και όλα τα επίπεδα δεδομένων του;",
    "Are you sure you want to delete the feature?": "Είστε βέβαιος ότι θέλετε να διαγράφει αυτό το στοιχείο;",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Είστε βέβαιος ότι θέλετε να διαγραφεί αυτός ο χάρτης ;",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Κέντραρε το στοιχείο",
    "Browse data": "Περιήγηση δεδομένων ",
    "Cancel edits": "Ακύρωση επεξεργασίας ",
    "Center map on your location": "Κέντραρε τον χάρτη στη θέση σου ",
    "Change map background": "Αλλαγή χαρτογραφικού υποβάθρου ",
    "Change tilelayers": "Αλλαγή επιπέδου ",
    "Choose a preset": "Choose a preset",
    "Choose the format of the data to import": "Επιλέξτε τη μορφή των δεδομένων για εισαγωγή",
    "Choose the layer to import in": "Επιλέξτε το επίπεδο που θα γίνει η εισαγωγή ",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "Clone",
    "Clone of {name}": "Clone of {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Κλωνοποίηση αυτού του χάρτη",
    "Close": "Close",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Continue line": "Continue line",
    "Continue line (Ctrl-click)": "Continue line (Ctrl-click)",
    "Coordinates": "Coordinates",
    "Credits": "Credits",
    "Current view instead of default map view?": "Current view instead of default map view?",
    "Custom background": "Custom background",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Default properties",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Διαγραφή ",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Διαγραφή αυτού του στοιχείου ",
    "Delete this property on all the features": "Delete this property on all the features",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Directions from here",
    "Disable editing": "Απενεργοποίηση επεξεργασίας ",
    "Display measure": "Display measure",
    "Display on load": "Εμφάνιση κατά την φόρτωση ",
    "Download": "Download",
    "Download data": "Λήψη δεδομένων",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Σχεδιασμός γραμμής ",
    "Draw a marker": "Σχεδιασμός σημείου ",
    "Draw a polygon": "Σχεδιασμός πολυγώνου ",
    "Draw a polyline": "Σχεδιασμός σύνθετης γραμμής ",
    "Dynamic": "Δυναμική ",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Επεξεργασία ",
    "Edit feature's layer": "Επεξεργασία στοιχείων επιπέδου",
    "Edit map properties": "Επεξεργασία ιδιοτήτων χάρτη ",
    "Edit map settings": "Επεξεργασία ρυθμίσεων χάρτη",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Επεξεργασία του στοιχείου ",
    "Editing": "Editing",
    "Embed and share this map": "Ένθεση και διαμοιρασμός του χάρτη ",
    "Embed the map": "Embed the map",
    "Empty": "Empty",
    "Enable editing": "Ενεργοποίηση επεξεργασίας ",
    "Error in the tilelayer URL": "Error in the tilelayer URL",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filter…",
    "Format": "Μορφή",
    "From zoom": "Από μεγέθυνση ",
    "Full map data": "Full map data",
    "Go to «{feature}»": "πήγαινε στο  «{στοιχείο}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "Βοήθεια",
    "Hide controls": "Απόκρυψη εργαλείων ελέγχου ",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Πόσο απλοποιείται η συνθέτη γραμμή σε κάθε επίπεδο μεγέθυνσης (περισσότερο = ταχύτερη εκτέλεση και γενικότερη αποτύπωση, λιγότερο = περισσότερη ακρίβεια)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe export options",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Εισαγωγή ",
    "Import data": "Εισαγωγή δεδομένων ",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Layer",
    "Layer properties": "Layer properties",
    "Licence": "Άδεια",
    "Limit bounds": "Limit bounds",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link with text: [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Πιστοποιητικά δημιουργού υποβάθρου ",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Ο χάρτης του χρήστη δημοσιεύθηκε με άδεια ",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "Περισσότερα εργαλεία ",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Only visible features will be downloaded.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Προαιρετικό. Ίδιο χρώμα αν δεν διαμορφωθεί  ",
    "Optionnal.": "Προαιρετικό ",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Paste here your data": "Επικόλλησε εδώ τα δεδομένα σου ",
    "Please be sure the licence is compliant with your use.": "Παρακαλώ χρησιμοποιείστε άδεια που συμμορφώνετε με την χρήση σας ",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Please save the map before": "Please save the map before",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Problem in the response",
    "Problem in the response format": "Problem in the response format",
    "Properties imported:": "Properties imported:",
    "Property to use for sorting features": "Property to use for sorting features",
    "Provide an URL here": "Provide an URL here",
    "Proxy request": "Proxy request",
    "Remote data": "Απομακρυσμένα δεδομένα ",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Αποθήκευση",
    "Save anyway": "Save anyway",
    "Save current edits": "Save current edits",
    "Save this center and zoom": "Save this center and zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "See full screen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Short URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Show/hide layer",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Skipping unkown geometry.type: {type}",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Start editing",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop editing",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS format",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "The zoom and center have been setted.",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "To zoom",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Untitled layer",
    "Untitled map": "Untitled map",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Update permissions and editors",
    "Url": "Url",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "User interface options",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Zoom out",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Zoom to this feature",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "ύψος",
    "licence": "άδεια",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "επόμενο",
    "previous": "προηγούμενο",
    "width": "πλάτος",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("el", locale);
L.setLocale("el");