var locale = {
    "Add symbol": "シンボルを追加",
    "Allow scroll wheel zoom?": "マウスホイールでのスクロールを許可？",
    "Automatic": "自動",
    "Ball": "まち針",
    "Cancel": "キャンセル",
    "Caption": "表題",
    "Change symbol": "シンボル変更",
    "Choose the data format": "データ形式選択",
    "Choose the layer of the feature": "地物のレイヤを選択",
    "Circle": "円形",
    "Clustered": "クラスタ化",
    "Data browser": "データブラウザ",
    "Default": "デフォルト",
    "Default zoom level": "標準ズームレベル",
    "Default: name": "デフォルト: 名称",
    "Display label": "ラベルを表示",
    "Display the control to open OpenStreetMap editor": "OpenStreetMapエディタを起動するパネルを表示",
    "Display the data layers control": "データレイヤ操作パネルを表示",
    "Display the embed control": "サイトへのマップ埋め込みパネルを表示",
    "Display the fullscreen control": "フルスクリーンパネルを表示",
    "Display the locate control": "現在地パネルを表示",
    "Display the measure control": "縮尺パネルを表示",
    "Display the search control": "検索パネルを表示",
    "Display the tile layers control": "タイルレイヤパネルを表示",
    "Display the zoom control": "ズーム変更パネルを表示",
    "Do you want to display a caption bar?": "表題を表示しますか？",
    "Do you want to display a minimap?": "ミニマップを表示しますか？",
    "Do you want to display a panel on load?": "読み込み時にパネルを表示しますか？",
    "Do you want to display popup footer?": "フッタをポップアップしますか？",
    "Do you want to display the scale control?": "縮尺を表示しますか？",
    "Do you want to display the «more» control?": "«more»操作パネルを表示しますか？",
    "Drop": "しずく型",
    "GeoRSS (only link)": "GeoRSS (リンクのみ)",
    "GeoRSS (title + image)": "GeoRSS (タイトル+画像)",
    "Heatmap": "ヒートマップ",
    "Icon shape": "アイコン形状",
    "Icon symbol": "アイコンシンボル",
    "Inherit": "属性継承",
    "Label direction": "ラベルの位置",
    "Label key": "ラベル表示するキー",
    "Labels are clickable": "ラベルをクリックしてポップアップを表示",
    "None": "なし",
    "On the bottom": "下寄せ",
    "On the left": "左寄せ",
    "On the right": "右寄せ",
    "On the top": "上寄せ",
    "Popup content template": "ポップアップコンテンツのテンプレート",
    "Set symbol": "シンボルを設定",
    "Side panel": "サイドパネル",
    "Simplify": "簡略化",
    "Symbol or url": "シンボルまたはURL",
    "Table": "テーブル",
    "always": "常時",
    "clear": "クリア",
    "collapsed": "ボタン",
    "color": "色",
    "dash array": "破線表示",
    "define": "指定",
    "description": "概要",
    "expanded": "リスト",
    "fill": "塗りつぶし",
    "fill color": "塗りつぶし色",
    "fill opacity": "塗りつぶし透過度",
    "hidden": "隠す",
    "iframe": "iframe",
    "inherit": "属性継承",
    "name": "名称",
    "never": "表示しない",
    "new window": "新規ウィンドウ",
    "no": "いいえ",
    "on hover": "ホバー時",
    "opacity": "透過度",
    "parent window": "親ウィンドウ",
    "stroke": "ストローク",
    "weight": "線の太さ",
    "yes": "はい",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# ハッシュ1つで主な見出し",
    "## two hashes for second heading": "## ハッシュ2つで第二見出し",
    "### three hashes for third heading": "### ハッシュ3つで第三見出し",
    "**double star for bold**": "**アスタリスク2つで太字**",
    "*simple star for italic*": "*アスタリスク1つでイタリック体*",
    "--- for an horizontal rule": "--- 横方向の罫線",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "カンマで数字を区切り、ストロークの破線パターンを指定。 例: \"5, 10, 15\"",
    "About": "概要",
    "Action not allowed :(": "そのアクションは禁止されています :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "レイヤ追加",
    "Add a line to the current multi": "現在のマルチにラインを追加",
    "Add a new property": "プロパティ追加",
    "Add a polygon to the current multi": "現在のマルチにポリゴンを追加",
    "Advanced actions": "拡張アクション",
    "Advanced properties": "拡張プロパティ",
    "Advanced transition": "拡張トランジション",
    "All properties are imported.": "すべてのプロパティがインポートされました。",
    "Allow interactions": "インタラクションを許可",
    "An error occured": "エラーが発生しました",
    "Are you sure you want to cancel your changes?": "本当に編集内容を破棄しますか？",
    "Are you sure you want to clone this map and all its datalayers?": "すべてのデータレイヤを含むマップ全体を複製してよいですか？",
    "Are you sure you want to delete the feature?": "地物を削除してよいですか？",
    "Are you sure you want to delete this layer?": "本当にこのレイヤを削除してよいですか？",
    "Are you sure you want to delete this map?": "本当にこのマップを削除してよいですか？",
    "Are you sure you want to delete this property on all the features?": "すべての地物からこのプロパティを削除します。よろしいですか？",
    "Are you sure you want to restore this version?": "本当にこのバージョンを復元してよいですか？",
    "Attach the map to my account": "マップを自分のアカウントに関連付ける",
    "Auto": "自動",
    "Autostart when map is loaded": "マップ読み込み時に自動で開始",
    "Bring feature to center": "この地物を中心に表示",
    "Browse data": "データ内容表示",
    "Cancel edits": "編集を破棄",
    "Center map on your location": "閲覧者の位置をマップの中心に設定",
    "Change map background": "背景地図を変更",
    "Change tilelayers": "タイルレイヤの変更",
    "Choose a preset": "プリセット選択",
    "Choose the format of the data to import": "インポートデータ形式を選択",
    "Choose the layer to import in": "インポート対象レイヤ選択",
    "Click last point to finish shape": "クリックでシェイプの作成を終了",
    "Click to add a marker": "クリックでマーカー追加",
    "Click to continue drawing": "クリックで描画を継続",
    "Click to edit": "クリックで編集",
    "Click to start drawing a line": "クリックでラインの描画開始",
    "Click to start drawing a polygon": "クリックでポリゴンの描画開始",
    "Clone": "複製",
    "Clone of {name}": "{name}の複製",
    "Clone this feature": "この地物を複製",
    "Clone this map": "マップを複製",
    "Close": "閉じる",
    "Clustering radius": "クラスタ包括半径",
    "Comma separated list of properties to use when filtering features": "地物をフィルタする際に利用する、カンマで区切ったプロパティのリスト",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "カンマ、タブ、セミコロンなどで区切られた値。SRSはWGS84が適用されます。ポイントのジオメトリのみがインポート対象です。インポートを行なう際は、カラムの先頭行を対象に «lat» と «lon» という文字列が検索されます。検索は行の最初から順に行われ、大文字と小文字は区別されません。その他のすべてのカラムは、プロパティとしてインポートされます。",
    "Continue line": "ラインを延長",
    "Continue line (Ctrl-click)": "ラインを延長(Ctrl-クリック)",
    "Coordinates": "位置情報",
    "Credits": "制作",
    "Current view instead of default map view?": "デフォルトのマップ表示から現在の表示に切り替えますか？",
    "Custom background": "独自背景",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "標準のポップアップオプション",
    "Default properties": "標準のプロパティ",
    "Default shape properties": "標準のシェイプ表示プロパティ",
    "Define link to open in a new window on polygon click.": "ポリゴンクリック時にリンクを新しいウィンドウで開く",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "削除",
    "Delete all layers": "すべてのレイヤを削除",
    "Delete layer": "レイヤを削除",
    "Delete this feature": "地物を削除",
    "Delete this property on all the features": "すべての地物からこのプロパティを削除",
    "Delete this shape": "このシェイプを削除",
    "Delete this vertex (Alt-click)": "このポイントを削除(Altを押しながらクリック)",
    "Directions from here": "ここからの距離",
    "Disable editing": "編集を終了",
    "Display measure": "Display measure",
    "Display on load": "読み込み時に表示",
    "Download": "ダンロード",
    "Download data": "データダウンロード",
    "Drag to reorder": "ドラッグして並べ替える",
    "Draw a line": "ラインを描く",
    "Draw a marker": "マーカーを配置",
    "Draw a polygon": "ポリゴンを描く",
    "Draw a polyline": "ポリゴンを描く",
    "Dynamic": "ダイナミック",
    "Dynamic properties": "動的なプロパティ",
    "Edit": "編集",
    "Edit feature's layer": "地物レイヤー編集",
    "Edit map properties": "マッププロパティを編集",
    "Edit map settings": "マップ設定を編集",
    "Edit properties in a table": "表形式でプロパティを編集",
    "Edit this feature": "地物を編集",
    "Editing": "編集",
    "Embed and share this map": "サイトへのマップ埋め込みと共有",
    "Embed the map": "マップ埋め込み",
    "Empty": "内容なし",
    "Enable editing": "編集を有効化",
    "Error in the tilelayer URL": "タイルレイヤのURLに誤りがあります",
    "Error while fetching {url}": "{url} の取得エラー",
    "Exit Fullscreen": "フルスクリーン表示を解除",
    "Extract shape to separate feature": "シェイプを複数の地物に変換",
    "Fetch data each time map view changes.": "地図表示が変更されたらデータを再取得する",
    "Filter keys": "フィルタに使うキー",
    "Filter…": "フィルタ...",
    "Format": "フォーマット",
    "From zoom": "表示開始するズームレベル",
    "Full map data": "Full map data",
    "Go to «{feature}»": "«{feature}»を表示",
    "Heatmap intensity property": "ヒートマップ強調設定",
    "Heatmap radius": "ヒートマップ包括半径",
    "Help": "ヘルプ",
    "Hide controls": "操作パネルを非表示",
    "Home": "ホーム",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "各ズームレベルでのポリゴン簡略化 (more = パフォーマンスと滑らかさ重視, less = 正確さ重視)",
    "If false, the polygon will act as a part of the underlying map.": "無効にした場合、ポリゴンは背景地図の一部として動作します。",
    "Iframe export options": "Iframeエクスポートオプション",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframeの縦幅を指定(ピクセル): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframeの縦幅および横幅を指定(ピクセル): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "画像の横幅カスタム値 (px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "画像:  {{http://image.url.com}}",
    "Import": "インポート",
    "Import data": "データインポート",
    "Import in a new layer": "新規レイヤをインポート",
    "Imports all umap data, including layers and settings.": "umapのデータをすべてインポート(レイヤ、設定を含む)",
    "Include full screen link?": "フルスクリーンのリンクを含める？",
    "Interaction options": "ポップアップオプション",
    "Invalid umap data": "不正なumapデータ",
    "Invalid umap data in {filename}": "{filename} に不正なumapデータ",
    "Keep current visible layers": "現在表示しているレイヤを保持",
    "Latitude": "緯度",
    "Layer": "レイヤ",
    "Layer properties": "レイヤープロパティ",
    "Licence": "ライセンス",
    "Limit bounds": "表示範囲の制限",
    "Link to…": "リンク",
    "Link with text: [[http://example.com|text of the link]]": "テキストとリンク: [[http://example.com|リンクのテキスト]]",
    "Long credits": "正式なクレジット",
    "Longitude": "経度",
    "Make main shape": "メインシェイプを作成",
    "Manage layers": "レイヤ管理",
    "Map background credits": "背景地図クレジット",
    "Map has been attached to your account": "あなたのアカウントにマップが関連付けられました",
    "Map has been saved!": "地図の保存完了",
    "Map user content has been published under licence": "マップユーザコンテンツのライセンス",
    "Map's editors": "マップの編集者",
    "Map's owner": "マップの所有者",
    "Merge lines": "ラインを結合",
    "More controls": "詳細操作パネル",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "CSSで有効な値を指定してください (例: DarkBlue, #123456など)",
    "No licence has been set": "ライセンス指定がありません",
    "No results": "検索結果なし",
    "Only visible features will be downloaded.": "表示中の地物のみがダウンロードされます。",
    "Open download panel": "ダウンロードパネルを開く",
    "Open link in…": "リンクの開き方",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "現在表示中の領域をエディタで編集し、より正確なデータをOpenStreetMapへ書き込む",
    "Optional intensity property for heatmap": "ヒートマップ強調表示オプション",
    "Optional. Same as color if not set.": "オプション。設定がない場合、色指定と同様",
    "Optionnal.": "オプション",
    "Override clustering radius (default 80)": "クラスタ包括半径を上書き (基本値 80)",
    "Override heatmap radius (default 25)": "ヒートマップ包括半径を上書き (基本値 25)",
    "Paste here your data": "手持ちのデータからペースト",
    "Please be sure the licence is compliant with your use.": "利用目的に沿ったライセンスを選択するようにしてください",
    "Please choose a format": "フォーマットを指定してください",
    "Please enter the name of the property": "プロパティの名称を入力してください",
    "Please enter the new name of this property": "このプロパティに新しい名称を付与してください",
    "Please save the map before": "いちどマップの保存を行ってください",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "レスポンスに問題があります",
    "Problem in the response format": "レスポンス形式に問題があります",
    "Properties imported:": "インポートされたプロパティ:",
    "Property to use for sorting features": "地物並び替え時のプロパティ",
    "Provide an URL here": "URLを入力してください",
    "Proxy request": "プロキシリクエスト",
    "Remote data": "サイト外のデータ",
    "Remove shape from the multi": "マルチからシェイプを削除",
    "Rename this property on all the features": "すべての地物に対してこのプロパティ名を変更",
    "Replace layer content": "レイヤ内容を差し替える",
    "Restore this version": "このバージョンを復元する",
    "Save": "保存",
    "Save anyway": "保存を再実行",
    "Save current edits": "編集内容を保存",
    "Save this center and zoom": "地図中心点とズームレベルを保存",
    "Save this location as new feature": "この場所を新しい地物として保存",
    "Search a place name": "場所の名前を検索",
    "Search location": "地名で検索",
    "Secret edit link is:<br>{link}": "非公開の編集用リンク:<br>{link}",
    "See all": "すべて表示",
    "See data layers": "データレイヤを見る",
    "See full screen": "フルスクリーン表示",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "シェイプ表示プロパティ",
    "Short URL": "短縮URL",
    "Short credits": "短縮表示板クレジット",
    "Show/hide layer": "レイヤ表示/非表示",
    "Simple link: [[http://example.com]]": "シンプルリンク: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "不明なジオメトリタイプ {type}をスキップしました",
    "Slideshow": "スライドショー",
    "Smart transitions": "Smart transitions",
    "Sort key": "並び替えに使うキー",
    "Split line": "ラインを分割",
    "Start a hole here": "この部分に穴を作成",
    "Start editing": "編集開始",
    "Start slideshow": "スライドショーを開始",
    "Stop editing": "編集中断",
    "Stop slideshow": "スライドショーを停止",
    "Supported scheme": "対応スキーマ",
    "Supported variables that will be dynamically replaced": "対応する動的な変数",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "シンボルにはユニコード文字やURLを使えます。地物のプロパティを変数として使うこともできます。例: \"http://myserver.org/images/{name}.png\" であれば、{name}の部分はそれぞれのマーカーの\"name\"の値で置き換えられます。",
    "TMS format": "TMSフォーマット",
    "Text color for the cluster label": "クラスタラベルのテキスト色",
    "Text formatting": "テキスト形式",
    "The name of the property to use as feature label (ex.: \"nom\")": "地物のラベルとして用いるプロパティ名を入力する",
    "The zoom and center have been setted.": "ズームと地図中心点の設定完了",
    "To use if remote server doesn't allow cross domain (slower)": "外部サーバがクロスドメインを許可していない場合に使用します (処理速度低下)",
    "To zoom": "非表示にするズームレベル",
    "Toggle edit mode (shift-click)": "編集モードを切り替える(シフトキーを押しながらクリック)",
    "Transfer shape to edited feature": "シェイプを編集済み地物へ変換",
    "Transform to lines": "ラインへ変換",
    "Transform to polygon": "ポリゴンへ変換",
    "Type of layer": "レイヤタイプ",
    "Unable to detect format of file {filename}": "ファイル形式を認識できません {filename}",
    "Untitled layer": "名称未定レイヤ",
    "Untitled map": "名称未定マップ",
    "Update permissions": "権限設定を更新",
    "Update permissions and editors": "権限設定とエディタを更新",
    "Url": "URL",
    "Use current bounds": "現在の表示範囲を利用",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "波括弧で地物プロパティをくくると(例： &#123;name&#125;)、対応する値に動的に置き換えられます。",
    "User content credits": "ユーザ作成データのクレジット",
    "User interface options": "ユーザインターフェースオプション",
    "Versions": "バージョン",
    "View Fullscreen": "フルスクリーン表示",
    "Where do we go from here?": "ここからどこへ向かいますか？",
    "Whether to display or not polygons paths.": "ポリゴンの外周線を表示するかどうか",
    "Whether to fill polygons with color.": "ポリゴンを塗りつぶすかどうか",
    "Who can edit": "編集できる人",
    "Who can view": "閲覧できる人",
    "Will be displayed in the bottom right corner of the map": "地図の右下に表示されます",
    "Will be visible in the caption of the map": "地図の脚注として表示されます",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "おおおっと！ 他の誰かがデータを編集したようです。あなたの編集内容をもう一度保存することもできますが、その場合、他の誰かが行った編集は削除されます。",
    "You have unsaved changes.": "編集が保存されていません",
    "Zoom in": "ズームイン",
    "Zoom level for automatic zooms": "自動ズーム時のズームレベル",
    "Zoom out": "ズームアウト",
    "Zoom to layer extent": "データがある位置を表示",
    "Zoom to the next": "次にズーム",
    "Zoom to the previous": "前にズーム",
    "Zoom to this feature": "この地物にズーム",
    "Zoom to this place": "この場所にズーム",
    "attribution": "著作権表示",
    "by": "by",
    "display name": "表示名",
    "height": "縦幅",
    "licence": "ライセンス",
    "max East": "東端",
    "max North": "北端",
    "max South": "南端",
    "max West": "西端",
    "max zoom": "最大ズーム",
    "min zoom": "最小ズーム",
    "next": "次へ",
    "previous": "前へ",
    "width": "横幅",
    "{count} errors during import: {message}": "インポートで {count} 個のエラー: {message}",
    "Measure distances": "距離を計測",
    "NM": "NM",
    "kilometers": "キロメートル",
    "km": "km",
    "mi": "マイル",
    "miles": "マイル",
    "nautical miles": "海里",
    "{area} acres": "{area} エイカー",
    "{area} ha": "{area} ヘクタール",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} 平方マイル",
    "{area} yd&sup2;": "{area} 平方ヤード",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} マイル",
    "{distance} yd": "{distance} ヤード",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("ja", locale);
L.setLocale("ja");