{% load  i18n %}

<footer>
    <a href="/" class="branding">umap</a> an OpenStreetMap project (version {{ UMAP_VERSION }})
    {% get_language_info_list for LANGUAGES as languages %}
    <form action="{% url "set_language" %}" method="post" class="i18n_switch">
        {% csrf_token %}
        <select name="language" onchange="this.form.submit()">
        {% for language in languages %}
        <option value="{{ language.code }}"
            {% if language.code == LANGUAGE_CODE %}selected="selected"{% endif %}>
            {{ language.name_local }}
        </option>
        {% endfor %}
        </select>
    </form>
</footer>
