var locale = {
    "Add symbol": "Aggiungi un simbolo",
    "Allow scroll wheel zoom?": "Abilitare la rotellina del mouse per lo zoom?",
    "Automatic": "Automatic",
    "Ball": "Palla",
    "Cancel": "Annulla",
    "Caption": "Didascalia",
    "Change symbol": "Cambia il simbolo",
    "Choose the data format": "Scegli il formato dati",
    "Choose the layer of the feature": "Scegli il layer della geometria",
    "Circle": "Cerchio",
    "Clustered": "Raggruppata",
    "Data browser": "Visualizza i dati",
    "Default": "Predefinito",
    "Default zoom level": "Default zoom level",
    "Default: name": "Predefinito: nome",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Visualizza una didascalia?",
    "Do you want to display a minimap?": "Visualizzare una mappa panoramica?",
    "Do you want to display a panel on load?": "Visualizza un panello al caricamento?",
    "Do you want to display popup footer?": "Visualizzare la finestra di popup a piè pagina?",
    "Do you want to display the scale control?": "Visualizzare la scala?",
    "Do you want to display the «more» control?": "Vuoi visualizzare il controllo \"altro\"?",
    "Drop": "Goccia",
    "GeoRSS (only link)": "GeoRSS (solo il link)",
    "GeoRSS (title + image)": "GeoRSS (titolo + immagine)",
    "Heatmap": "Mappa di densità (heatmap)",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Eredita",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Nulla",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Template del contenuto del popup",
    "Set symbol": "Set symbol",
    "Side panel": "Pannello laterale",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Tabella",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "colore",
    "dash array": "tratteggio",
    "define": "define",
    "description": "descrizione",
    "expanded": "expanded",
    "fill": "riempimento",
    "fill color": "colore di riempimento",
    "fill opacity": "opacità riempimento",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "eredita",
    "name": "nome",
    "never": "never",
    "new window": "new window",
    "no": "non",
    "on hover": "on hover",
    "opacity": "opacità",
    "parent window": "parent window",
    "stroke": "tratto",
    "weight": "peso",
    "yes": "sì",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# un cancelleto per l'intestazione principale",
    "## two hashes for second heading": "## due cancelletti per le intestazioni di secondo livello",
    "### three hashes for third heading": "### tre cancelletti per intestazione di terzo livello",
    "**double star for bold**": "**due asterischi per il testo marcato**",
    "*simple star for italic*": "*asterisco per l'italico*",
    "--- for an horizontal rule": "--- per una linea orizzontale",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Informazioni",
    "Action not allowed :(": "Azione non permessa :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Aggiungi un layer",
    "Add a line to the current multi": "Aggiungi una linea a quelle correnti",
    "Add a new property": "Aggiungi una nuova proprietà",
    "Add a polygon to the current multi": "Aggiungi un poligono a quell correnti",
    "Advanced actions": "Azioni avanzate",
    "Advanced properties": "Proprietà avanzate",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Tutte le proprietà sono state importate.",
    "Allow interactions": "Allow interactions",
    "An error occured": "Si è verificato un errore",
    "Are you sure you want to cancel your changes?": "Si vuole realmente annullare le modifiche fatte?",
    "Are you sure you want to clone this map and all its datalayers?": "Confermi di duplicare questa mappa e tutti i suoi livelli?",
    "Are you sure you want to delete the feature?": "Si è sicuri di voler cancellare questa geometria?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Si è certi di voler eliminare questa mappa?",
    "Are you sure you want to delete this property on all the features?": "Si è sicuri di voler cancellare questa proprietà per ogni geometria?",
    "Are you sure you want to restore this version?": "Si vuole veramente ripristinare questa versione?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Porta la geometria al centro",
    "Browse data": "Visualizza i dati",
    "Cancel edits": "Annulla le modifiche",
    "Center map on your location": "Centra la mappa sulla tua posizione",
    "Change map background": "Cambia la mappa di sfondo",
    "Change tilelayers": "Cambia i livelli di sfondo",
    "Choose a preset": "Seleziona una preimpostazione",
    "Choose the format of the data to import": "Seleziona il formato dei dati da importare",
    "Choose the layer to import in": "Seleziona su quale livello fare l'importazione",
    "Click last point to finish shape": "Click su ultimo punto per completare la geometria",
    "Click to add a marker": "Clicca per aggiungere un marcatore",
    "Click to continue drawing": "Clic per continuare a disegnare",
    "Click to edit": "Clic per la modifica",
    "Click to start drawing a line": "Clic per iniziare a disegnare una linea",
    "Click to start drawing a polygon": "Clicca per iniziare a disegnare un poligono",
    "Clone": "Clona",
    "Clone of {name}": "Clone di {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Duplica questa mappa",
    "Close": "Chiudi",
    "Clustering radius": "Raggio del raggruppamento",
    "Comma separated list of properties to use when filtering features": "Lista di proprietà separate da virgola da utilizzare per filtrare le geometrie",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valori separati da virgola, tabulatore o punto e virgola. Il sistema di riferimento spaziale implementato è WGS84. Vengono importati solo punti. La funzione di importazione va a cercare nell'intestazione le colonne  «lat» e «lon» indifferentemente se scritte in maiuscolo o minuscolo. Tutte le altre colonne sono importate come proprietà.",
    "Continue line": "Linea continua",
    "Continue line (Ctrl-click)": "Continua linea (Ctrl-click)",
    "Coordinates": "Coordinate",
    "Credits": "Ringraziamenti",
    "Current view instead of default map view?": "Vista attuale invece che quella della mappa preimpostata?",
    "Custom background": "Sfondo personalizzato",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Proprietà preimpostate",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Cancella",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Cancella questa geometria",
    "Delete this property on all the features": "Cancella questa proprietà in tutte le geometrie",
    "Delete this shape": "Cancella questa geometria",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Indicazioni stradali da qui",
    "Disable editing": "Disabilita la modifica",
    "Display measure": "Display measure",
    "Display on load": "Mostra durante il caricamento",
    "Download": "Scarica",
    "Download data": "Download dei dati",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Disegna una linea",
    "Draw a marker": "Aggiungi un marcatore",
    "Draw a polygon": "Disegna un poligono",
    "Draw a polyline": "Disegna una polilinea",
    "Dynamic": "Dinamico",
    "Dynamic properties": "Proprietà dinamiche",
    "Edit": "Modifica",
    "Edit feature's layer": "Modifica le geometrie del layer",
    "Edit map properties": "Modifica le proprietà della mappa",
    "Edit map settings": "Modifica le impostazioni della mappa",
    "Edit properties in a table": "Modifica le proprietà in una tabella",
    "Edit this feature": "Modifica questa geometria",
    "Editing": "Modifica",
    "Embed and share this map": "Includi e condividi questa mappa",
    "Embed the map": "Includi la mappa",
    "Empty": "Vuoto",
    "Enable editing": "Abilita la modifica",
    "Error in the tilelayer URL": "Errore nell'URL nel servizio di tile",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Dividi la geometria in geometrie separate",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filtro...",
    "Format": "Formato",
    "From zoom": "Dallo zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Vai a «{feature}»",
    "Heatmap intensity property": "Proprietà intensità mappa di densità",
    "Heatmap radius": "Raggio mappa di densità",
    "Help": "Aiuto",
    "Hide controls": "Nascondi controlli",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Quanto vuoi semplificare la polilinea per ogni zoom (più = maggiori perfromance a aspetto più semplificato, meno = maggior dettaglio)",
    "If false, the polygon will act as a part of the underlying map.": "Se falso, il poligono agirà come parte della mappa sottostante.",
    "Iframe export options": "opzioni di esportazione iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altezza (in px) personalizzata: {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Immagine con larghezza personalizzata (width) (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Immagini: {{http://image.url.com}}",
    "Import": "Importa",
    "Import data": "Importa dati",
    "Import in a new layer": "Importa in un nuovo layer",
    "Imports all umap data, including layers and settings.": "importa tutti i dati di umap compresi layer e le impostazioni",
    "Include full screen link?": "inserire link per la vista a schemo intero?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "dati di umap non validi",
    "Invalid umap data in {filename}": "dati umap non validi nel file {filename}",
    "Keep current visible layers": "Mantieni i livelli attualmente visibili",
    "Latitude": "Latitudine",
    "Layer": "Layer",
    "Layer properties": "Proprietà del layer",
    "Licence": "Licenza",
    "Limit bounds": "Limiti di confine",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link con testo: [[http://example.com|testo del link]]",
    "Long credits": "Ringraziamenti estesi",
    "Longitude": "Longitudine",
    "Make main shape": "Genera geometria generale",
    "Manage layers": "Manage layers",
    "Map background credits": "Riconoscimenti per la mappa di sfondo",
    "Map has been attached to your account": "La mappa è stata associata al tuo account",
    "Map has been saved!": "La mappa è stata salvata",
    "Map user content has been published under licence": "I contenuti della mappa sono rilasciati secondo la licenza",
    "Map's editors": "Editor della mappa",
    "Map's owner": "Proprietario della mappa",
    "Merge lines": "Unisci linee",
    "More controls": "Maggiori controlli",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "Non è ancora stata impostata una licenza",
    "No results": "No results",
    "Only visible features will be downloaded.": "Saranno scaricate solo le geoemtrie visibili.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Apri quest'area della mappa nell'editor in modo da fornire dati più accurati in OpenStreeetMap",
    "Optional intensity property for heatmap": "Proprietà opzionale per la mappa di densità",
    "Optional. Same as color if not set.": "Opzionale. Stesso colore se non assegnato.",
    "Optionnal.": "Opzionale",
    "Override clustering radius (default 80)": "Sovrascrivi raggio di raggruppamento (predefinito 80)",
    "Override heatmap radius (default 25)": "Sovrascrivi raggio mappa di intensità (predefinito 25)",
    "Paste here your data": "Incolla i tuoi dati qui",
    "Please be sure the licence is compliant with your use.": "Si prega di verificare che la licenza è compatibile con quella in uso.",
    "Please choose a format": "Scegliere un formato",
    "Please enter the name of the property": "Inserire il nome della proprietà",
    "Please enter the new name of this property": "Inserire il nuovo nome per questa proprietà",
    "Please save the map before": "Per favore, prima, salva la mappa",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Basato su <a href=\"{leaflet}\">Leaflet</a> e <a href=\"{django}\">Django</a>, uniti nel <a href=\"{umap}\">progetto uMap</a>.",
    "Problem in the response": "Problema nella risposta",
    "Problem in the response format": "Problema nel formato della risposta",
    "Properties imported:": "Proprietà importate:",
    "Property to use for sorting features": "Proprietà da utilizzare per ordinare gli oggetti",
    "Provide an URL here": "Aggiungi una URL qui",
    "Proxy request": "Richiesta proxy",
    "Remote data": "Dati remoti",
    "Remove shape from the multi": "Rimuovi geometria dalle altre",
    "Rename this property on all the features": "Rinomina questa proprietà in tutti gli oggetti",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Ripristina questa versione",
    "Save": "Salva",
    "Save anyway": "Salva comunque",
    "Save current edits": "Salva le modifiche effettuate",
    "Save this center and zoom": "Salva il centro e lo zoom",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Cerca il nome di un posto",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Vedi tutto",
    "See data layers": "See data layers",
    "See full screen": "Visualizza a schermo intero",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "URL breve",
    "Short credits": "Mostra i ringraziamenti",
    "Show/hide layer": "Mostra/nascondi layer",
    "Simple link: [[http://example.com]]": "Link semplice: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Ignorare le geometrie sconosciute di tipo: {type}",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Dividi linea",
    "Start a hole here": "Comincia un buco qui",
    "Start editing": "Avvia modifica",
    "Start slideshow": "Avvia slideshow",
    "Stop editing": "Ferma la modifica",
    "Stop slideshow": "Ferma slideshow",
    "Supported scheme": "Schema supportato",
    "Supported variables that will be dynamically replaced": "Variabili supportate che verranno cambiate dinamicamente",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "formato TMS",
    "Text color for the cluster label": "Colore di testo per l'etichetta del raggruppamento",
    "Text formatting": "Formattazione testo",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Il livello di zoom e il centro sono stati impostati.",
    "To use if remote server doesn't allow cross domain (slower)": "Da utilizzare se il server remoto non permette l'accesso incrociato ai domini (lento)",
    "To zoom": "Allo zoom",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Trasforma la geometria in una modificabile",
    "Transform to lines": "Trasforma in linee",
    "Transform to polygon": "Trasforma in poligono",
    "Type of layer": "Tipo di layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Layer senza nome",
    "Untitled map": "Mappa senza nome",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Cambia i permessi e gli editori",
    "Url": "Url",
    "Use current bounds": "Utilizza l'area in uso",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Specificando le proprietà degli oggetti attraverso le parentesi graffe es. &#123;name&#125; queste saranno automaticamente sostituite con i valore corrispondenti",
    "User content credits": "Riconoscimenti ai contenuti utente",
    "User interface options": "Opzioni interfaccia utente",
    "Versions": "Versioni",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Da dove ci spostiamo da qui?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Chi può modificare",
    "Who can view": "Chi può vedere",
    "Will be displayed in the bottom right corner of the map": "Sarà visualizzato in un angolo in basso a destra sulla mappa",
    "Will be visible in the caption of the map": "Sarà visibile nella didascalia della mappa",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "OPS! Qualcun altro sembra aver modificato i dati. È possibile comunque salvare, ma questo cancellerà le modifiche apportate da altri.",
    "You have unsaved changes.": "Ci sono delle modifiche che non sono state ancora salvate.",
    "Zoom in": "Ingrandisci",
    "Zoom level for automatic zooms": "Livelli di zoom per zoom automatici",
    "Zoom out": "Rimpicciolisci",
    "Zoom to layer extent": "Zoom alla larghezza massima del layer",
    "Zoom to the next": "Zoom sul prossimo",
    "Zoom to the previous": "Zoom sul precedente",
    "Zoom to this feature": "Zoom su questa geometria",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribuzione",
    "by": "di",
    "display name": "visualizza il nome",
    "height": "altezza",
    "licence": "licenza",
    "max East": "max Est",
    "max North": "max Nord",
    "max South": "max Sud",
    "max West": "max Ovest",
    "max zoom": "zoom massimo",
    "min zoom": "zoom minimo",
    "next": "prossimo",
    "previous": "precedente",
    "width": "larghezza",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "chilometri",
    "km": "km",
    "mi": "mi",
    "miles": "miglia",
    "nautical miles": "miglia nautiche",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("it", locale);
L.setLocale("it");