{% extends "umap/content.html" %}

{% load i18n %}

{% block content %}
  <h2 class="section">{% trans "Password change successful" %}</h2>
  <p>{% trans "Your password was changed." %}</p>
  <p><a href="{% url 'home' %}">Home</a></p>
{% endblock content %}
