var locale = {
    "Add symbol": "Dodaj symbol",
    "Allow scroll wheel zoom?": "Pozwalać na przybliżanie kółkiem?",
    "Automatic": "Automatic",
    "Ball": "Piłka",
    "Cancel": "Anuluj",
    "Caption": "Podpis",
    "Change symbol": "Zmień symbol",
    "Choose the data format": "Wybierz format danych",
    "Choose the layer of the feature": "Wybierz warstwę obiektu",
    "Circle": "Kółko",
    "Clustered": "Zgrupowane",
    "Data browser": "Przeglądanie danych",
    "Default": "Domyślne",
    "Default zoom level": "Domyślne przybliżenie",
    "Default: name": "Domyślnie: name",
    "Display label": "Wyświetl etykietę",
    "Display the control to open OpenStreetMap editor": "Wyświetlaj panel otwierający edytor OSM",
    "Display the data layers control": "Wyświetlaj panel warstw z danymi",
    "Display the embed control": "Wyświetlaj panel sterujący osadzaniem",
    "Display the fullscreen control": "Wyświetlaj panel widoku pełnoekranowego",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Wyświetlaj panel miarek",
    "Display the search control": "Wyświetlaj panel wyszukiwania",
    "Display the tile layers control": "Wyświetlaj panel warstw kafelków",
    "Display the zoom control": "Wyświetlaj panel sterujący powiększeniem",
    "Do you want to display a caption bar?": "Chcesz wyświetlić pasek z nagłówkiem?",
    "Do you want to display a minimap?": "Chcesz wyświetlać małą mapę?",
    "Do you want to display a panel on load?": "Chcesz wyświetlić panel po załadowaniu?",
    "Do you want to display popup footer?": "Chcesz wyświetlacz stopkę dymka?",
    "Do you want to display the scale control?": "Chcesz wyświetlać kontrolkę ze skalą?",
    "Do you want to display the «more» control?": "Chcesz wyświetlić «więcej» kontrolek?",
    "Drop": "Wyrzuć",
    "GeoRSS (only link)": "GeoRSS (tylko link)",
    "GeoRSS (title + image)": "GeoRSS (tytuł i obrazek)",
    "Heatmap": "Mapa cieplna",
    "Icon shape": "Kształt ikony",
    "Icon symbol": "Symbol ikony",
    "Inherit": "Dziedziczne",
    "Label direction": "Kierunek etykiety",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "Brak",
    "On the bottom": "Na dole",
    "On the left": "Po lewej",
    "On the right": "Po prawej",
    "On the top": "Na górze",
    "Popup content template": "Szablon treści dymka",
    "Set symbol": "Set symbol",
    "Side panel": "Panel boczny",
    "Simplify": "Uprość",
    "Symbol or url": "Symbol or url",
    "Table": "Tabela",
    "always": "zawsze",
    "clear": "wyczyść",
    "collapsed": "collapsed",
    "color": "kolor",
    "dash array": "przerywana linia",
    "define": "określ",
    "description": "opis",
    "expanded": "expanded",
    "fill": "wypełnienie",
    "fill color": "kolor wypełnienia",
    "fill opacity": "stopień wypełnienia",
    "hidden": "ukryte",
    "iframe": "iframe",
    "inherit": "dziedziczny",
    "name": "nazwa",
    "never": "nigdy",
    "new window": "nowe okno",
    "no": "nie",
    "on hover": "on hover",
    "opacity": "przeźroczystość",
    "parent window": "parent window",
    "stroke": "obramowanie",
    "weight": "waga",
    "yes": "tak",
    "{delay} seconds": "{opóźnienie} w sekundach",
    "# one hash for main heading": "# jeden krzyżyk - nagłówek pierwszego poziomu",
    "## two hashes for second heading": "# dwa krzyżyki - nagłówek drugiego poziomu",
    "### three hashes for third heading": "# trzy krzyżyki - nagłówek trzeciego poziomu",
    "**double star for bold**": "**podwójna gwiazdka do pogrubienia**",
    "*simple star for italic*": "*pojedyncza gwiazdka do pochylenia*",
    "--- for an horizontal rule": "--- dla poziomej linii",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Informacje",
    "Action not allowed :(": "Operacja niedozwolona :(",
    "Activate slideshow mode": "Aktywuj pokaz slajdów",
    "Add a layer": "Dodaj warstwę",
    "Add a line to the current multi": "Dodaj linie do wybranego multipoligonu",
    "Add a new property": "Dodaj nową właściwość",
    "Add a polygon to the current multi": "Dodaj poligon do wybranego multipoligonu",
    "Advanced actions": "Zaawansowane operacje",
    "Advanced properties": "Zaawansowane właściwości",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Zaimportowano wszystkie właściwości",
    "Allow interactions": "Zezwalaj na interakcję",
    "An error occured": "Wystąpił błąd",
    "Are you sure you want to cancel your changes?": "Na pewno chcesz porzucić swoje zmiany?",
    "Are you sure you want to clone this map and all its datalayers?": "Na pewno chcesz sklonować tą mapę razem z jej warstwami?",
    "Are you sure you want to delete the feature?": "Na pewno chcesz usunąć obiekt?",
    "Are you sure you want to delete this layer?": "Czy jesteś pewien, że chcesz usunąć tą warstwę?",
    "Are you sure you want to delete this map?": "Na pewno chcesz usunąć tą mapę?",
    "Are you sure you want to delete this property on all the features?": "Na pewno chcesz usunąć tę właściwość we wszystkich obiektach?",
    "Are you sure you want to restore this version?": "Na pewno chcesz przywrócić tą wersję?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Przenieś obiekt do środka",
    "Browse data": "Przeglądaj dane",
    "Cancel edits": "Anuluj edycje",
    "Center map on your location": "Wyśrodkuje mapę na twojej lokalizacji",
    "Change map background": "Zmień podkład mapy",
    "Change tilelayers": "Zmień podkład",
    "Choose a preset": "Wybierz szablon",
    "Choose the format of the data to import": "Wybierz format importowanych danych",
    "Choose the layer to import in": "Wybierz warstwę docelową",
    "Click last point to finish shape": "Kliknij w ostatni punkt aby zakończyć rysowanie",
    "Click to add a marker": "Kliknij aby dodać znacznik",
    "Click to continue drawing": "Kliknij aby kontynuować rysowanie",
    "Click to edit": "Kliknij aby edytować",
    "Click to start drawing a line": "Kliknij aby zacząć rysować linię",
    "Click to start drawing a polygon": "Kliknij aby zacząć rysować obszar",
    "Clone": "Klonowanie",
    "Clone of {name}": "Sklonowane z {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Sklonuj mapę",
    "Close": "Zamknij",
    "Clustering radius": "Promień grupowania",
    "Comma separated list of properties to use when filtering features": "Lista właściwości oddzielona przecinkiem do używania przy sortowaniu obiektów",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Wartości powinny być oddzielone przecinkiem, średnikiem lub znakiem tabulacji. Układ współrzędnych WGS84 jest wymagany. Tylko geometrie typu Punkt zostaną zaimportowane. Import sprawdzi nagłówki kolumn czy zawierają \"lat\" i \"lon\" na początku nagłówka, wielkość liter nie ma znaczenia. Wszystkie inne kolumny zostaną zaimportowane jako właściwości tych punktów.",
    "Continue line": "Dokończ linię",
    "Continue line (Ctrl-click)": "Dokończ linię (Ctrl+kliknij)",
    "Coordinates": "Koordynaty",
    "Credits": "Źródło",
    "Current view instead of default map view?": "Obecny widok mapy zamiast domyślnego?",
    "Custom background": "Własne tło",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Domyślne ustawienia interakcji",
    "Default properties": "Domyślne właściwości",
    "Default shape properties": "Domyślne właściwości kształtu",
    "Define link to open in a new window on polygon click.": "Ustaw odnośnik, który otworzy się w nowym oknie po kliknięciu w wielokąt.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Usuń",
    "Delete all layers": "Usuń wszystkie warstwy",
    "Delete layer": "Usuń warstwę",
    "Delete this feature": "Usuń ten obiekt",
    "Delete this property on all the features": "Usuń tę właściwość ze wszystkich obiektów",
    "Delete this shape": "Usuń tę figurę",
    "Delete this vertex (Alt-click)": "Usuń ten wierzchołek (Alt + klik)",
    "Directions from here": "Kierunki stąd",
    "Disable editing": "Wyłącz edytor",
    "Display measure": "Display measure",
    "Display on load": "Wyświetl przy ładowaniu",
    "Download": "Download",
    "Download data": "Pobierz dane",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Rysuj linię",
    "Draw a marker": "Dodaj znacznik",
    "Draw a polygon": "Rysuj obszar",
    "Draw a polyline": "Rysuj linię",
    "Dynamic": "Dynamiczne",
    "Dynamic properties": "Właściwości dynamiczne",
    "Edit": "Edytuj",
    "Edit feature's layer": "Edytuj warstwę z obiektami",
    "Edit map properties": "Edytuj właściwości mapy",
    "Edit map settings": "Edytuj ustawienia mapy",
    "Edit properties in a table": "Edytuj właściwości w tabeli",
    "Edit this feature": "Edytuj ten obiekt",
    "Editing": "Edycja",
    "Embed and share this map": "Osadź i udostępnij tą mapę",
    "Embed the map": "Osadź mapę na stronie",
    "Empty": "Wyczyść",
    "Enable editing": "Włącz edytor",
    "Error in the tilelayer URL": "Błąd w adresie URL podkładu",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Zamknij pełny ekran",
    "Extract shape to separate feature": "Wydziel kształt jako odrębny obiekt",
    "Fetch data each time map view changes.": "Załaduj dane za każdym razem gdy zmienia się widok mapy.",
    "Filter keys": "Filter keys",
    "Filter…": "Filtr...",
    "Format": "Format",
    "From zoom": "Od przybliżenia",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Idź do «{feature}»",
    "Heatmap intensity property": "Intensywność mapy cieplnej",
    "Heatmap radius": "Promień mapy cieplnej",
    "Help": "Pomoc",
    "Hide controls": "Ukryj przyciski",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak bardzo uprościć obszar na każdym poziomie przybliżenia (więcej = większa wydajność i gładki wygląd, mniej = większa dokładność)",
    "If false, the polygon will act as a part of the underlying map.": "Jeżeli fałsz, wielokąt będzie zachowywał się jak część mapy zasadniczej.",
    "Iframe export options": "Opcje eksportu Iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Ramka z podaną szerokością (w pikselach) {{{http://url.com|szerokość}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Ramka: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obrazek z własną szerokością (w pikselach) {{http://obrazek.url.com|szerokość}}",
    "Image: {{http://image.url.com}}": "Obrazek: {{http://obrazek.url.com}}",
    "Import": "Importuj",
    "Import data": "Importuj dane",
    "Import in a new layer": "Importuj do nowej warstwy",
    "Imports all umap data, including layers and settings.": "Import wszystkich danych umap, razem z warstwami i ustawieniami.",
    "Include full screen link?": "Dołączyć link do pełnego ekranu?",
    "Interaction options": "Opcje interakcji",
    "Invalid umap data": "Niepoprawne dane umap",
    "Invalid umap data in {filename}": "Niepoprawne dane umap w {filename}",
    "Keep current visible layers": "Zachowaj obecnie widoczne warstwy",
    "Latitude": "Szerokość geograficzna",
    "Layer": "Warstwa",
    "Layer properties": "Ustawienia warstwy",
    "Licence": "Licencja",
    "Limit bounds": "Limit granic",
    "Link to…": "Łącze do...",
    "Link with text: [[http://example.com|text of the link]]": "Link z tekstem: [[http://przyklad.pl|tekst zamiast linku]]",
    "Long credits": "Długie źródło",
    "Longitude": "Długość geograficzna",
    "Make main shape": "Narysuj główny kształt",
    "Manage layers": "Usuń warstwę",
    "Map background credits": "Źródło tła mapy",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Mapa została zapisana!",
    "Map user content has been published under licence": "Zawartość mapy użytkownika została opublikowana pod licencją",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Połącz linie",
    "More controls": "Więcej przycisków",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Musi być prawidłową wartością CSS (np. DarkBlue lub #123456)",
    "No licence has been set": "Nie wybrano licencji",
    "No results": "Brak wyników",
    "Only visible features will be downloaded.": "Tylko widoczne obiekty zostaną pobrane.",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otwórz ten zakres mapy w edytorze, by wprowadzić do OpenStreetMap dokładniejsze dane",
    "Optional intensity property for heatmap": "Opcjonalna intensywności mapy cieplnej",
    "Optional. Same as color if not set.": "Opcjonalne. Taki sam jak kolor jeśli nie podano.",
    "Optionnal.": "Opcjonalne.",
    "Override clustering radius (default 80)": "Nadpisz promień grupowania (domyślnie 80)",
    "Override heatmap radius (default 25)": "Nadpisz promień mapy cieplnej (domyślnie 25)",
    "Paste here your data": "Wklej tutaj swoje dane",
    "Please be sure the licence is compliant with your use.": "Upewnij się czy licencja jest zgodna z twoim użyciem.",
    "Please choose a format": "Wybierz format",
    "Please enter the name of the property": "Podaj nazwę właściwości",
    "Please enter the new name of this property": "Podaj nową nazwę tej właściwości",
    "Please save the map before": "Proszę najpierw zapisać mapę",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Zasilany przez <a href=\"{leaflet}\">Leaflet</a> i <a href=\"{django}\">Django</a>, sklejony przez <a href=\"{umap}\">projekt uMap</a>.",
    "Problem in the response": "Problem z odpowiedzią",
    "Problem in the response format": "Problem z formatem odpowiedzi",
    "Properties imported:": "Zaimportowane właściwości:",
    "Property to use for sorting features": "Właściwość do sortowania elementów",
    "Provide an URL here": "Wprowadź tutaj adres URL",
    "Proxy request": "Żądanie proxy",
    "Remote data": "Zdalne dane",
    "Remove shape from the multi": "Usuń obiekt z wybranego multipoligonu",
    "Rename this property on all the features": "Zmień nazwę tej właściwości we wszystkich obiektach",
    "Replace layer content": "Zamień zawartość warstwy",
    "Restore this version": "Przywróć tą wersję",
    "Save": "Zapisz",
    "Save anyway": "Zapisz mimo wszystko",
    "Save current edits": "Zapisz obecne edycje",
    "Save this center and zoom": "Zapisz obecną pozycję i przybliżenie",
    "Save this location as new feature": "Zapisz to miejsce jako nowy obiekt",
    "Search a place name": "Search a place name",
    "Search location": "Znajdź miejsce",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Pokaż wszystko",
    "See data layers": "See data layers",
    "See full screen": "Pełny ekran",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Właściwości kształtu",
    "Short URL": "Krótki adres URL",
    "Short credits": "Krótkie źródło",
    "Show/hide layer": "Pokaż/ukryj warstwę",
    "Simple link: [[http://example.com]]": "Prosty link: [[http://przyklad.pl]]",
    "Skipping unkown geometry.type: {type}": "Pomijanie nieznanego geometry.type: {type}",
    "Slideshow": "Pokaz slajdów",
    "Smart transitions": "Smart transitions",
    "Sort key": "Klucz sortowania",
    "Split line": "Podziel linię",
    "Start a hole here": "Zacznij dziurę tutaj",
    "Start editing": "Rozpocznij edycję",
    "Start slideshow": "Rozpocznij pokaz",
    "Stop editing": "Zakończ edycję",
    "Stop slideshow": "Zakończ pokaz",
    "Supported scheme": "Obsługiwany schemat",
    "Supported variables that will be dynamically replaced": "Obsługiwane zmienne zostaną dynamicznie zamienione",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "Format TMS",
    "Text color for the cluster label": "Kolor tekstu dla etykiety grupy",
    "Text formatting": "Formatowanie tekstu",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Przybliżenie i środek zostały ustawione.",
    "To use if remote server doesn't allow cross domain (slower)": "Używaj jeśli zdalny serwer nie zezwala na cross domain (wolne)",
    "To zoom": "Przybliżać",
    "Toggle edit mode (shift-click)": "Przełącz tryb edycji (Shift+klik)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Przekształć na linie",
    "Transform to polygon": "Przekształć w wielokąt",
    "Type of layer": "Typ warstwy",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Warstwa bez nazwy",
    "Untitled map": "Mapa bez nazwy",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Aktualizuj uprawnienia i edytory",
    "Url": "Adres URL",
    "Use current bounds": "Użyj bieżących granic",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Źródło treści użytkownika",
    "User interface options": "Opcje interfejsu",
    "Versions": "Wersje",
    "View Fullscreen": "Włącz tryb pełnoekranowy",
    "Where do we go from here?": "Gdzie można stąd pojechać?",
    "Whether to display or not polygons paths.": "Czy wyświetlić obrysy obszarów",
    "Whether to fill polygons with color.": "Czy wypełnić obszary kolorem",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Będzie wyświetlone w prawym dolnym rogu mapy",
    "Will be visible in the caption of the map": "Będzie widoczne w nagłówku mapy",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Ups! Ktoś jeszcze edytował dane. Możesz mimo wszystko zapisać, ale to uszkodzi zmiany dokonane przez innych.",
    "You have unsaved changes.": "Masz niezapisane zmiany.",
    "Zoom in": "Przybliż",
    "Zoom level for automatic zooms": "Poziom automatycznych przybliżeń",
    "Zoom out": "Oddal",
    "Zoom to layer extent": "Przybliż do warstwy",
    "Zoom to the next": "Przybliż do następnego",
    "Zoom to the previous": "Przybliż do poprzedniego",
    "Zoom to this feature": "Przybliż to tego obiektu",
    "Zoom to this place": "Przybliż do tego miejsca",
    "attribution": "oznaczenie autorstwa",
    "by": " ",
    "display name": "wyświetl nazwę",
    "height": "wysokość",
    "licence": "licencja",
    "max East": "granica wschodnia",
    "max North": "granica północna",
    "max South": "granica południowa",
    "max West": "granica zachodnia",
    "max zoom": "maksymalne powiększenie",
    "min zoom": "minimalne powiększenie",
    "next": "następne",
    "previous": "poprzednie",
    "width": "szerokość",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("pl", locale);
L.setLocale("pl");