var locale = {
    "Add symbol": "Добавить значок",
    "Allow scroll wheel zoom?": "Разрешить изменение масштаба колесом мыши?",
    "Automatic": "Автоматически",
    "Ball": "Булавка",
    "Cancel": "Отменить",
    "Caption": "Заголовок",
    "Change symbol": "Изменить значок",
    "Choose the data format": "Выберите формат данных",
    "Choose the layer of the feature": "Выберите слой для объекта",
    "Circle": "Кружок",
    "Clustered": "Кластеризованный",
    "Data browser": "Просмотр данных",
    "Default": "По умолчанию",
    "Default zoom level": "Масштаб по умолчанию",
    "Default: name": "По умолчанию: название",
    "Display label": "Показывать надпись",
    "Display the control to open OpenStreetMap editor": "Отображать кнопку редактора OpenStreetMap",
    "Display the data layers control": "Отображать кнопку управления слоями данных",
    "Display the embed control": "Отображать кнопку встраивания",
    "Display the fullscreen control": "Отображать кнопку полноэкранного режима",
    "Display the locate control": "Отображать кнопку определения местоположения",
    "Display the measure control": "Отображать линейку",
    "Display the search control": "Отображать строку поиска",
    "Display the tile layers control": "Отображать кнопку управления слоями подложки",
    "Display the zoom control": "Отображать кнопку масштабирования",
    "Do you want to display a caption bar?": "Показывать строку заголовка?",
    "Do you want to display a minimap?": "Показывать миникарту?",
    "Do you want to display a panel on load?": "Показывать панель управления при загрузке?",
    "Do you want to display popup footer?": "Хотите использовать всплывающую подсказку снизу?",
    "Do you want to display the scale control?": "Показывать шкалу расстояний?",
    "Do you want to display the «more» control?": "Показывать кнопку «Ещё»?",
    "Drop": "Капля",
    "GeoRSS (only link)": "GeoRSS (только ссылка)",
    "GeoRSS (title + image)": "GeoRSS (заголовок и изображение)",
    "Heatmap": "Тепловая карта",
    "Icon shape": "Форма иконки",
    "Icon symbol": "Иконка значка",
    "Inherit": "Наследовать",
    "Label direction": "Направление метки",
    "Label key": "Кнопка метки",
    "Labels are clickable": "Метки можно нажимать",
    "None": "Нет",
    "On the bottom": "Внизу",
    "On the left": "Слева",
    "On the right": "Справа",
    "On the top": "Вверху",
    "Popup content template": "Шаблон всплывающей подсказки",
    "Set symbol": "Выбрать значок",
    "Side panel": "Боковая панель",
    "Simplify": "Упростить",
    "Symbol or url": "Значок или URL",
    "Table": "Таблица",
    "always": "всегда",
    "clear": "очистить",
    "collapsed": "Свёрнуто",
    "color": "цвет",
    "dash array": "штрихи",
    "define": "обозначить",
    "description": "описание",
    "expanded": "Развёрнуто",
    "fill": "заливка",
    "fill color": "цвет заливки",
    "fill opacity": "Непрозрачность заливки",
    "hidden": "скрыт",
    "iframe": "Iframe",
    "inherit": "наследовать",
    "name": "название",
    "never": "никогда",
    "new window": "Новое окно",
    "no": "нет",
    "on hover": "при наведении",
    "opacity": "непрозрачность",
    "parent window": "Родительское окно",
    "stroke": "штрихи",
    "weight": "толщина",
    "yes": "да",
    "{delay} seconds": "{delay} секунд",
    "# one hash for main heading": "# один шарп — заголовок",
    "## two hashes for second heading": "## два шарпа — подзаголовок",
    "### three hashes for third heading": "### три шарпа — подзаголовок 3-го уровня",
    "**double star for bold**": "**двойные звёздочки — полужирный**",
    "*simple star for italic*": "*звёздочки — курсив*",
    "--- for an horizontal rule": "--- — горизонтальная линия",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Список значений, определяющих штрихи линии. Напр. «5, 10, 15».",
    "About": "Подробней",
    "Action not allowed :(": "Действие недоступно :(",
    "Activate slideshow mode": "Включить режим слайдшоу",
    "Add a layer": "Добавить слой",
    "Add a line to the current multi": "Добавить линию к текущему мультиполигону",
    "Add a new property": "Добавить новое свойство",
    "Add a polygon to the current multi": "Добавить полигон к текущему мультиполигону",
    "Advanced actions": "Дополнительные действия",
    "Advanced properties": "Дополнительные свойства",
    "Advanced transition": "Дополнительные преобразования",
    "All properties are imported.": "Все свойства импортированы.",
    "Allow interactions": "Разрешить взаимодействие",
    "An error occured": "Произошла ошибка",
    "Are you sure you want to cancel your changes?": "Вы уверены, что хотите отменить сделанные изменения?",
    "Are you sure you want to clone this map and all its datalayers?": "Вы уверены, что хотите скопировать эту карту и все её слои данных?",
    "Are you sure you want to delete the feature?": "Вы уверены, что хотите удалить объект?",
    "Are you sure you want to delete this layer?": "Вы уверены что хотите удалить этот слой?",
    "Are you sure you want to delete this map?": "Вы уверены, что хотите удалить карту?",
    "Are you sure you want to delete this property on all the features?": "Вы уверены, что хотите удалить это свойство у всех объектов?",
    "Are you sure you want to restore this version?": "Вы уверены, что хотите восстановить эту версию?",
    "Attach the map to my account": "Прикрепить карту к моей учётной записи",
    "Auto": "Автоматически",
    "Autostart when map is loaded": "Автозапуск при открытии карты",
    "Bring feature to center": "Поместить объект в центр",
    "Browse data": "Просмотр данных",
    "Cancel edits": "Отменить правки",
    "Center map on your location": "Переместить карту в ваше местоположение",
    "Change map background": "Изменить подложку карты",
    "Change tilelayers": "Выбрать подложку",
    "Choose a preset": "Выберите шаблон",
    "Choose the format of the data to import": "Выберите формат данных для импорта",
    "Choose the layer to import in": "Выбрать слой для импорта в него",
    "Click last point to finish shape": "Щёлкните на последней точке, чтобы завершить",
    "Click to add a marker": "Щёлкните, чтобы добавить метку",
    "Click to continue drawing": "Щёлкайте, чтобы продолжить рисование",
    "Click to edit": "Щёлкните, чтобы изменить",
    "Click to start drawing a line": "Щёлкните, чтобы начать рисование линии",
    "Click to start drawing a polygon": "Щёлкните, чтобы начать рисование полигона",
    "Clone": "Создать копию",
    "Clone of {name}": "Копия {name}",
    "Clone this feature": "Скопировать фигуру",
    "Clone this map": "Создать копию карты",
    "Close": "Закрыть",
    "Clustering radius": "Радиус кластеризации",
    "Comma separated list of properties to use when filtering features": "Список свойств, разделённых запятыми, для использования при фильтрации",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "В качестве разделителя используются запятые, табуляции и точки с запятой. Применяется датум WGS84. Импорт просматривает заголовок на наличие полей «lat» и «lon», регистр не имеет значения. Все остальные поля импортируются как свойства.",
    "Continue line": "Продолжить линию",
    "Continue line (Ctrl-click)": "Продолжить линию (Ctrl-click)",
    "Coordinates": "Координаты",
    "Credits": "Авторские права",
    "Current view instead of default map view?": "Использовать текущий вид вместо карты по умолчанию?",
    "Custom background": "Пользовательская подложка карты",
    "Data is browsable": "Данные можно просматривать",
    "Default interaction options": "Параметры интерактивности по умолчанию",
    "Default properties": "Свойства по умолчанию",
    "Default shape properties": "Параметры фигуры по умолчанию",
    "Define link to open in a new window on polygon click.": "Задайте адрес для открытия его в новом окне по клику на полигон.",
    "Delay between two transitions when in play mode": "Задержка между двумя переходами в режиме проигрывания",
    "Delete": "Удалить",
    "Delete all layers": "Удалить все слои",
    "Delete layer": "Удалить слой",
    "Delete this feature": "Удалить объект",
    "Delete this property on all the features": "Удалить это свойство у всех объектов",
    "Delete this shape": "Удалить эту фигуру",
    "Delete this vertex (Alt-click)": "Удалить эту точку (Alt-клик)",
    "Directions from here": "Навигация отсюда",
    "Disable editing": "Отключить редактирование",
    "Display measure": "Display measure",
    "Display on load": "Показывать при загрузке",
    "Download": "Скачать",
    "Download data": "Скачать данные",
    "Drag to reorder": "Перетащите для изменения порядка",
    "Draw a line": "Нарисовать линию",
    "Draw a marker": "Добавить метку",
    "Draw a polygon": "Нарисовать полигон",
    "Draw a polyline": "Нарисовать линию",
    "Dynamic": "Динамический",
    "Dynamic properties": "Динамические свойства",
    "Edit": "Редактировать",
    "Edit feature's layer": "Изменить слой объекта",
    "Edit map properties": "Редактировать свойства карты",
    "Edit map settings": "Изменить свойства карты",
    "Edit properties in a table": "Редактировать свойства в таблице",
    "Edit this feature": "Редактировать объект",
    "Editing": "Редактируем",
    "Embed and share this map": "Встроить карту или поделиться ей",
    "Embed the map": "Встроить карту",
    "Empty": "Очистить",
    "Enable editing": "Разрешить редактирование",
    "Error in the tilelayer URL": "Ошибка в ссылке на слой карты",
    "Error while fetching {url}": "Ошибка при обработке {url}",
    "Exit Fullscreen": "Выйти из полноэкранного режима",
    "Extract shape to separate feature": "Извлечь фигуру в отдельный объект",
    "Fetch data each time map view changes.": "Запрашивать данные при каждом изменении отображения карты",
    "Filter keys": "Кнопки фильтра",
    "Filter…": "Фильтр...",
    "Format": "Формат",
    "From zoom": "С масштаба",
    "Full map data": "Все данные карты",
    "Go to «{feature}»": "Перейти к «{feature}»",
    "Heatmap intensity property": "Свойство интенсивности тепловой карты",
    "Heatmap radius": "Радиус для тепловой карты",
    "Help": "Помощь",
    "Hide controls": "Убрать элементы управления",
    "Home": "Заглавная",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Насколько сильно упрощать линии на каждом масштабе (больше значение — больше скорость, но выглядит хуже; меньше значение — более гладкое отображение)",
    "If false, the polygon will act as a part of the underlying map.": "Если нет, тогда полигон будет выглядеть как часть карты",
    "Iframe export options": "Свойства экспорта для Iframe",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe с указанием высоты (в пикселях): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe с заданной высотой и шириной (в px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Изображение с указанием ширины (в пикселях): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Изображение: {{http://image.url.com}}",
    "Import": "Импорт",
    "Import data": "Импортировать данные",
    "Import in a new layer": "Импортировать в новый слой",
    "Imports all umap data, including layers and settings.": "Импортировать все данные uMap, включая слои и настройки.",
    "Include full screen link?": "Включить ссылку на полноэкранный вид?",
    "Interaction options": "Параметры взаимодействия",
    "Invalid umap data": "Неверные данные uMap",
    "Invalid umap data in {filename}": "Неверные данные uMap в файле {filename}",
    "Keep current visible layers": "Оставить текущие видимые слои",
    "Latitude": "Широта",
    "Layer": "Слой",
    "Layer properties": "Свойства слоя",
    "Licence": "Лицензия",
    "Limit bounds": "Установить границы",
    "Link to…": "Связать с...",
    "Link with text: [[http://example.com|text of the link]]": "Ссылка с текстом: [[http://example.com|текст для ссылки]]",
    "Long credits": "Полное описание прав",
    "Longitude": "Долгота",
    "Make main shape": "Сделать главной фигурой",
    "Manage layers": "Управление слоями",
    "Map background credits": "Права на фоновый слой карты",
    "Map has been attached to your account": "Карта была прикреплена к вашей учётной записи",
    "Map has been saved!": "Карта сохранена!",
    "Map user content has been published under licence": "Пользовательские данные опубликованы под лицензией",
    "Map's editors": "Редакторы карты",
    "Map's owner": "Владелец карты",
    "Merge lines": "Соединить линии",
    "More controls": "Другие элементы управления",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Должен быть в формате CSS (напр., DarkBlue или #123456)",
    "No licence has been set": "Лицензия не была указана",
    "No results": "Нет данных",
    "Only visible features will be downloaded.": "Будут загружены только отображаемые объекты.",
    "Open download panel": "Открыть панель скачивания",
    "Open link in…": "Открыть ссылку в ...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Откройте эту часть карты в редакторе OpenStreetMap, чтобы улучшить данные",
    "Optional intensity property for heatmap": "Дополнительные свойства интенсивности тепловой карты",
    "Optional. Same as color if not set.": "Дополнительно. Если не выбрано, то как цвет.",
    "Optionnal.": "Дополнительно.",
    "Override clustering radius (default 80)": "Переопределить радиус кластеризации (по умолчанию 80)",
    "Override heatmap radius (default 25)": "Переопределить радиус для тепловой карты (по умолчанию 25)",
    "Paste here your data": "Вставить данные сюда",
    "Please be sure the licence is compliant with your use.": "Убедитесь, что лицензия соответствует правилам использования.",
    "Please choose a format": "Пожалуйста, выберите формат",
    "Please enter the name of the property": "Введите название свойства",
    "Please enter the new name of this property": "Введите новое название свойства",
    "Please save the map before": "Пожалуйста, сначала сохраните карту",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Работает на <a href=\"{leaflet}\">Leaflet</a> и <a href=\"{django}\">Django</a>, объединённые проектом <a href=\"{umap}\">uMap</a>.",
    "Problem in the response": "Проблема с ответом",
    "Problem in the response format": "Формат ответа не распознан",
    "Properties imported:": "Импортированы свойства:",
    "Property to use for sorting features": "Свойство для сортировки объектов",
    "Provide an URL here": "Укажите ссылку здесь",
    "Proxy request": "Проксировать запрос",
    "Remote data": "Данные с удаленного сервера",
    "Remove shape from the multi": "Удалить фигуру из мультиполигона",
    "Rename this property on all the features": "Переименовать это свойство у всех объектов",
    "Replace layer content": "Заменить содержимое слоя",
    "Restore this version": "Восстановить эту версию",
    "Save": "Сохранить",
    "Save anyway": "Сохранить в любом случае",
    "Save current edits": "Сохранить текущие правки",
    "Save this center and zoom": "Сохранить это положение и масштаб",
    "Save this location as new feature": "Сохранить это местоположение как новый объект",
    "Search a place name": "Искать название места",
    "Search location": "Поиск местоположения",
    "Secret edit link is:<br>{link}": "Секретная ссылка для редактирования:<br>{link}",
    "See all": "Посмотреть все",
    "See data layers": "Посмотреть слои данных",
    "See full screen": "Смотреть в полноэкранном режиме",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Сбросьте, чтобы скрыть слой из слайдшоу, просмотра данных и всплывающей навигации...",
    "Shape properties": "Свойства фигуры",
    "Short URL": "Короткая ссылка",
    "Short credits": "Краткое описание прав",
    "Show/hide layer": "Показать/скрыть слой",
    "Simple link: [[http://example.com]]": "Простая ссылка: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Пропущено неизвестное свойство geometry.type: {type}",
    "Slideshow": "Слайдшоу",
    "Smart transitions": "Интеллектуальные преобразования",
    "Sort key": "Кнопка сортировки",
    "Split line": "Разделить линию",
    "Start a hole here": "Начать отверстие отсюда",
    "Start editing": "Начать редактирование",
    "Start slideshow": "Начать слайдшоу",
    "Stop editing": "Завершить редактирование",
    "Stop slideshow": "Остановить слайдшоу",
    "Supported scheme": "Поддерживаемая схема",
    "Supported variables that will be dynamically replaced": "Поддерживаемые переменные для автоматической замены",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Значок может быть как юникод-символом так и URL. Вы можете использовать свойства объектов как переменные. Например, в \"http://myserver.org/images/{name}.png\", переменная {name} будет заменена значением поля \"названия\" каждой метки на карте.",
    "TMS format": "Формат TMS",
    "Text color for the cluster label": "Цвет текста для меток кластера",
    "Text formatting": "Форматирование текста",
    "The name of the property to use as feature label (ex.: \"nom\")": "Название свойства в качестве метки объекта (напр., «Номер»)",
    "The zoom and center have been setted.": "Масштаб и положение установлены",
    "To use if remote server doesn't allow cross domain (slower)": "Если удалённый сервер не позволяет кросс-домен (медленно)",
    "To zoom": "Масштабировать",
    "Toggle edit mode (shift-click)": "Переключиться в режим редактирования (shift-click)",
    "Transfer shape to edited feature": "Перенести фигуру на редактируемый объект",
    "Transform to lines": "Преобразовать в линию",
    "Transform to polygon": "Преобразовать в полигон",
    "Type of layer": "Тип слоя",
    "Unable to detect format of file {filename}": "Невозможно определить формат файла {filename}",
    "Untitled layer": "Слой без названия",
    "Untitled map": "Безымянная карта",
    "Update permissions": "Обновить разрешения",
    "Update permissions and editors": "Настроить права редактирования",
    "Url": "Ссылка",
    "Use current bounds": "Использовать текущие границы",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Используйте переменные в скобках со свойствами объектов, например, &#123;name&#125;, они будут автоматически заменены соответствующими значениями.",
    "User content credits": "Права на пользовательские данные",
    "User interface options": "Настройка интерфейса",
    "Versions": "Версии",
    "View Fullscreen": "Полноэкранный режим",
    "Where do we go from here?": "Что можно сделать с картой?",
    "Whether to display or not polygons paths.": "Показывать или нет контур полигона.",
    "Whether to fill polygons with color.": "Заполнять или нет полигон заливкой цветом",
    "Who can edit": "Кто может редактировать",
    "Who can view": "Кто может просматривать",
    "Will be displayed in the bottom right corner of the map": "Будет показано в правом нижнем углу карты",
    "Will be visible in the caption of the map": "Будет показано в заголовке карты",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Упс! Похоже, кто-то другой тоже редактирует эти данные. Вы можете сохранить свои правки, но это уничтожит правки другого участника.",
    "You have unsaved changes.": "У вас есть несохранённые изменения",
    "Zoom in": "Увеличить масштаб",
    "Zoom level for automatic zooms": "Масштабировать слой автоматически",
    "Zoom out": "Уменьшить масштаб",
    "Zoom to layer extent": "Масштабировать до границ слоя",
    "Zoom to the next": "Приблизиться к следующему",
    "Zoom to the previous": "Приблизиться к предыдущему",
    "Zoom to this feature": "Приблизиться к этому объекту",
    "Zoom to this place": "Приблизить объект",
    "attribution": "назначенные свойства",
    "by": "от",
    "display name": "отображаемое название",
    "height": "высота",
    "licence": "лицензия",
    "max East": "Восток",
    "max North": "Север",
    "max South": "Юг",
    "max West": "Запад",
    "max zoom": "максимальный масштаб",
    "min zoom": "минимальный масштаб",
    "next": "следующий",
    "previous": "предыдущий",
    "width": "ширина",
    "{count} errors during import: {message}": "{count} ошибок во время импорта: {message}",
    "Measure distances": "Измерить расстояния",
    "NM": "NM",
    "kilometers": "километров",
    "km": "км",
    "mi": "миля",
    "miles": "миль",
    "nautical miles": "морских миль",
    "{area} acres": "{area} акров",
    "{area} ha": "{area} гектар",
    "{area} m&sup2;": "{area} м&sup2;",
    "{area} mi&sup2;": "{area} миль&sup2;",
    "{area} yd&sup2;": "{area} ярд&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} км",
    "{distance} m": "{distance} м",
    "{distance} miles": "{distance} миль",
    "{distance} yd": "{distance} ярдов",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("ru", locale);
L.setLocale("ru");