var locale = {
    "Add symbol": "新增圖示",
    "Allow scroll wheel zoom?": "允許捲動放大？",
    "Automatic": "自動",
    "Ball": "球",
    "Cancel": "取消",
    "Caption": "標題",
    "Change symbol": "更改圖示",
    "Choose the data format": "選擇資料格式",
    "Choose the layer of the feature": "選擇圖徵的圖層",
    "Circle": "圓圈",
    "Clustered": "群集後",
    "Data browser": "資料檢視器",
    "Default": "預設",
    "Default zoom level": "預設縮放等級",
    "Default: name": "預設: name",
    "Display label": "顯示標籤",
    "Display the control to open OpenStreetMap editor": "顯示開啟開放街圖編輯器的按鍵",
    "Display the data layers control": "顯示資料圖層鍵",
    "Display the embed control": "顯示嵌入鍵",
    "Display the fullscreen control": "顯示全螢幕鍵",
    "Display the locate control": "顯示定位鍵",
    "Display the measure control": "顯示比例尺鍵",
    "Display the search control": "顯示搜尋鍵",
    "Display the tile layers control": "顯示圖層鍵",
    "Display the zoom control": "顯示縮放鍵",
    "Do you want to display a caption bar?": "您是否要顯示標題列？",
    "Do you want to display a minimap?": "您想要顯示小型地圖嗎？",
    "Do you want to display a panel on load?": "您是否要顯示",
    "Do you want to display popup footer?": "您是否要顯示註腳彈出？",
    "Do you want to display the scale control?": "您是否要顯示尺標？",
    "Do you want to display the «more» control?": "您是否要顯示 《更多》？",
    "Drop": "中止",
    "GeoRSS (only link)": "GeoRSS (只有連結)",
    "GeoRSS (title + image)": "GeoRSS (標題與圖片)",
    "Heatmap": "熱點圖",
    "Icon shape": "圖示圖形",
    "Icon symbol": "圖示標誌",
    "Inherit": "繼承",
    "Label direction": "標籤方向",
    "Label key": "標籤鍵",
    "Labels are clickable": "標籤可點擊",
    "None": "以上皆非",
    "On the bottom": "在底部",
    "On the left": "在左側",
    "On the right": "在右側",
    "On the top": "在頂部",
    "Popup content template": "彈出內文範本",
    "Set symbol": "Set symbol",
    "Side panel": "側邊框",
    "Simplify": "簡化",
    "Symbol or url": "Symbol or url",
    "Table": "表格",
    "always": "經常",
    "clear": "清除",
    "collapsed": "收起",
    "color": "色彩",
    "dash array": "虛線排列",
    "define": "定義",
    "description": "描述",
    "expanded": "展開",
    "fill": "填入",
    "fill color": "填入色彩",
    "fill opacity": "填入不透明度",
    "hidden": "隱藏",
    "iframe": "iframe",
    "inherit": "繼承",
    "name": "名稱",
    "never": "永不",
    "new window": "新視窗",
    "no": "否",
    "on hover": "on hover",
    "opacity": "不透明度",
    "parent window": "父視窗",
    "stroke": "筆畫粗細",
    "weight": "寬度",
    "yes": "是",
    "{delay} seconds": "{delay} 秒",
    "# one hash for main heading": "單個 # 代表主標題",
    "## two hashes for second heading": "兩個 # 代表次標題",
    "### three hashes for third heading": "三個 # 代表第三標題",
    "**double star for bold**": "** 重複兩次星號代表粗體 **",
    "*simple star for italic*": "*單個星號代表斜體*",
    "--- for an horizontal rule": "-- 代表水平線",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "用逗號來分隔一列列的虛線模式，例如：\"5, 10, 15\"。",
    "About": "關於",
    "Action not allowed :(": "行為不被允許:(",
    "Activate slideshow mode": "開啟幻燈片模式",
    "Add a layer": "新增圖層",
    "Add a line to the current multi": "新增線段",
    "Add a new property": "新增屬性",
    "Add a polygon to the current multi": "新增多邊形",
    "Advanced actions": "進階動作",
    "Advanced properties": "進階屬性",
    "Advanced transition": "進階轉換",
    "All properties are imported.": "所有物件皆已匯入",
    "Allow interactions": "允許互動",
    "An error occured": "發生錯誤",
    "Are you sure you want to cancel your changes?": "您確定要取消您所做的變更？",
    "Are you sure you want to clone this map and all its datalayers?": "您確定要複製此地圖及所有資料圖層？",
    "Are you sure you want to delete the feature?": "您確定要刪除該圖徵？",
    "Are you sure you want to delete this layer?": "你確定要刪除這個圖層嗎？",
    "Are you sure you want to delete this map?": "您確定要刪除此地圖？",
    "Are you sure you want to delete this property on all the features?": "您確定要刪除所有圖徵中的此項屬性？",
    "Are you sure you want to restore this version?": "您確定要回復此一版本嗎？",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "自動",
    "Autostart when map is loaded": "當讀取地圖時自動啟動",
    "Bring feature to center": "將圖徵置中",
    "Browse data": "瀏覽資料",
    "Cancel edits": "取消編輯",
    "Center map on your location": "將您的位置設為地圖中心",
    "Change map background": "更改地圖背景",
    "Change tilelayers": "改變地圖磚圖層",
    "Choose a preset": "選擇一種預設值",
    "Choose the format of the data to import": "選擇匯入的資料格式",
    "Choose the layer to import in": "選擇匯入圖層",
    "Click last point to finish shape": "點下最後一點後完成外形",
    "Click to add a marker": "點選以新增標記",
    "Click to continue drawing": "點擊以繼續繪製",
    "Click to edit": "點擊開始編輯",
    "Click to start drawing a line": "點擊以開始繪製直線",
    "Click to start drawing a polygon": "點選開始繪製多邊形",
    "Clone": "複製",
    "Clone of {name}": "複製 {name}",
    "Clone this feature": "複製此項目",
    "Clone this map": "複製此地圖",
    "Close": "關閉",
    "Clustering radius": "群集分析半徑",
    "Comma separated list of properties to use when filtering features": "以逗號分開列出篩選時要使用的屬性",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "使用逗號、定位鍵或是分號分隔的地理數據。預設座標系為 SRS WGS84。只會匯入地理座標點。匯入時抓取 «lat» 與 «lon» 開頭的欄位資料，不分大小寫。其他欄位則歸入屬性資料。",
    "Continue line": "連續線段",
    "Continue line (Ctrl-click)": "連續線（Ctrl+點擊鍵）",
    "Coordinates": "座標",
    "Credits": "工作人員名單",
    "Current view instead of default map view?": "將目前視點設為預設視點？",
    "Custom background": "自訂背景",
    "Data is browsable": "資料是可檢視的",
    "Default interaction options": "預設互動選項",
    "Default properties": "預設屬性",
    "Default shape properties": "預設形狀屬性",
    "Define link to open in a new window on polygon click.": "指定點多邊形連結時開新視窗。",
    "Delay between two transitions when in play mode": "播放模式下兩個轉換間會延遲",
    "Delete": "刪除",
    "Delete all layers": "刪除所有圖層",
    "Delete layer": "刪除圖層",
    "Delete this feature": "刪除此圖徵",
    "Delete this property on all the features": "從所有圖徵中刪除此屬性",
    "Delete this shape": "刪除外形",
    "Delete this vertex (Alt-click)": "刪除頂點 (Alt-click)",
    "Directions from here": "從此處開始導航",
    "Disable editing": "停用編輯功能",
    "Display measure": "Display measure",
    "Display on load": "載入時顯示",
    "Download": "Download",
    "Download data": "下載資料",
    "Drag to reorder": "拖拽以排序",
    "Draw a line": "描繪線條",
    "Draw a marker": "描繪標記",
    "Draw a polygon": "描繪多邊形",
    "Draw a polyline": "描繪折線",
    "Dynamic": "動態",
    "Dynamic properties": "動態屬性",
    "Edit": "編輯",
    "Edit feature's layer": "編輯圖徵的圖層",
    "Edit map properties": "編輯地圖屬性",
    "Edit map settings": "編輯地圖設定值",
    "Edit properties in a table": "在表格中編輯屬性",
    "Edit this feature": "編輯此圖徵",
    "Editing": "編輯",
    "Embed and share this map": "將地圖內嵌並分享",
    "Embed the map": "嵌入地圖",
    "Empty": "空白",
    "Enable editing": "啟用編輯功能",
    "Error in the tilelayer URL": "地圖磚圖層 URL 錯誤",
    "Error while fetching {url}": "擷取網址時發生錯誤 {url}",
    "Exit Fullscreen": "結束全螢幕模式",
    "Extract shape to separate feature": "由外形分離出圖徵",
    "Fetch data each time map view changes.": "每次地圖檢視改變時截取資料。",
    "Filter keys": "篩選鍵",
    "Filter…": "篩選器",
    "Format": "格式",
    "From zoom": "由縮放大小",
    "Full map data": "全部地圖資料",
    "Go to «{feature}»": "轉至 «{feature}»",
    "Heatmap intensity property": "熱點圖強度屬性",
    "Heatmap radius": "熱點圖半徑",
    "Help": "幫助",
    "Hide controls": "隱藏控制列",
    "Home": "首頁",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "在不同縮放比例下，多邊形的精簡程度 (精簡越多有較好的效率、多邊形越平滑，精簡越少圖形越精確)",
    "If false, the polygon will act as a part of the underlying map.": "選擇「否」時，多邊形物件會被當成為底圖的一部分。",
    "Iframe export options": "Iframe 匯出選項",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "自訂 iframe 高度 (以 px 為單位): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "自訂 iframe 高度和寬度 (以 px 為單位)：{{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "自訂圖像的寬度（像素）: {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "圖像: {{http://image.url.com}}",
    "Import": "匯入",
    "Import data": "匯入資料",
    "Import in a new layer": "匯入至新圖層",
    "Imports all umap data, including layers and settings.": "匯入所有 umap 資料，包含圖層與設定。",
    "Include full screen link?": "是否包含全螢幕的連結？",
    "Interaction options": "互動選項",
    "Invalid umap data": "無效的 umap 資料",
    "Invalid umap data in {filename}": "無效的 umap 資料於檔案 {filename}",
    "Keep current visible layers": "保留目前可見圖層",
    "Latitude": "緯度",
    "Layer": "圖層",
    "Layer properties": "圖層屬性",
    "Licence": "授權",
    "Limit bounds": "限制範圍",
    "Link to…": "連結至...",
    "Link with text: [[http://example.com|text of the link]]": "帶有超連結的文字: [[http://example.com|text of the link]]",
    "Long credits": "詳細工作人員名單",
    "Longitude": "經度",
    "Make main shape": "設為主要外形",
    "Manage layers": "管理圖層",
    "Map background credits": "地圖背景取自",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "地圖儲存已完成",
    "Map user content has been published under licence": "使用者地圖資訊內容已經以以下授權發佈",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "合併線段",
    "More controls": "更多控制項目",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "必須是有效的 CSS 值 (例如：DarkBlue 或是 #123456)",
    "No licence has been set": "尚未設定授權條例",
    "No results": "沒有結果",
    "Only visible features will be downloaded.": "只有可見的圖徵會被下載",
    "Open download panel": "Open download panel",
    "Open link in…": "開啓連結於...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "在地圖編輯器中打開此地圖，提供更多準確資料給 OpenStreetMap",
    "Optional intensity property for heatmap": "選用的熱圖 heatmap 強度屬性",
    "Optional. Same as color if not set.": "可選，若您未選取顏色，則採用預設值",
    "Optionnal.": "選填",
    "Override clustering radius (default 80)": "覆蓋群集分析半徑 (預設80)",
    "Override heatmap radius (default 25)": "覆蓋指定熱圖 heatmap 半徑 (預設 25)",
    "Paste here your data": "在此貼入資料",
    "Please be sure the licence is compliant with your use.": "請再次確認所選的授權方式符合您的需求",
    "Please choose a format": "請選擇地圖格式",
    "Please enter the name of the property": "請輸入物件名稱",
    "Please enter the new name of this property": "請輸入新的物件名稱",
    "Please save the map before": "請先儲存您的地圖",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "使用 <a href=\"{leaflet}\">Leaflet</a> 與 <a href=\"{django}\">Django</a> 技術﹐由 <a href=\"{umap}\">uMap 計畫</a> 整合。",
    "Problem in the response": "回應出現錯誤",
    "Problem in the response format": "回應的格式出現錯誤",
    "Properties imported:": "屬性匯入完成",
    "Property to use for sorting features": "排序圖徵所使用的屬性",
    "Provide an URL here": "提供 URL網址",
    "Proxy request": "使用代理請求",
    "Remote data": "遠端資料",
    "Remove shape from the multi": "移除外形",
    "Rename this property on all the features": "在所有特徵中重新命名該物件",
    "Replace layer content": "取代圖層內容",
    "Restore this version": "回復此版本",
    "Save": "儲存",
    "Save anyway": "通通都儲存吧！",
    "Save current edits": "儲存近期的變更",
    "Save this center and zoom": "保存地圖中心點位置與縮放大小",
    "Save this location as new feature": "將地點存為新的圖徵",
    "Search a place name": "Search a place name",
    "Search location": "搜尋地點",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "觀看完整內容",
    "See data layers": "See data layers",
    "See full screen": "觀看全螢幕",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "設定為假時，在幻燈片時、資料檢視器和彈出式導航中可將此圖層隱藏...",
    "Shape properties": "形狀屬性",
    "Short URL": "短網址",
    "Short credits": "簡短工作人員名單",
    "Show/hide layer": "顯示/隱藏圖層",
    "Simple link: [[http://example.com]]": "簡單連結: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "略過未知的地理資料格式 geometry.type: {type}",
    "Slideshow": "投影片",
    "Smart transitions": "智慧轉換",
    "Sort key": "排序鍵",
    "Split line": "分隔線",
    "Start a hole here": "開始一個凹洞",
    "Start editing": "開始編輯",
    "Start slideshow": "開啟投影片",
    "Stop editing": "停止編輯",
    "Stop slideshow": "中止投影片",
    "Supported scheme": "支援的模板",
    "Supported variables that will be dynamically replaced": "支援的物件將直接動態轉換",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS 格式",
    "Text color for the cluster label": "叢集標籤的文字顏色",
    "Text formatting": "文字格式",
    "The name of the property to use as feature label (ex.: \"nom\")": "用作圖徵標籤的屬性名稱 (例如：“nom”)",
    "The zoom and center have been setted.": "已完成置中及切換功能設定",
    "To use if remote server doesn't allow cross domain (slower)": "如果遠端伺服器不允許跨網域存取時使用 (效率較差)",
    "To zoom": "至縮放大小",
    "Toggle edit mode (shift-click)": "切換編輯模式 (shift-click)",
    "Transfer shape to edited feature": "將外形加到編輯中的特徵",
    "Transform to lines": "轉換為線條",
    "Transform to polygon": "轉換為多邊形",
    "Type of layer": "圖層類型",
    "Unable to detect format of file {filename}": "無法偵測 {filename} 的檔案格式",
    "Untitled layer": "未命名圖層",
    "Untitled map": "未命名地圖",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "更新可編輯權限及編輯者",
    "Url": "網址",
    "Use current bounds": "使用目前範圍",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "以圖徵的屬性加上括弧作為標記，例如 &#123;name&#125;，這樣子就可以動態被取代成對應的數值。",
    "User content credits": "使用者內容清單",
    "User interface options": "使用者界面選項",
    "Versions": "版本",
    "View Fullscreen": "以全屏幕模式顯示",
    "Where do we go from here?": "我們要去哪裡？",
    "Whether to display or not polygons paths.": "是否顯示多邊形的路徑。",
    "Whether to fill polygons with color.": "是否將多邊形填入色彩。",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "將會顯示在地圖的右下角",
    "Will be visible in the caption of the map": "標題將出現在地圖上",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "糟糕，好像有人正在進行編輯，您仍可儲存資料，但您做的變更將被他人修改取代。",
    "You have unsaved changes.": "您有變更尚未儲存",
    "Zoom in": "放大",
    "Zoom level for automatic zooms": "自動縮放的比例大小",
    "Zoom out": "縮小",
    "Zoom to layer extent": "切換至圖層範圍",
    "Zoom to the next": "切換至下一頁",
    "Zoom to the previous": "切換至前一頁",
    "Zoom to this feature": "縮放至圖徵範圍",
    "Zoom to this place": "縮放到這個地方",
    "attribution": "表彰",
    "by": "由",
    "display name": "顯示名稱",
    "height": "高度",
    "licence": "授權",
    "max East": "最東方",
    "max North": "最北方",
    "max South": "最南方",
    "max West": "最西方",
    "max zoom": "放到最大",
    "min zoom": "縮至最小",
    "next": "下一個",
    "previous": "前一個",
    "width": "寬度",
    "{count} errors during import: {message}": "於匯入時發生 {count} 項錯誤: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("zh_TW", locale);
L.setLocale("zh_TW");