var locale = {
    "Add symbol": "Symbool toevoegen",
    "Allow scroll wheel zoom?": "Zoomen met scrollwieltje toestaan?",
    "Automatic": "Automatic",
    "Ball": "Kopspeld",
    "Cancel": "Annuleren",
    "Caption": "Caption",
    "Change symbol": "Symbool veranderen",
    "Choose the data format": "Gegevensformaat selecteren",
    "Choose the layer of the feature": "Kies de laag van het object",
    "Circle": "Cirkel",
    "Clustered": "Bij elkaar gevoegd",
    "Data browser": "Data browser",
    "Default": "Standaard",
    "Default zoom level": "Default zoom level",
    "Default: name": "Default: name",
    "Display label": "Display label",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Do you want to display a caption bar?",
    "Do you want to display a minimap?": "Wil je een minikaartje tonen?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display popup footer?": "Wil je een popup-footer tonen?",
    "Do you want to display the scale control?": "Wil je het schaal-besturingselement tonen?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Drop": "Drop",
    "GeoRSS (only link)": "GeoRSS (only link)",
    "GeoRSS (title + image)": "GeoRSS (title + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "Inherit": "Overerving",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "None": "None",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Popup content template": "Popup content template",
    "Set symbol": "Set symbol",
    "Side panel": "Side panel",
    "Simplify": "Simplify",
    "Symbol or url": "Symbol or url",
    "Table": "Table",
    "always": "always",
    "clear": "clear",
    "collapsed": "collapsed",
    "color": "kleur",
    "dash array": "soort stippellijn",
    "define": "define",
    "description": "beschrijving",
    "expanded": "expanded",
    "fill": "opvullen",
    "fill color": "opvulkleur",
    "fill opacity": "(on)doorzichtigheid van inkleuring",
    "hidden": "hidden",
    "iframe": "iframe",
    "inherit": "overerven",
    "name": "naam",
    "never": "never",
    "new window": "new window",
    "no": "neen",
    "on hover": "on hover",
    "opacity": "ondoorzichtigheid",
    "parent window": "parent window",
    "stroke": "lijndikte",
    "weight": "weight",
    "yes": "ja",
    "{delay} seconds": "{delay} seconds",
    "# one hash for main heading": "# een hekje voor hoofding 1",
    "## two hashes for second heading": "## twee hekjes voor hoofding 2",
    "### three hashes for third heading": "### twee hekjes voor hoofding 3",
    "**double star for bold**": "**Twee sterretjes voor vet**",
    "*simple star for italic*": "*Enkel sterretje voor cursief*",
    "--- for an horizontal rule": "--- voor een horizontale scheidingslijn",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Over",
    "Action not allowed :(": "Handeling niet toegestaan :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Laag toevoegen",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Advanced actions": "Geavanceerde acties",
    "Advanced properties": "Geavanceerde eigenschappen",
    "Advanced transition": "Advanced transition",
    "All properties are imported.": "Alle eigenschappen zijn geïmporteerd",
    "Allow interactions": "Allow interactions",
    "An error occured": "Er is een fout opgetreden",
    "Are you sure you want to cancel your changes?": "Ben je zeker dat je je wijzigingen wil annuleren?",
    "Are you sure you want to clone this map and all its datalayers?": "Ben je zeker dat je deze kaart en alle gegevenslagen wil klonen?",
    "Are you sure you want to delete the feature?": "Ben je zeker dat je het object wil verwijderen?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Ben je zeker dat je deze kaart wil verwijderen?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Auto",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Bring feature to center": "Object in het midden zetten",
    "Browse data": "Gegevens doorbladeren",
    "Cancel edits": "Bewerkingen annuleren",
    "Center map on your location": "Centreer kaart op je locatie",
    "Change map background": "Verander kaartachtergrond",
    "Change tilelayers": "Andere kaartachtergrond instellen",
    "Choose a preset": "Kies een voorkeuzeinstelling",
    "Choose the format of the data to import": "Kies het formaat van de te importeren gegevens",
    "Choose the layer to import in": "Kies de laag om in te importeren",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone": "Clone",
    "Clone of {name}": "Clone of {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Deze kaart klonen",
    "Close": "Close",
    "Clustering radius": "Clustering radius",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma-, tabulator- of puntkomma-gescheiden waardes, SRS WGS84 wordt verondersteld. Enkel puntgeometrieën wordne geímporteerd. Bij het importeren wordt gekeken naar kolomkoppen die met «lat» of «lon» beginnen. Alle andere kolommen worden als eigenschappen geïmporteerd",
    "Continue line": "Continue line",
    "Continue line (Ctrl-click)": "Continue line (Ctrl-click)",
    "Coordinates": "Coordinates",
    "Credits": "Bronvermelding",
    "Current view instead of default map view?": "Huidig zicht in plaats van standaard kaartaanzicht",
    "Custom background": "Custom background",
    "Data is browsable": "Data is browsable",
    "Default interaction options": "Default interaction options",
    "Default properties": "Standaardeigenschappen",
    "Default shape properties": "Default shape properties",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete": "Verwijderen",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Dit object verwijderen",
    "Delete this property on all the features": "Delete this property on all the features",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt-click)": "Delete this vertex (Alt-click)",
    "Directions from here": "Wegbeschrijving vanaf hier",
    "Disable editing": "Bewerken uitschakelen",
    "Display measure": "Display measure",
    "Display on load": "Tonen bij laden",
    "Download": "Download",
    "Download data": "Gegevens downloaden",
    "Drag to reorder": "Drag to reorder",
    "Draw a line": "Teken een lijn",
    "Draw a marker": "Teken een punt",
    "Draw a polygon": "Teken een veelhoek",
    "Draw a polyline": "Teken een veelhoek",
    "Dynamic": "Dynamisch",
    "Dynamic properties": "Dynamic properties",
    "Edit": "Bewerken",
    "Edit feature's layer": "Objectlaag bewerken",
    "Edit map properties": "Kaarteigenschappen wijzigen",
    "Edit map settings": "Kaartinstellingen aanpassen",
    "Edit properties in a table": "Edit properties in a table",
    "Edit this feature": "Dit object bewerken",
    "Editing": "Bewerken",
    "Embed and share this map": "Deze kaart insluiten en delen",
    "Embed the map": "Kaart inbedden",
    "Empty": "Empty",
    "Enable editing": "Bewerken inschakelen",
    "Error in the tilelayer URL": "Er is een fout opgetreden met de achtergrondtegels",
    "Error while fetching {url}": "Error while fetching {url}",
    "Exit Fullscreen": "Exit Fullscreen",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "Filter keys": "Filter keys",
    "Filter…": "Filter…",
    "Format": "Formaat",
    "From zoom": "Van zoom",
    "Full map data": "Full map data",
    "Go to «{feature}»": "Ga naar «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Help": "Help",
    "Hide controls": "Verberg besturingselementen",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Graad van vereenvoudiging van een veelhoek, per zoomniveau. (Hogere waarde = betere prestaties, lagere waarde = getrouwere precisie)",
    "If false, the polygon will act as a part of the underlying map.": "If false, the polygon will act as a part of the underlying map.",
    "Iframe export options": "Iframe exporteeropties",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Beeld met standaardbreedte (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import": "Importeer",
    "Import data": "Gegevens importeren",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Include full screen link?",
    "Interaction options": "Interaction options",
    "Invalid umap data": "Invalid umap data",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Keep current visible layers": "Keep current visible layers",
    "Latitude": "Latitude",
    "Layer": "Layer",
    "Layer properties": "Layer properties",
    "Licence": "Licentie",
    "Limit bounds": "Gebied begrenzen",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Link with text: [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Map background credits": "Bronvermelding kaartachtergrond",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map user content has been published under licence": "Inhoud toegevoegd aan deze kaart wordt gepubliceerd onder deze licentievoorwaarden",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Merge lines",
    "More controls": "Meer instelknoppen",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "Only visible features will be downloaded.": "Enkel zichtbare objecten zullen worden geëxporteerd",
    "Open download panel": "Open download panel",
    "Open link in…": "Open link in…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open dit gedeelte van de kaart in een editor, zodat u de kaartgegeven in Openstreetmap zelf kan bijwerken.",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optioneel. Gelijk aan kleur indien niet ingesteld",
    "Optionnal.": "Optioneel",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "Paste here your data": "Plak hier uw gegevens",
    "Please be sure the licence is compliant with your use.": "Zorg er aub voor dat je je aan de licentievoorwaarden houdt",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Please save the map before": "Please save the map before",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Probleem met het antwoord gekregen van de server",
    "Problem in the response format": "Probleem met het formaat van het antwoord van de server",
    "Properties imported:": "Properties imported:",
    "Property to use for sorting features": "Property to use for sorting features",
    "Provide an URL here": "Geef hier een URL-adres op",
    "Proxy request": "Proxy request",
    "Remote data": "Data van elders",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Rename this property on all the features",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save": "Opslaan",
    "Save anyway": "Save anyway",
    "Save current edits": "Huidige bewerkingen opslaan",
    "Save this center and zoom": "Bewaar deze positie op de kaart en het zoomniveau",
    "Save this location as new feature": "Save this location as new feature",
    "Search a place name": "Search a place name",
    "Search location": "Search location",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "See all",
    "See data layers": "See data layers",
    "See full screen": "Op volledig scherm weergeven",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "Shape properties": "Shape properties",
    "Short URL": "Korte URL",
    "Short credits": "Short credits",
    "Show/hide layer": "Laat tonen/verbergen",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Skipping unkown geometry.type: {type}",
    "Slideshow": "Slideshow",
    "Smart transitions": "Smart transitions",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Start a hole here": "Start a hole here",
    "Start editing": "Starten met editeren",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop met editeren",
    "Stop slideshow": "Stop slideshow",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "TMS-formaat",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (ex.: \"nom\")": "The name of the property to use as feature label (ex.: \"nom\")",
    "The zoom and center have been setted.": "Het zoomniveau en de positie op de kaarten zijn ingesteld",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Tot zoomniveau",
    "Toggle edit mode (shift-click)": "Toggle edit mode (shift-click)",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Omzetten naar lijnen",
    "Transform to polygon": "Omzetten naar veelhoed",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Laag zonder naam",
    "Untitled map": "Kaart zonder naam",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Bijwerken van permissies en bewerkers",
    "Url": "URL",
    "Use current bounds": "Begrensd gebied instellen op wat nu te zien is",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Gebruikersinhoud bronvermelding",
    "User interface options": "Gebruikersinterfaceopties",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "Where do we go from here?": "Waar gaan we nu heen?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "You have unsaved changes.": "You have unsaved changes.",
    "Zoom in": "Inzoomen",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Uitzoomen",
    "Zoom to layer extent": "Zodanig zoomen dat alle data in venster past",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Op dit object inzoomen",
    "Zoom to this place": "Zoom to this place",
    "attribution": "attribution",
    "by": "by",
    "display name": "display name",
    "height": "hoogte",
    "licence": "licentie",
    "max East": "maximale oostwaarde",
    "max North": "maximale noordwaarde",
    "max South": "maximale zuidwaarde",
    "max West": "maximale westwaarde",
    "max zoom": "max zoom",
    "min zoom": "min zoom",
    "next": "next",
    "previous": "previous",
    "width": "breedte",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("nl", locale);
L.setLocale("nl");