var locale = {
    "Add symbol": "Dodaj simbol",
    "Allow scroll wheel zoom?": "Ali naj se dovoli približanje pogleda s kolescem miške?",
    "Automatic": "Samodejno",
    "Ball": "Bucika",
    "Cancel": "Prekliči",
    "Caption": "Naslov",
    "Change symbol": "Spremeni simbol",
    "Choose the data format": "Izbor zapisa podatkov",
    "Choose the layer of the feature": "Izbor plasti za postavitev predmeta",
    "Circle": "Točka",
    "Clustered": "Zbrano območje",
    "Data browser": "Brskalnik podatkov",
    "Default": "Privzeto",
    "Default zoom level": "Privzeta raven približanja",
    "Default: name": "Privzeto: ime",
    "Display label": "Pokaži oznako",
    "Display the control to open OpenStreetMap editor": "Pokaži gumb za odpiranje urejevalnika OpenstreetMap",
    "Display the data layers control": "Pokaži gumb za nadzor podatkov plasti",
    "Display the embed control": "Pokaži gumb za vstavljanje predmetov",
    "Display the fullscreen control": "Pokaži gumb za preklop v celozaslonski način",
    "Display the locate control": "Pokaži gumb za omogočanje lokacijskih storitev",
    "Display the measure control": "Pokaži gumb za merjenje razdalij",
    "Display the search control": "Pokaži možnosti za iskanje",
    "Display the tile layers control": "Pokaži gumb za upravljanje s sličicami plasti",
    "Display the zoom control": "Pokaži gumb za približanje",
    "Do you want to display a caption bar?": "Ali želite pokazati naslovno vrstico?",
    "Do you want to display a minimap?": "Ali želite prikazati mini zemljevid?",
    "Do you want to display a panel on load?": "Ali želite pokazati bočno okno ob zagonu?",
    "Do you want to display popup footer?": "Ali želite prikazati pojavno okno noge?",
    "Do you want to display the scale control?": "Ali želite prikazati gumbe merila?",
    "Do you want to display the «more» control?": "Ali želite pokazati orodno vrstico »več možnosti«?",
    "Drop": "Kapljica",
    "GeoRSS (only link)": "GeoRSS (le povezava)",
    "GeoRSS (title + image)": "GeoRSS (naslov in slika)",
    "Heatmap": "Vročinske točke",
    "Icon shape": "Oblika ikone",
    "Icon symbol": "Simbol ikone",
    "Inherit": "Prevzemi",
    "Label direction": "Usmerjenost oznake",
    "Label key": "Oznaka",
    "Labels are clickable": "Oznake so klikljive",
    "None": "Brez",
    "On the bottom": "Na dnu",
    "On the left": "Na levi",
    "On the right": "Na desni",
    "On the top": "Na vrhu",
    "Popup content template": "Predloga pojavne vsebine",
    "Set symbol": "Set symbol",
    "Side panel": "Bočno okno",
    "Simplify": "Poenostavi",
    "Symbol or url": "Symbol or url",
    "Table": "Razpredelnica",
    "always": "vedno",
    "clear": "počisti",
    "collapsed": "zloženo",
    "color": "barva",
    "dash array": "črtkano",
    "define": "določi",
    "description": "opis",
    "expanded": "razširjeno",
    "fill": "polnilo",
    "fill color": "barva polnila",
    "fill opacity": "prosojnost polnila",
    "hidden": "skrito",
    "iframe": "iframe",
    "inherit": "prevzemi",
    "name": "ime",
    "never": "nikoli",
    "new window": "novo okno",
    "no": "ne",
    "on hover": "on hover",
    "opacity": "prosojnost",
    "parent window": "glavno okno",
    "stroke": "prečrtano",
    "weight": "debelina",
    "yes": "da",
    "{delay} seconds": "{delay} sekund",
    "# one hash for main heading": "# en znak za prvi glavni naslov",
    "## two hashes for second heading": "## dva znaka za drugi naslov",
    "### three hashes for third heading": "### trije znaki za tretji naslov",
    "**double star for bold**": "**dvojna zvezdica za krepko pisavo**",
    "*simple star for italic*": "*enojna zvezdica za ležečo pisavo*",
    "--- for an horizontal rule": "--- za vodoravno črto",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Z vejilo ločen seznam števil, ki določajo vzorec poteze. Na primer »5, 10, 15«.",
    "About": "O programu",
    "Action not allowed :(": "Dejanje ni dovoljeno :(",
    "Activate slideshow mode": "Omogoči predstavitveni način",
    "Add a layer": "Dodaj plast",
    "Add a line to the current multi": "Dodaj črto k trenutnemu večtočkovnemu predmetu",
    "Add a new property": "Dodaj novo lastnost",
    "Add a polygon to the current multi": "Dodaj mnogokotnik k trenutnemu večtočkovnemu predmetu",
    "Advanced actions": "Napredna dejanja",
    "Advanced properties": "Napredne nastavitve",
    "Advanced transition": "Napredni prehodi",
    "All properties are imported.": "Vse lastnosti so uvožene.",
    "Allow interactions": "Dovoli interakcije",
    "An error occured": "Prišlo je do napake",
    "Are you sure you want to cancel your changes?": "Ali ste prepričani, da želite preklicati spremembe?",
    "Are you sure you want to clone this map and all its datalayers?": "Ali ste prepričani, da želite klonirati ta zemljevid in vse njegove podatkovne plasti?",
    "Are you sure you want to delete the feature?": "Ali ste prepričani, da želite izbrisati to možnost?",
    "Are you sure you want to delete this layer?": "Ali ste prepričani, da želite izbrisati to plast?",
    "Are you sure you want to delete this map?": "Ali ste prepričani, da želite izbrisati ta zemljevid?",
    "Are you sure you want to delete this property on all the features?": "Ali res želite izbrisati to lastnost pri vseh vstavljenih predmetih?",
    "Are you sure you want to restore this version?": "Ali res želite obnoviti to različico?",
    "Attach the map to my account": "Attach the map to my account",
    "Auto": "Samodejno",
    "Autostart when map is loaded": "Samodejno zaženi, ko je zemljevid naložen",
    "Bring feature to center": "Postavi predmet v središče",
    "Browse data": "Prebrskaj podatke",
    "Cancel edits": "Prekliči urajanje",
    "Center map on your location": "Postavi trenutno točko v središče zemljevida",
    "Change map background": "Zamenjaj ozadje zemljevida",
    "Change tilelayers": "Spremeni plasti",
    "Choose a preset": "Izbor prednastavitev",
    "Choose the format of the data to import": "Izbor oblike zapisa podatkov za uvoz",
    "Choose the layer to import in": "Izbor plasti za uvoz podatkov",
    "Click last point to finish shape": "Kliknite na zadnjo točko za dokončanje risanja oblike",
    "Click to add a marker": "Kliknite za dodajanje označbe",
    "Click to continue drawing": "Kliknite za nadaljevanje risanja",
    "Click to edit": "Kliknite za urejanje",
    "Click to start drawing a line": "Kliknite za začetek risanja črte",
    "Click to start drawing a polygon": "Kliknite za začetek risanja mnogokotnika",
    "Clone": "Kloniraj",
    "Clone of {name}": "Klon zemljevida {name}",
    "Clone this feature": "Kloniraj predmet",
    "Clone this map": "Kloniraj zemljevid",
    "Close": "Zapri",
    "Clustering radius": "Radij zbranega omgočja",
    "Comma separated list of properties to use when filtering features": "Z vejico ločen seznam lastnosti, uporabljenimi med filtriranjem predmetov",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Z vejico, tabulatorjem ali podpičjem ločene vrednosti, nakazane prek SRS WGS84. Uvoženi so le točkovni podatki. Med uvozom bo preiskan stolpec glav za podatke geografske »širine« in«dolžine«, neupoštevajoč velikost pisave. Vsi ostali stolpci bodo uvoženi kot lastnosti predmetov.",
    "Continue line": "Nadaljuj z risanjem črte",
    "Continue line (Ctrl-click)": "Nadaljuj s črto (ctrl-klik)",
    "Coordinates": "Koordinate",
    "Credits": "Zasluge",
    "Current view instead of default map view?": "Ali želite omogočiti trenutni pogled namesto privzetega pogleda zemljevida?",
    "Custom background": "Ozadje po meri",
    "Data is browsable": "Podatke je mogoče brskati",
    "Default interaction options": "Privzete možnosti interakcije",
    "Default properties": "Privzete lastnosti",
    "Default shape properties": "Privzete možnosti oblike",
    "Define link to open in a new window on polygon click.": "Določitev povezave za odpiranje v novem oknu ob kliku na mnogokotnik.",
    "Delay between two transitions when in play mode": "Zamik med prehodi v načinu predvajanja",
    "Delete": "Izbriši",
    "Delete all layers": "Izbriši vse plasti",
    "Delete layer": "Izbriši plast",
    "Delete this feature": "Izbriši ta predmet",
    "Delete this property on all the features": "Izbriši lastnost pri vseh vstavljenih predmetih",
    "Delete this shape": "Izbriši ta predmet",
    "Delete this vertex (Alt-click)": "Izbriši to točko (alt + klik)",
    "Directions from here": "Navigacija od tu",
    "Disable editing": "Onemogoči urejanje",
    "Display measure": "Pokaži merilo",
    "Display on load": "Prikaži ob nalaganju",
    "Download": "Download",
    "Download data": "Prejmi podatke",
    "Drag to reorder": "Potegni za prerazvrstitev",
    "Draw a line": "Nariši črto",
    "Draw a marker": "Nariši označbo",
    "Draw a polygon": "Nariši mnogokotnik",
    "Draw a polyline": "Nariši črto v več koleni",
    "Dynamic": "Dinamično",
    "Dynamic properties": "Dinamične lastnosti",
    "Edit": "Uredi",
    "Edit feature's layer": "Uredi plast predmeta",
    "Edit map properties": "Uredi lastnosti zemljevida",
    "Edit map settings": "Uredi nastavitve zemljevida",
    "Edit properties in a table": "Uredi lastnosti v razpredelnici",
    "Edit this feature": "Uredi predmet",
    "Editing": "Urejanje",
    "Embed and share this map": "Vstavi in objavi zemljevid",
    "Embed the map": "Vstavi zemljevid",
    "Empty": "Prazno",
    "Enable editing": "Omogoči urejanje",
    "Error in the tilelayer URL": "Napaka v naslovu URL plasti",
    "Error while fetching {url}": "Napaka pridobivanja naslova URL {url}",
    "Exit Fullscreen": "Končaj celozaslonski način",
    "Extract shape to separate feature": "Izloči obliko v ločen predmet",
    "Fetch data each time map view changes.": "Pridobi podatke vsakič, ko se spremeni pogled zemljevida.",
    "Filter keys": "Filtri",
    "Filter…": "Filter ...",
    "Format": "zapis",
    "From zoom": "Iz približanja",
    "Full map data": "Polni podatki zemljevida",
    "Go to «{feature}»": "Skoči na »{feature}«",
    "Heatmap intensity property": "Lastnosti jakosti vročinskih točk",
    "Heatmap radius": "Radij vročinskih točk",
    "Help": "Pomoč",
    "Hide controls": "Skrij orodja",
    "Home": "Začetna stran",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Kako močno naj bodo poenostavljene prte na posamezni ravni približanja (močno = boljše delovanje in prijetnejši videz ali malo = bolj natančen prikaz)",
    "If false, the polygon will act as a part of the underlying map.": "Neizbrana možnost določa, da bo mnogokotnik obravnavan kot del zemljevida.",
    "Iframe export options": "Možnosti izvoza v iFrame",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Predmet Iframe z višino po meri (v točkah): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Predmet Iframe z višino in širino po meri (v točkah): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Slika s širino po meri (v tpčkah): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Slika: {{http://image.url.com}}",
    "Import": "Uvozi",
    "Import data": "Uvozi podatke",
    "Import in a new layer": "Uvozi v novo plast",
    "Imports all umap data, including layers and settings.": "Uvozi vse podatke umap, vključno s plastmi in nastavitvami.",
    "Include full screen link?": "Ali želite vključiti povezavo do celozaslonskega prikaza?",
    "Interaction options": "Možnosti interakcije",
    "Invalid umap data": "Neveljavni podatki umap",
    "Invalid umap data in {filename}": "Neveljavni podatki umap v datoteki {filename}",
    "Keep current visible layers": "Ohrani trenutno vidne plasti",
    "Latitude": "Geografska širina",
    "Layer": "Plast",
    "Layer properties": "Lastnosti plasti",
    "Licence": "Dovoljenje",
    "Limit bounds": "Omejitev področja",
    "Link to…": "Povezava z ...",
    "Link with text: [[http://example.com|text of the link]]": "Povezava z besedilom: [[http://primer.com|besedilo povezave]]",
    "Long credits": "Poln seznam zaslug",
    "Longitude": "Geografska dolžina",
    "Make main shape": "Nastavi kot glavni predmet",
    "Manage layers": "Upravljanje s plastmi",
    "Map background credits": "Zasluge ozadij zemljevida",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Zemljevid je shranjen!",
    "Map user content has been published under licence": "Uporabniška vsebina  zemljevida je objavljena z dovoljenjem",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "Merge lines": "Združi črte",
    "More controls": "Več orodij",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Vrednost mora biti skladna z zapisom CSS (na primer: DarkBlue ali #123456)",
    "No licence has been set": "Ni določenega dovoljenja za uporabo",
    "No results": "Ni zadetkov",
    "Only visible features will be downloaded.": "Prejeti bodo le vidni predmeti.",
    "Open download panel": "Open download panel",
    "Open link in…": "Odpri povezavo v ...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Odpri obseg zemljevida v urejevalniku za prenos podrobnejših podatkov na OpenStreetMap.",
    "Optional intensity property for heatmap": "Izbirna lastnost jakosti vročinskih točke",
    "Optional. Same as color if not set.": "Izbirno. Enako, kot nedoločena barva.",
    "Optionnal.": "Izbirno.",
    "Override clustering radius (default 80)": "Prekliči radij združevanja (privzeto 80)",
    "Override heatmap radius (default 25)": "Prekliči radij vročinskih točk (privzeto 25)",
    "Paste here your data": "Prilepite podatke",
    "Please be sure the licence is compliant with your use.": "Prepričajte se, da je zemljevid uporabljen v skladu z dovoljenjem.",
    "Please choose a format": "Izbrati je treba zapis",
    "Please enter the name of the property": "Ime lastnosti",
    "Please enter the new name of this property": "Novo ime lastnosti",
    "Please save the map before": "Shranite zemljevid pred",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Zasnovano na orodjih <a href=\"{leaflet}\">Leaflet</a> in <a href=\"{django}\">Django</a>, združeno pri <a href=\"{umap}\">projektu uMap</a>.",
    "Problem in the response": "Napaka v odzivu",
    "Problem in the response format": "Napaka v zapisu odziva",
    "Properties imported:": "Lastnosti so uvožene:",
    "Property to use for sorting features": "Določilo za uporabo pri razvrščanju predmetov",
    "Provide an URL here": "Vpis naslova URL",
    "Proxy request": "Zahteva posredniškega strežnika",
    "Remote data": "Oddaljeni podatki",
    "Remove shape from the multi": "Odstrani obliko iz večtočkovnega predmeta",
    "Rename this property on all the features": "Preimenuj lastnost na vseh predmetih",
    "Replace layer content": "Zamenjaj vsebino plasti",
    "Restore this version": "Obnovi različico",
    "Save": "Shrani",
    "Save anyway": "Vseeno shrani",
    "Save current edits": "Shrani urejanje",
    "Save this center and zoom": "Shrani središče in približaj",
    "Save this location as new feature": "Shrani mesto kot nov predmet",
    "Search a place name": "Search a place name",
    "Search location": "Preišči mesto",
    "Secret edit link is:<br>{link}": "Secret edit link is:<br>{link}",
    "See all": "Pokaži vse",
    "See data layers": "See data layers",
    "See full screen": "Pokaži v celozaslonskem načinu",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Neizbrana možnost skrije plast med predstavitvijo,  v pregledovalniku podatkov, ...",
    "Shape properties": "Lastnosti oblike",
    "Short URL": "Skrajšan naslov URL",
    "Short credits": "Kratek zapis zaslug",
    "Show/hide layer": "Pokaži / Skrij plast",
    "Simple link: [[http://example.com]]": "Enostavna povezava: [[http://primer.com]]",
    "Skipping unkown geometry.type: {type}": "Preskoči neznano geometrično vrsto: {type}",
    "Slideshow": "Predstavitev",
    "Smart transitions": "Pametni prehodi",
    "Sort key": "Razvrščanje",
    "Split line": "Ločitvena črta",
    "Start a hole here": "Začni z vrisovanjem luknje",
    "Start editing": "Začni z urejanjem",
    "Start slideshow": "Začni s predstavitvijo",
    "Stop editing": "Končaj z urejanjem",
    "Stop slideshow": "Zaustavi predstavitev",
    "Supported scheme": "Podprta shema",
    "Supported variables that will be dynamically replaced": "Podprte spremenljivke, ki bodo dinamično zamenjane",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.",
    "TMS format": "Zapis TMS",
    "Text color for the cluster label": "Barva besedila za oznako polja",
    "Text formatting": "Oblikovanje besedila",
    "The name of the property to use as feature label (ex.: \"nom\")": "Ime lastnosti, ki naj se uporabi kot oznaka predmeta (na primer »nom«)",
    "The zoom and center have been setted.": "Vrednost in središčna točka sta nastavljeni.",
    "To use if remote server doesn't allow cross domain (slower)": "Za uporabo, ko oddaljeni stražnik ne dovoli vzporednih domen (počasneje)",
    "To zoom": "Za približanje",
    "Toggle edit mode (shift-click)": "Preklop načina urejanja (shift + klik)",
    "Transfer shape to edited feature": "Prenesi obliko na urejen predmet",
    "Transform to lines": "Pretvori v črte",
    "Transform to polygon": "Pretvori v mnogokotnik",
    "Type of layer": "Vrsta plasti",
    "Unable to detect format of file {filename}": "Ni mogoče zaznati zapisa datoteke {filename}",
    "Untitled layer": "Neimenovana plast",
    "Untitled map": "Neimenovan zemljevid",
    "Update permissions": "Update permissions",
    "Update permissions and editors": "Posodobitev dovoljenj in urednikov",
    "Url": "Naslov URL",
    "Use current bounds": "Uporabi trenutne meje",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Uporabi ročnike lastnosti predmetov, pri zapisu podatkov. Vpis &#123;ime&#125; bo dinamično zamenjan z ustrezno vrednostjo.",
    "User content credits": "Zasluge za uporabniško vsebino",
    "User interface options": "Možnosti uporabniškega vmesnika",
    "Versions": "Različice",
    "View Fullscreen": "Pokaži v celozaslonskem načinu",
    "Where do we go from here?": "Kam naj se usmerimo?",
    "Whether to display or not polygons paths.": "Ali naj bodo izrisane daljice mnogokotnika.",
    "Whether to fill polygons with color.": "Ali naj bodo mnogokotniki zapolnjeni z barvo.",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "Will be displayed in the bottom right corner of the map": "Prikazan bo v spodnjem desnem kotu zemljevida",
    "Will be visible in the caption of the map": "Prikazan bo v naslovu zemljevida",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Opa! Nekdo drug je najverjetneje urejal podatke. Spremembe lahko vseeno shranite, vendar bo to prepisalo spremembe, ustvarjene s strani drugih urednikov.",
    "You have unsaved changes.": "Zaznane so neshranjene spremembe.",
    "Zoom in": "Približaj",
    "Zoom level for automatic zooms": "Raven za samodejno približanje",
    "Zoom out": "Oddalji",
    "Zoom to layer extent": "Približaj na obseg plasti",
    "Zoom to the next": "Približaj na naslednjo točko",
    "Zoom to the previous": "Približaj na predhodno točko",
    "Zoom to this feature": "Približaj k predmetu",
    "Zoom to this place": "Približaj na to mesto",
    "attribution": "pripisovanje",
    "by": "–",
    "display name": "prikazno ime",
    "height": "višina",
    "licence": "dovoljenje",
    "max East": "najbolj vzhodno",
    "max North": "najbolj severno",
    "max South": "najbolj južno",
    "max West": "najbolj zahodno",
    "max zoom": "največje približanje",
    "min zoom": "največje oddaljanje",
    "next": "naslednji",
    "previous": "predhodni",
    "width": "širina",
    "{count} errors during import: {message}": "Zaznane so napake ({count}) med uvozom: {message}",
    "Measure distances": "Measure distances",
    "NM": "NM",
    "kilometers": "kilometers",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "nautical miles",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} km",
    "{distance} m": "{distance} m",
    "{distance} miles": "{distance} miles",
    "{distance} yd": "{distance} yd",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup shape": "Popup shape"
};
L.registerLocale("sl", locale);
L.setLocale("sl");