{% extends "umap/content.html" %}

{% load i18n %}

{% block content %}
  <h2 class="section">{% trans "Password change" %}</h2>
  <p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

  <form action="{% url 'password_change' %}" method="POST">
    {% csrf_token %}
    {{ form.old_password.errors }}
    <input type='password' name='old_password' placeholder='{% trans "Old password" %}' autofocus />
    {{ form.new_password1.errors }}
    <input type='password' name='new_password1' placeholder='{% trans "New password" %}' />
    {{ form.new_password2.errors }}
    <input type='password' name='new_password2' placeholder='{% trans "New password confirmation" %}' />

    <input type='submit' value='{% trans "Change my password" %}' />
  </form>
{% endblock content %}
